pub struct Request<'a> {
pub client_secret: &'a ClientSecret,
pub identity_server_info: IdentityServerInfo<'a>,
pub sid: &'a SessionId,
}Available on crate features
client or server only.Expand description
Data for a request to the bind_3pid API endpoint.
Bind a 3PID to a user’s account on an identity server
Fields
client_secret: &'a ClientSecretClient-generated secret string used to protect this session.
identity_server_info: IdentityServerInfo<'a>The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
sid: &'a SessionIdThe session identifier given by the identity server.
Implementations
Sourceimpl<'a> Request<'a>
impl<'a> Request<'a>
Sourcepub fn new(
client_secret: &'a ClientSecret,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a SessionId,
) -> Self
pub fn new( client_secret: &'a ClientSecret, identity_server_info: IdentityServerInfo<'a>, sid: &'a SessionId, ) -> Self
Creates a new Request with the given client secret, identity server information and
session identifier.