#[non_exhaustive]
pub enum ThirdPartyIdRemovalStatus {
NoSupport,
Success,
// some variants omitted
}Available on crate features
client or server only.Expand description
Possible values for deleting or unbinding 3PIDs.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoSupport
Either the homeserver couldn’t determine the right identity server to contact, or the identity server refused the operation.
Success
Success.
Implementations