Available on crate features
client or server only.Expand description
GET /_matrix/client/*/register/available
Checks to see if a username is available, and valid, for the server.
client or server only.GET /_matrix/client/*/register/available
Checks to see if a username is available, and valid, for the server.