Struct ruma_client_api::account::get_username_availability::v3::Response
source · pub struct Response {
pub available: bool,
}Available on crate features
client or server only.Expand description
Response type for the get_username_availability endpoint.
Fields
available: boolA flag to indicate that the username is available. This should always be true when the server replies with 200 OK.
Implementations