Struct ruma_client_api::backup::add_backup_keys_for_session::v3::Response
source · pub struct Response {
pub etag: String,
pub count: UInt,
}Available on crate features
client or server only.Expand description
Response type for the add_backup_keys_for_session endpoint.
Fields
etag: StringAn opaque string representing stored keys in the backup.
Clients can compare it with the etag value they received in the request of their last key storage request.
count: UIntThe number of keys stored in the backup.
Implementations