Module ruma_client_api::backup::create_backup_version::v3
source · [−]Available on crate features
client or server only.Expand description
/v3/ (spec)
Structs
Data for a request to the
create_backup_version API endpoint.Data in the response from the
create_backup_version API endpoint.Constants
Metadata for the
create_backup_version API endpoint.Type Definitions
Convenience type alias for Request, for consistency with other IncomingRequest types.
Convenience type alias for Response, for consistency with other IncomingResponse types.