Available on crate features
client or server only.Expand description
DELETE /_matrix/client/*/room_keys/keys/{roomId}/{sessionId}
Delete keys from a backup for a given session.
client or server only.DELETE /_matrix/client/*/room_keys/keys/{roomId}/{sessionId}
Delete keys from a backup for a given session.