Struct ruma_client_api::backup::get_backup_info::v3::Response
source · [−]pub struct Response {
pub algorithm: Raw<BackupAlgorithm>,
pub count: UInt,
pub etag: String,
pub version: String,
}Available on crate features
client or server only.Expand description
Data in the response from the get_backup_info API endpoint.
Fields
algorithm: Raw<BackupAlgorithm>The algorithm used for storing backups.
count: UIntThe number of keys stored in the backup.
etag: StringAn opaque string representing stored keys in the backup.
Clients can compare it with the etag value they received in the request of their last key storage request.
version: StringThe backup version.
Implementations