Available on crate features
client or server only.Expand description
GET /_matrix/client/*/room_keys/keys/{roomId}/{sessionId}
Retrieve a key from the backup for a given session.
client or server only.GET /_matrix/client/*/room_keys/keys/{roomId}/{sessionId}
Retrieve a key from the backup for a given session.