Struct ruma_client_api::backup::KeyBackupDataInit
source · pub struct KeyBackupDataInit {
pub first_message_index: UInt,
pub forwarded_count: UInt,
pub is_verified: bool,
pub session_data: SessionData,
}Available on crate features
client or server only.Expand description
Information about the backup key.
This struct will not be updated even if additional fields are added to SessionData in a
new (non-breaking) release of the Matrix specification.
Fields
first_message_index: UIntThe index of the first message in the session that the key can decrypt.
forwarded_count: UIntThe number of times this key has been forwarded via key-sharing between devices.
is_verified: boolWhether the device backing up the key verified the device that the key is from.
session_data: SessionDataData about the session.