Struct ruma_client_api::config::set_global_account_data::v3::Request
source · [−]pub struct Request<'a> {
pub user_id: &'a UserId,
pub event_type: GlobalAccountDataEventType,
pub data: Raw<AnyGlobalAccountDataEventContent>,
}Available on crate features
client or server only.Expand description
Data for a request to the set_global_account_data API endpoint.
Sets global account data.
Fields
user_id: &'a UserIdThe ID of the user to set account_data for.
The access token must be authorized to make requests for this user ID.
event_type: GlobalAccountDataEventTypeThe event type of the account_data to set.
Custom types should be namespaced to avoid clashes.
data: Raw<AnyGlobalAccountDataEventContent>Arbitrary JSON to store as config data.
To create a RawJsonValue, use serde_json::value::to_raw_value.
Implementations
sourceimpl<'a> Request<'a>
impl<'a> Request<'a>
sourcepub fn new<T>(user_id: &'a UserId, data: &'a T) -> Result<Self>where
T: GlobalAccountDataEventContent,
pub fn new<T>(user_id: &'a UserId, data: &'a T) -> Result<Self>where
T: GlobalAccountDataEventContent,
sourcepub fn new_raw(
user_id: &'a UserId,
event_type: GlobalAccountDataEventType,
data: Raw<AnyGlobalAccountDataEventContent>
) -> Self
pub fn new_raw(
user_id: &'a UserId,
event_type: GlobalAccountDataEventType,
data: Raw<AnyGlobalAccountDataEventContent>
) -> Self
Creates a new Request with the given raw data, event type and user ID.