Struct ruma_client_api::context::get_context::v3::Response
source · pub struct Response {
pub start: Option<String>,
pub end: Option<String>,
pub events_before: Vec<Raw<AnyTimelineEvent>>,
pub event: Option<Raw<AnyTimelineEvent>>,
pub events_after: Vec<Raw<AnyTimelineEvent>>,
pub state: Vec<Raw<AnyStateEvent>>,
}Available on crate features
client or server only.Expand description
Response type for the get_context endpoint.
Fields
start: Option<String>A token that can be used to paginate backwards with.
end: Option<String>A token that can be used to paginate forwards with.
events_before: Vec<Raw<AnyTimelineEvent>>A list of room events that happened just before the requested event, in reverse-chronological order.
event: Option<Raw<AnyTimelineEvent>>Details of the requested event.
events_after: Vec<Raw<AnyTimelineEvent>>A list of room events that happened just after the requested event, in chronological order.
state: Vec<Raw<AnyStateEvent>>The state of the room at the last event returned.
Implementations