pub struct DehydratedDeviceV1 {
pub device_pickle: String,
}Available on (crate features
client or server) and crate feature unstable-msc3814 only.Expand description
The org.matrix.msc3814.v1.olm variant of a dehydrated device.
Fields
device_pickle: StringThe pickle of the Olm account of the device.
The pickle will contain the private parts of the long-term identity keys of the device as well as a collection of one-time keys.
Implementations
sourceimpl DehydratedDeviceV1
impl DehydratedDeviceV1
sourcepub fn new(device_pickle: String) -> Self
pub fn new(device_pickle: String) -> Self
Create a DehydratedDeviceV1 struct from a device pickle.