Struct ruma_client_api::directory::set_room_visibility::v3::Request
source · pub struct Request {
pub room_id: OwnedRoomId,
pub visibility: Visibility,
}Available on crate features
client or server only.Expand description
Request type for the set_room_visibility endpoint.
Fields
room_id: OwnedRoomIdThe ID of the room of which to set the visibility.
visibility: VisibilityNew visibility setting for the room.
Implementations
sourceimpl Request
impl Request
sourcepub fn new(room_id: OwnedRoomId, visibility: Visibility) -> Self
pub fn new(room_id: OwnedRoomId, visibility: Visibility) -> Self
Creates a new Request with the given room ID and visibility.