Struct ruma_client_api::discovery::discover_homeserver::Response
source · pub struct Response {
pub homeserver: HomeserverInfo,
pub identity_server: Option<IdentityServerInfo>,
pub tile_server: Option<TileServerInfo>,
pub authentication: Option<AuthenticationServerInfo>,
pub sliding_sync_proxy: Option<SlidingSyncProxyInfo>,
}Available on crate features
client or server only.Expand description
Response type for the client_well_known endpoint.
Fields
homeserver: HomeserverInfoInformation about the homeserver to connect to.
identity_server: Option<IdentityServerInfo>Information about the identity server to connect to.
tile_server: Option<TileServerInfo>Available on crate feature
unstable-msc3488 only.Information about the tile server to use to display location data.
authentication: Option<AuthenticationServerInfo>Available on crate feature
unstable-msc2965 only.Information about the authentication server to connect to when using OpenID Connect.
sliding_sync_proxy: Option<SlidingSyncProxyInfo>Available on crate feature
unstable-msc3575 only.Information about the homeserver’s trusted proxy to use for sliding sync development.
Implementations