Struct ruma_client_api::discovery::get_capabilities::Capabilities
source · pub struct Capabilities {
pub change_password: ChangePasswordCapability,
pub room_versions: RoomVersionsCapability,
pub set_displayname: SetDisplayNameCapability,
pub set_avatar_url: SetAvatarUrlCapability,
pub thirdparty_id_changes: ThirdPartyIdChangesCapability,
/* private fields */
}client or server only.Expand description
Contains information about all the capabilities that the server supports.
Fields
change_password: ChangePasswordCapabilityCapability to indicate if the user can change their password.
room_versions: RoomVersionsCapabilityThe room versions the server supports.
set_displayname: SetDisplayNameCapabilityCapability to indicate if the user can change their display name.
set_avatar_url: SetAvatarUrlCapabilityCapability to indicate if the user can change their avatar.
thirdparty_id_changes: ThirdPartyIdChangesCapabilityCapability to indicate if the user can change the third-party identifiers associated with their account.
Implementations
sourceimpl Capabilities
impl Capabilities
sourcepub fn get(&self, capability: &str) -> Option<Cow<'_, JsonValue>>
pub fn get(&self, capability: &str) -> Option<Cow<'_, JsonValue>>
Returns the value of the given capability.
Prefer to use the public fields of Capabilities where possible; this method is meant to be
used for unsupported capabilities only.
sourcepub fn set(&mut self, capability: &str, value: JsonValue) -> Result<()>
pub fn set(&mut self, capability: &str, value: JsonValue) -> Result<()>
Sets a capability to the given value.
Prefer to use the public fields of Capabilities where possible; this method is meant to be
used for unsupported capabilities only and does not allow setting arbitrary data for
supported ones.
sourcepub fn iter(&self) -> CapabilitiesIter<'_> ⓘ
pub fn iter(&self) -> CapabilitiesIter<'_> ⓘ
Returns an iterator over the capabilities.