pub struct Error {
pub kind: ErrorKind,
pub message: String,
pub status_code: StatusCode,
pub authenticate: Option<AuthenticateError>,
}Available on crate features
client or server only.Expand description
A Matrix Error
Fields
kind: ErrorKindA value which can be used to handle an error message.
message: StringA human-readable error message, usually a sentence explaining what went wrong.
status_code: StatusCodeThe http status code.
authenticate: Option<AuthenticateError>Available on crate feature
unstable-msc2967 only.The WWW-Authenticate header error message.