pub struct ErrorBody {
pub kind: ErrorKind,
pub message: String,
}Available on crate features
client or server only.Expand description
A Matrix Error without a status code.
Fields
kind: ErrorKindA value which can be used to handle an error message.
message: StringA human-readable error message, usually a sentence explaining what went wrong.
Implementations
Sourceimpl ErrorBody
impl ErrorBody
Sourcepub fn into_error(self, status_code: StatusCode) -> Error
pub fn into_error(self, status_code: StatusCode) -> Error
Convert the ErrorBody into an Error by adding the http status code.