ruma_client_api::filter

Struct Filter

pub struct Filter<'a> {
    pub not_types: &'a [String],
    pub limit: Option<UInt>,
    pub senders: Option<&'a [OwnedUserId]>,
    pub types: Option<&'a [String]>,
    pub not_senders: &'a [OwnedUserId],
}
Available on crate features client or server only.
Filter for non-room data.

Fields

not_types: &'a [String]

A list of event types to exclude.

If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.

limit: Option<UInt>

The maximum number of events to return.

senders: Option<&'a [OwnedUserId]>

A list of senders IDs to include.

If this list is absent then all senders are included.

types: Option<&'a [String]>

A list of event types to include.

If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.

not_senders: &'a [OwnedUserId]

A list of sender IDs to exclude.

If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.

Implementations

Source

impl<'a> Filter<'a>

pub fn empty() -> Self

Creates an empty Filter.

You can also use the Default implementation.

pub fn ignore_all() -> Self

Creates a new Filter that can be used to ignore all events.

pub fn is_empty(&self) -> bool

Returns true if all fields are empty.