ruma_client_api::filter

Struct RoomEventFilter

pub struct RoomEventFilter<'a> {
    pub not_types: &'a [String],
    pub not_rooms: &'a [OwnedRoomId],
    pub limit: Option<UInt>,
    pub rooms: Option<&'a [OwnedRoomId]>,
    pub not_senders: &'a [OwnedUserId],
    pub senders: Option<&'a [OwnedUserId]>,
    pub types: Option<&'a [String]>,
    pub url_filter: Option<UrlFilter>,
    pub lazy_load_options: LazyLoadOptions,
    pub related_by_rel_types: &'a [RelationType],
    pub related_by_senders: &'a [OwnedUserId],
}
Available on crate features client or server only.
Filters to be applied to room events.

Fields

not_types: &'a [String]

A list of event types to exclude.

If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.

not_rooms: &'a [OwnedRoomId]

A list of room IDs to exclude.

If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter.

limit: Option<UInt>

The maximum number of events to return.

rooms: Option<&'a [OwnedRoomId]>

A list of room IDs to include.

If this list is absent then all rooms are included.

not_senders: &'a [OwnedUserId]

A list of sender IDs to exclude.

If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.

senders: Option<&'a [OwnedUserId]>

A list of senders IDs to include.

If this list is absent then all senders are included.

types: Option<&'a [String]>

A list of event types to include.

If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.

url_filter: Option<UrlFilter>

Controls whether to include events with a URL key in their content.

  • None: No filtering
  • Some(EventsWithUrl): Only events with a URL
  • Some(EventsWithoutUrl): Only events without a URL
lazy_load_options: LazyLoadOptions

Options to control lazy-loading of membership events.

Defaults to LazyLoadOptions::Disabled.

related_by_rel_types: &'a [RelationType]
Available on crate feature unstable-msc3440 only.

A list of relation types to include.

An event A is included in the filter only if there exists another event B which relates to A with a rel_type which is defined in the list.

related_by_senders: &'a [OwnedUserId]
Available on crate feature unstable-msc3440 only.

A list of senders to include.

An event A is included in the filter only if there exists another event B which relates to A, and which has a sender which is in the list.

Implementations

Source

impl<'a> RoomEventFilter<'a>

pub fn empty() -> Self

Creates an empty RoomEventFilter.

You can also use the Default implementation.

pub fn ignore_all() -> Self

Creates a new RoomEventFilter that can be used to ignore all room events.

pub fn is_empty(&self) -> bool

Returns true if all fields are empty.