Struct ruma_client_api::keys::get_key_changes::v3::Response
source · pub struct Response {
pub changed: Vec<OwnedUserId>,
pub left: Vec<OwnedUserId>,
}Available on crate features
client or server only.Expand description
Response type for the get_key_changes endpoint.
Fields
changed: Vec<OwnedUserId>The Matrix User IDs of all users who updated their device identity keys.
left: Vec<OwnedUserId>The Matrix User IDs of all users who may have left all the end-to-end encrypted rooms they previously shared with the user.
Implementations
sourceimpl Response
impl Response
sourcepub fn new(changed: Vec<OwnedUserId>, left: Vec<OwnedUserId>) -> Self
pub fn new(changed: Vec<OwnedUserId>, left: Vec<OwnedUserId>) -> Self
Creates a new Response with the given changed and left user ID lists.