pub struct Invite3pid<'a> {
pub id_server: &'a str,
pub id_access_token: &'a str,
pub medium: Medium,
pub address: &'a str,
}Available on crate features
client or server only.Expand description
Represents third party IDs to invite to the room.
To create an instance of this type, first create a Invite3pidInit and convert it via
Invite3pid::from / .into().
Fields
id_server: &'a strHostname and port of identity server to be used for account lookups.
id_access_token: &'a strAn access token registered with the identity server.
medium: MediumType of third party ID.
address: &'a strThird party identifier.