Struct ruma_client_api::membership::ThirdPartySigned
source · pub struct ThirdPartySigned {
pub sender: OwnedUserId,
pub mxid: OwnedUserId,
pub token: String,
pub signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>,
}Available on crate features
client or server only.Expand description
A signature of an m.third_party_invite token to prove that this user owns a third party
identity which has been invited to the room.
Fields
sender: OwnedUserIdThe Matrix ID of the user who issued the invite.
mxid: OwnedUserIdThe Matrix ID of the invitee.
token: StringThe state key of the m.third_party_invite event.
signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>A signatures object containing a signature of the entire signed object.
Implementations
sourceimpl ThirdPartySigned
impl ThirdPartySigned
sourcepub fn new(
sender: OwnedUserId,
mxid: OwnedUserId,
token: String,
signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>
) -> Self
pub fn new(
sender: OwnedUserId,
mxid: OwnedUserId,
token: String,
signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>
) -> Self
Creates a new ThirdPartySigned from the given sender and invitee user IDs, state key token
and signatures.