Struct ruma_client_api::message::get_message_events::v3::IncomingRequest
source · [−]pub struct IncomingRequest {
pub room_id: OwnedRoomId,
pub from: Option<String>,
pub to: Option<String>,
pub dir: Direction,
pub limit: UInt,
pub filter: IncomingRoomEventFilter,
}client or server only.Expand description
‘Incoming’ variant of Request.
Fields
room_id: OwnedRoomIdThe room to get events from.
from: Option<String>The token to start returning events from.
This token can be obtained from a prev_batch token returned for each room by the
sync endpoint, or from a start or end token returned by a previous request to
this endpoint.
If this is None, the server will return messages from the start or end of the
history visible to the user, depending on the value of dir.
to: Option<String>The token to stop returning events at.
This token can be obtained from a prev_batch token returned for each room by the
sync endpoint, or from a start or end token returned by a previous request to
this endpoint.
dir: DirectionThe direction to return events from.
limit: UIntThe maximum number of events to return.
Default: 10.
filter: IncomingRoomEventFilterA RoomEventFilter to filter returned events with.