Struct ruma_client_api::message::get_message_events::v3::Request
source · [−]pub struct Request<'a> {
pub room_id: &'a RoomId,
pub from: Option<&'a str>,
pub to: Option<&'a str>,
pub dir: Direction,
pub limit: UInt,
pub filter: RoomEventFilter<'a>,
}client or server only.Expand description
Data for a request to the get_message_events API endpoint.
Get message events for a room.
Fields
room_id: &'a RoomIdThe room to get events from.
from: Option<&'a str>The token to start returning events from.
This token can be obtained from a prev_batch token returned for each room by the
sync endpoint, or from a start or end token returned by a previous request to
this endpoint.
If this is None, the server will return messages from the start or end of the
history visible to the user, depending on the value of dir.
to: Option<&'a str>The token to stop returning events at.
This token can be obtained from a prev_batch token returned for each room by the
sync endpoint, or from a start or end token returned by a previous request to
this endpoint.
dir: DirectionThe direction to return events from.
limit: UIntThe maximum number of events to return.
Default: 10.
filter: RoomEventFilter<'a>A RoomEventFilter to filter returned events with.
Implementations
sourceimpl<'a> Request<'a>
impl<'a> Request<'a>
sourcepub fn new(room_id: &'a RoomId, dir: Direction) -> Self
pub fn new(room_id: &'a RoomId, dir: Direction) -> Self
Creates a new Request with the given room ID and direction.
All other parameters will be defaulted.
sourcepub fn backward(room_id: &'a RoomId) -> Self
pub fn backward(room_id: &'a RoomId) -> Self
Creates a new Request with the given room ID and dir set to Backward.
If the returned request is sent without from being set, pagination will start at the
end of (the accessible part of) the room timeline.
Example
let request = get_message_events::v3::Request::backward(room_id).from(token);sourcepub fn forward(room_id: &'a RoomId) -> Self
pub fn forward(room_id: &'a RoomId) -> Self
Creates a new Request with the given room ID and dir set to Forward.
If the returned request is sent without from being set, pagination will start at the
beginning of (the accessible part of) the room timeline.
Example
let request = get_message_events::v3::Request::forward(room_id).from(token);Trait Implementations
sourceimpl<'a> OutgoingRequest for Request<'a>
Available on crate feature client only.
impl<'a> OutgoingRequest for Request<'a>
client only.type EndpointError = Error
type EndpointError = Error
type IncomingResponse = Response
type IncomingResponse = Response
sourcefn try_into_http_request<T: Default + BufMut>(
self,
base_url: &str,
access_token: SendAccessToken<'_>,
considering_versions: &[MatrixVersion]
) -> Result<Request<T>, IntoHttpError>
fn try_into_http_request<T: Default + BufMut>(
self,
base_url: &str,
access_token: SendAccessToken<'_>,
considering_versions: &[MatrixVersion]
) -> Result<Request<T>, IntoHttpError>
http::Request. Read moreAuto Trait Implementations
impl<'a> RefUnwindSafe for Request<'a>
impl<'a> Send for Request<'a>
impl<'a> Sync for Request<'a>
impl<'a> Unpin for Request<'a>
impl<'a> UnwindSafe for Request<'a>