Module ruma_client_api::push::get_notifications
source · Available on crate features
client or server only.Expand description
GET /_matrix/client/*/notifications
Paginate through the list of events that the user has been, or would have been notified about.