Struct ruma_client_api::push::get_notifications::v3::Notification
source · pub struct Notification {
pub actions: Vec<Action>,
pub event: Raw<AnySyncTimelineEvent>,
pub profile_tag: Option<String>,
pub read: bool,
pub room_id: OwnedRoomId,
pub ts: MilliSecondsSinceUnixEpoch,
}Available on crate features
client or server only.Expand description
Represents a notification.
Fields
actions: Vec<Action>The actions to perform when the conditions for this rule are met.
event: Raw<AnySyncTimelineEvent>The event that triggered the notification.
profile_tag: Option<String>The profile tag of the rule that matched this event.
read: boolIndicates whether the user has sent a read receipt indicating that they have read this message.
room_id: OwnedRoomIdThe ID of the room in which the event was posted.
ts: MilliSecondsSinceUnixEpochThe time at which the event notification was sent.
Implementations
sourceimpl Notification
impl Notification
sourcepub fn new(
actions: Vec<Action>,
event: Raw<AnySyncTimelineEvent>,
read: bool,
room_id: OwnedRoomId,
ts: MilliSecondsSinceUnixEpoch
) -> Self
pub fn new(
actions: Vec<Action>,
event: Raw<AnySyncTimelineEvent>,
read: bool,
room_id: OwnedRoomId,
ts: MilliSecondsSinceUnixEpoch
) -> Self
Creates a new Notification with the given actions, event, read flag, room ID and
timestamp.