pub struct Pusher {
pub pushkey: String,
pub kind: PusherKind,
pub app_id: String,
pub app_display_name: String,
pub device_display_name: String,
pub profile_tag: Option<String>,
pub lang: String,
pub data: PusherData,
}Available on crate features
client or server only.Expand description
Defines a pusher.
To create an instance of this type, first create a PusherInit and convert it via
Pusher::from / .into().
Fields
pushkey: StringA unique identifier for this pusher.
The maximum allowed length is 512 bytes.
kind: PusherKindThe kind of the pusher.
app_id: StringA reverse-DNS style identifier for the application.
The maximum allowed length is 64 bytes.
app_display_name: StringA string that will allow the user to identify what application owns this pusher.
device_display_name: StringA string that will allow the user to identify what device owns this pusher.
profile_tag: Option<String>Determines which set of device specific rules this pusher executes.
lang: StringThe preferred language for receiving notifications (e.g. ‘en’ or ‘en-US’)
data: PusherDataInformation for the pusher implementation itself.