Module ruma_client_api::push::get_pushrules_all::v3
source · [−]Available on crate features
client or server only.Expand description
/v3/ (spec)
Structs
Data for a request to the
get_pushrules_all API endpoint.Data in the response from the
get_pushrules_all API endpoint.Constants
Metadata for the
get_pushrules_all API endpoint.Type Definitions
Convenience type alias for Request, for consistency with other IncomingRequest types.
Convenience type alias for Response, for consistency with other IncomingResponse types.