logo
Available on crate features client or server only.
/v3/ (spec)

Structs

Data for a request to the get_pushrules_global_scope API endpoint.
Data in the response from the get_pushrules_global_scope API endpoint.

Constants

Metadata for the get_pushrules_global_scope API endpoint.

Type Definitions

Convenience type alias for Request, for consistency with other IncomingRequest types.
Convenience type alias for Response, for consistency with other IncomingResponse types.