ruma_client_api::push::set_pusher::v3

Struct PusherInit

pub struct PusherInit {
    pub pushkey: String,
    pub kind: Option<PusherKind>,
    pub app_id: String,
    pub app_display_name: String,
    pub device_display_name: String,
    pub profile_tag: Option<String>,
    pub lang: String,
    pub data: PusherData,
}
Available on crate features client or server only.
Initial set of fields of Pusher.

This struct will not be updated even if additional fields are added to Pusher in a new (non-breaking) release of the Matrix specification.

Fields

pushkey: String

A unique identifier for this pusher.

The maximum allowed length is 512 bytes.

kind: Option<PusherKind>

The kind of the pusher.

None deletes the pusher.

app_id: String

A reverse-DNS style identifier for the application.

The maximum allowed length is 64 bytes.

app_display_name: String

A string that will allow the user to identify what application owns this pusher.

device_display_name: String

A string that will allow the user to identify what device owns this pusher.

profile_tag: Option<String>

Determines which set of device specific rules this pusher executes.

lang: String

The preferred language for receiving notifications (e.g. ‘en’ or ‘en-US’)

data: PusherData

Information for the pusher implementation itself.