Struct ruma_client_api::push::set_pusher::v3::PusherPostData
source · pub struct PusherPostData {
pub pusher: Pusher,
pub append: bool,
}Available on crate features
client or server only.Expand description
Data necessary to create or update a pusher.
Fields
pusher: PusherThe pusher to configure.
append: boolControls if another pusher with the same pushkey and app id should be created, if there are already others for other users.
Defaults to false. See the spec for more details.