Module ruma_client_api::push::set_pushrule_actions
source · Available on crate features
client or server only.Expand description
PUT /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}/actions
This endpoint allows clients to change the actions of a push rule. This can be used to change the actions of builtin rules.