Struct ruma_client_api::push::Pusher
source · pub struct Pusher {
pub ids: PusherIds,
pub kind: PusherKind,
pub app_display_name: String,
pub device_display_name: String,
pub profile_tag: Option<String>,
pub lang: String,
}Available on crate features
client or server only.Expand description
Defines a pusher.
To create an instance of this type, first create a PusherInit and convert it via
Pusher::from / .into().
Fields
ids: PusherIdsIdentifiers for this pusher.
kind: PusherKindThe kind of the pusher and the information for that kind.
app_display_name: StringA string that will allow the user to identify what application owns this pusher.
device_display_name: StringA string that will allow the user to identify what device owns this pusher.
profile_tag: Option<String>Determines which set of device specific rules this pusher executes.
lang: StringThe preferred language for receiving notifications (e.g. ‘en’ or ‘en-US’)