Struct ruma_client_api::r0::account::bind_3pid::IncomingRequest
source · [−]pub struct IncomingRequest {
pub client_secret: Box<ClientSecret>,
pub identity_server_info: IncomingIdentityServerInfo,
pub sid: Box<SessionId>,
}Expand description
‘Incoming’ variant of Request.
Fields
client_secret: Box<ClientSecret>Client-generated secret string used to protect this session.
identity_server_info: IncomingIdentityServerInfoThe ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
sid: Box<SessionId>The session identifier given by the identity server.