Struct ruma_client_api::r0::account::bind_3pid::Request [−][src]
pub struct Request<'a> {
pub client_secret: &'a str,
pub identity_server_info: IdentityServerInfo<'a>,
pub sid: &'a str,
}Expand description
Data for a request to the bind_3pid API endpoint.
Bind a 3PID to a user’s account on an identity server
Fields
client_secret: &'a strClient-generated secret string used to protect this session.
identity_server_info: IdentityServerInfo<'a>The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
sid: &'a strThe session identifier given by the identity server.
Implementations
pub fn new(
client_secret: &'a str,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a str
) -> Self
pub fn new(
client_secret: &'a str,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a str
) -> SelfCreates a new Request with the given client secret, identity server information and
session identifier.