Struct ruma_client_api::r0::account::get_username_availability::Response [−][src]
pub struct Response {
pub available: bool,
}Expand description
Data in the response from the get_username_availability API endpoint.
Fields
available: boolA flag to indicate that the username is available. This should always be true when the server replies with 200 OK.
Implementations