Struct ruma_client_api::r0::account::register::Request[][src]

#[non_exhaustive]
pub struct Request<'a> { pub password: Option<&'a str>, pub username: Option<&'a str>, pub device_id: Option<&'a DeviceId>, pub initial_device_display_name: Option<&'a str>, pub auth: Option<AuthData<'a>>, pub kind: RegistrationKind, pub inhibit_login: bool, pub login_type: Option<&'a LoginType>, }
Data for a request to the register API endpoint.

Register an account on this homeserver.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
password: Option<&'a str>
The desired password for the account.

May be empty for accounts that should not be able to log in again with a password, e.g., for guest or application service accounts.

username: Option<&'a str>
Localpart of the desired Matrix ID.

If omitted, the homeserver MUST generate a Matrix ID local part.

device_id: Option<&'a DeviceId>
ID of the client device.

If this does not correspond to a known client device, a new device will be created. The server will auto-generate a device_id if this is not specified.

initial_device_display_name: Option<&'a str>
A display name to assign to the newly-created device.

Ignored if device_id corresponds to a known device.

auth: Option<AuthData<'a>>
Additional authentication information for the user-interactive authentication API.

Note that this information is not used to define how the registered user should be authenticated, but is instead used to authenticate the register call itself. It should be left empty, or omitted, unless an earlier call returned an response with status code 401.

kind: RegistrationKind
Kind of account to register

Defaults to User if omitted.

inhibit_login: bool
If true, an access_token and device_id should not be returned from this call, therefore preventing an automatic login.

login_type: Option<&'a LoginType>
Login type used by Appservices.

Appservices can bypass the registration flows entirely by providing their token in the header and setting this login type to m.login.application_service.

Implementations

impl Request<'_>[src]

pub fn new() -> Self[src]

Creates a new Request with all parameters defaulted.