pub struct Request {
    pub client_secret: String,
    pub email: String,
    pub id_server: Option<String>,
    pub send_attempt: u64,
}
Data for a request to this API endpoint.

Fields

client_secret: String

Client-generated secret string used to protect this session.

email: String

The email address.

id_server: Option<String>

The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.

send_attempt: u64

Used to distinguish protocol level retries from requests to re-send the email.