Struct ruma_client_api::r0::account::IdentityServerInfo [−][src]
Additional authentication information for requestToken endpoints.
Fields
id_server: &'a strThe ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
id_access_token: &'a strAccess token previously registered with identity server.
Implementations