Struct ruma_client_api::r0::account::IncomingIdentityServerInfo [−][src]
‘Incoming’ variant of IdentityServerInfo.
Fields
id_server: StringThe ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
id_access_token: StringAccess token previously registered with identity server.