Struct ruma_client_api::r0::alias::get_alias::Response [−][src]
#[non_exhaustive]pub struct Response { pub room_id: RoomId, pub servers: Vec<ServerNameBox>, }
Data in the response from the get_alias API endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: RoomIdExpand description
The room ID for this room alias.
servers: Vec<ServerNameBox>Expand description
A list of servers that are aware of this room ID.
Implementations
impl Response[src]
impl Response[src]pub fn new(room_id: RoomId, servers: Vec<ServerNameBox>) -> Self[src]
pub fn new(room_id: RoomId, servers: Vec<ServerNameBox>) -> Self[src]Creates a new Response with the given room id and servers