Struct ruma_client_api::r0::backup::delete_backup_key_session::IncomingRequest [−][src]
This is supported on crate feature
unstable-pre-spec only.Expand description
‘Incoming’ variant of Request.
Fields
version: StringThe backup version. Must be the current backup.
room_id: RoomIdThe ID of the room that the requested key is for.
session_id: StringThe ID of the megolm session whose key is requested.