Struct ruma_client_api::r0::backup::delete_backup_key_sessions::Request [−][src]
This is supported on crate feature
unstable-pre-spec only.Expand description
Data for a request to the delete_backup_key_sessions API endpoint.
Delete keys from the backup for a given room.
Fields
version: &'a strThe backup version. Must be the current backup.
room_id: &'a RoomIdThe ID of the room that the requested key is for.
Implementations