Struct ruma_client_api::r0::backup::get_latest_backup::Response [−][src]
pub struct Response {
pub algorithm: BackupAlgorithm,
pub count: UInt,
pub etag: String,
pub version: String,
}This is supported on crate feature
unstable-pre-spec only.Expand description
Data in the response from the get_latest_backup API endpoint.
Fields
algorithm: BackupAlgorithmThe algorithm used for storing backups.
count: UIntThe number of keys stored in the backup.
etag: StringAn opaque string represetning stored keys in the backup. Clients can compare it with the etag value they received in the request of their last key storage request.
version: StringThe backup version. This is an opaque string.
Implementations