Enum ruma_client_api::r0::capabilities::RoomVersionStability [−][src]
#[non_exhaustive]
pub enum RoomVersionStability {
Stable,
Unstable,
// some variants omitted
}Expand description
The stability of a room version.
This type can hold an arbitrary string. To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Support for the given version is stable.
Support for the given version is unstable.
Implementations