[][src]Struct ruma_client_api::r0::capabilities::get_capabilities::Capabilities

#[non_exhaustive]pub struct Capabilities {
    pub change_password: ChangePasswordCapability,
    pub room_versions: RoomVersionsCapability,
    pub custom_capabilities: BTreeMap<String, JsonValue>,
}

Contains information about all the capabilities that the server supports.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
change_password: ChangePasswordCapability

Capability to indicate if the user can change their password.

room_versions: RoomVersionsCapability

The room versions the server supports.

custom_capabilities: BTreeMap<String, JsonValue>

Any other custom capabilities that the server supports outside of the specification, labeled using the Java package naming convention and stored as arbitrary JSON values.

Implementations

impl Capabilities[src]

pub fn new() -> Self[src]

Creates empty Capabilities.