Struct ruma_client_api::r0::capabilities::Capabilities [−][src]
pub struct Capabilities {
pub change_password: ChangePasswordCapability,
pub room_versions: RoomVersionsCapability,
// some fields omitted
}Expand description
Contains information about all the capabilities that the server supports.
Fields
change_password: ChangePasswordCapabilityCapability to indicate if the user can change their password.
room_versions: RoomVersionsCapabilityThe room versions the server supports.
Implementations
Returns the value of the given capability.
Prefer to use the public fields of Capabilities where possible; this method is meant to be
used for unsupported capabilities only.
Sets a capability to the given value.
Prefer to use the public fields of Capabilities where possible; this method is meant to be
used for unsupported capabilities only and does not allow setting arbitrary data for
supported ones.
pub fn iter(&self) -> CapabilitiesIter<'_>ⓘNotable traits for CapabilitiesIter<'a>
impl<'a> Iterator for CapabilitiesIter<'a> type Item = CapabilityRef<'a>;
pub fn iter(&self) -> CapabilitiesIter<'_>ⓘNotable traits for CapabilitiesIter<'a>
impl<'a> Iterator for CapabilitiesIter<'a> type Item = CapabilityRef<'a>;Returns an iterator over the capabilities.