Struct ruma_client_api::r0::capabilities::RoomVersionsCapability [−][src]
pub struct RoomVersionsCapability {
pub default: RoomVersionId,
pub available: BTreeMap<RoomVersionId, RoomVersionStability>,
}Expand description
Information about the m.room_versions capability
Fields
default: RoomVersionIdThe default room version the server is using for new rooms.
available: BTreeMap<RoomVersionId, RoomVersionStability>A detailed description of the room versions the server supports.
Implementations
pub fn new(
default: RoomVersionId,
available: BTreeMap<RoomVersionId, RoomVersionStability>
) -> Self
pub fn new(
default: RoomVersionId,
available: BTreeMap<RoomVersionId, RoomVersionStability>
) -> SelfCreates a new RoomVersionsCapability with the given default room version ID and room
version descriptions.
Returns whether all fields have their default value.