Struct ruma_client_api::r0::config::set_global_account_data::Request [−][src]
pub struct Request<'a> {
pub user_id: &'a UserId,
pub event_type: &'a str,
pub data: &'a RawJsonValue,
}Expand description
Data for a request to the set_global_account_data API endpoint.
Sets global account data.
Fields
user_id: &'a UserIdThe ID of the user to set account_data for.
The access token must be authorized to make requests for this user ID.
event_type: &'a strThe event type of the account_data to set.
Custom types should be namespaced to avoid clashes.
data: &'a RawJsonValueArbitrary JSON to store as config data.
To create a RawJsonValue, use serde_json::value::to_raw_value.
Implementations
Creates a new Request with the given data, event type and user ID.