[][src]Struct ruma_client_api::r0::contact::create_contact::ThreePidCredentials

pub struct ThreePidCredentials {
    pub client_secret: String,
    pub id_server: String,
    pub sid: String,
}

The third party credentials to associate with the account.

Fields

client_secret: String

The client secret used in the session with the identity server.

id_server: String

The identity server to use.

sid: String

The session identifier given by the identity server.