Struct ruma_client_api::r0::contact::get_contacts::ThirdPartyIdentifierInit [−][src]
pub struct ThirdPartyIdentifierInit {
pub address: String,
pub medium: Medium,
pub validated_at: MilliSecondsSinceUnixEpoch,
pub added_at: MilliSecondsSinceUnixEpoch,
}Expand description
Initial set of fields of ThirdPartyIdentifier.
This struct will not be updated even if additional fields are added to ThirdPartyIdentifier
in a new (non-breaking) release of the Matrix specification.
Fields
address: StringExpand description
The third party identifier address.
medium: MediumExpand description
The medium of third party identifier.
validated_at: MilliSecondsSinceUnixEpochExpand description
The time when the identifier was validated by the identity server.
added_at: MilliSecondsSinceUnixEpochExpand description
The time when the homeserver associated the third party identifier with the user.