Struct ruma_client_api::r0::contact::request_contact_verification_token::Request [−][src]
pub struct Request<'a> {
pub client_secret: &'a str,
pub email: &'a str,
pub send_attempt: UInt,
pub next_link: Option<&'a str>,
pub id_server: Option<&'a str>,
pub id_access_token: Option<&'a str>,
}Expand description
Data for a request to the request_contact_verification_token API endpoint.
Ask for a verification token for a given 3rd party ID.
Fields
client_secret: &'a strClient-generated secret string used to protect this session.
email: &'a strThe email address.
send_attempt: UIntUsed to distinguish protocol level retries from requests to re-send the email.
next_link: Option<&'a str>A URL for the identity server to redirect the user to after validation is completed.
id_server: Option<&'a str>The identity server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
id_access_token: Option<&'a str>An access token previously registered with the identity server.
Required if an id_server is supplied.
Implementations