pub struct Request {
pub event_id: EventId,
pub limit: u8,
pub room_id: RoomId,
}
Data for a request to this API endpoint.
The event to get context around.
The maximum number of events to return.
Defaults to 10 if not supplied.
The room to get events from.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
The future for the conversion.
Possible errors during conversion.
Consume the given value, beginning the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.