Enum ruma_client_api::r0::filter::UrlFilter [−][src]
pub enum UrlFilter {
EventsWithUrl,
EventsWithoutUrl,
}Expand description
Options for filtering based on the presence of a URL.
Variants
Includes only events with a url key in their content.
Excludes events with a url key in their content.