Struct ruma_client_api::r0::filter::FilterDefinition [−][src]
pub struct FilterDefinition<'a> {
pub event_fields: Option<&'a [String]>,
pub event_format: EventFormat,
pub presence: Filter<'a>,
pub account_data: Filter<'a>,
pub room: RoomFilter<'a>,
}Expand description
A filter definition
Fields
event_fields: Option<&'a [String]>List of event fields to include.
If this list is absent then all fields are included. The entries may include ‘.’ characters to indicate sub-fields. So [‘content.body’] will include the ‘body’ field of the ‘content’ object. A literal ‘.’ character in a field name may be escaped using a ’'. A server may include more fields than were requested.
event_format: EventFormatThe format to use for events.
‘client’ will return the events in a format suitable for clients. ‘federation’ will return the raw event as received over federation. The default is ‘client’.
presence: Filter<'a>The presence updates to include.
account_data: Filter<'a>The user account data that isn’t associated with rooms to include.
room: RoomFilter<'a>Filters to be applied to room data.
Implementations