Struct ruma_client_api::r0::filter::IncomingFilter [−][src]
pub struct IncomingFilter {
pub not_types: Vec<String>,
pub limit: Option<UInt>,
pub senders: Option<Vec<UserId>>,
pub types: Option<Vec<String>>,
pub not_senders: Vec<UserId>,
}Expand description
‘Incoming’ variant of Filter.
Fields
not_types: Vec<String>A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.
limit: Option<UInt>The maximum number of events to return.
senders: Option<Vec<UserId>>A list of senders IDs to include.
If this list is absent then all senders are included.
types: Option<Vec<String>>A list of event types to include.
If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.
not_senders: Vec<UserId>A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.
Implementations