Struct ruma_client_api::r0::filter::IncomingFilterDefinition [−][src]
pub struct IncomingFilterDefinition {
pub event_fields: Option<Vec<String>>,
pub event_format: EventFormat,
pub presence: IncomingFilter,
pub account_data: IncomingFilter,
pub room: IncomingRoomFilter,
}Expand description
‘Incoming’ variant of FilterDefinition.
Fields
event_fields: Option<Vec<String>>List of event fields to include.
If this list is absent then all fields are included. The entries may include ‘.’ characters to indicate sub-fields. So [‘content.body’] will include the ‘body’ field of the ‘content’ object. A literal ‘.’ character in a field name may be escaped using a ’'. A server may include more fields than were requested.
event_format: EventFormatThe format to use for events.
‘client’ will return the events in a format suitable for clients. ‘federation’ will return the raw event as received over federation. The default is ‘client’.
presence: IncomingFilterThe presence updates to include.
account_data: IncomingFilterThe user account data that isn’t associated with rooms to include.
room: IncomingRoomFilterFilters to be applied to room data.
Implementations