Struct ruma_client_api::r0::filter::IncomingRoomEventFilter [−][src]
pub struct IncomingRoomEventFilter {
pub not_types: Vec<String>,
pub not_rooms: Vec<String>,
pub limit: Option<UInt>,
pub rooms: Option<Vec<RoomId>>,
pub not_senders: Vec<UserId>,
pub senders: Option<Vec<UserId>>,
pub types: Option<Vec<String>>,
pub url_filter: Option<UrlFilter>,
pub lazy_load_options: LazyLoadOptions,
}Expand description
‘Incoming’ variant of RoomEventFilter.
Fields
not_types: Vec<String>A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.
not_rooms: Vec<String>A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter.
limit: Option<UInt>The maximum number of events to return.
rooms: Option<Vec<RoomId>>A list of room IDs to include.
If this list is absent then all rooms are included.
not_senders: Vec<UserId>A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.
senders: Option<Vec<UserId>>A list of senders IDs to include.
If this list is absent then all senders are included.
types: Option<Vec<String>>A list of event types to include.
If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.
url_filter: Option<UrlFilter>Controls whether to include events with a URL key in their content.
None: No filteringSome(EventsWithUrl): Only events with a URLSome(EventsWithoutUrl): Only events without a URL
lazy_load_options: LazyLoadOptionsOptions to control lazy-loading of membership events.
Defaults to LazyLoadOptions::Disabled.
Implementations