Struct ruma_client_api::r0::filter::RoomEventFilter [−][src]
pub struct RoomEventFilter<'a> {
pub not_types: &'a [String],
pub not_rooms: &'a [RoomId],
pub limit: Option<UInt>,
pub rooms: Option<&'a [RoomId]>,
pub not_senders: &'a [UserId],
pub senders: Option<&'a [UserId]>,
pub types: Option<&'a [String]>,
pub url_filter: Option<UrlFilter>,
pub lazy_load_options: LazyLoadOptions,
}Expand description
Filters to be applied to room events.
Fields
not_types: &'a [String]A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.
not_rooms: &'a [RoomId]A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter.
limit: Option<UInt>The maximum number of events to return.
rooms: Option<&'a [RoomId]>A list of room IDs to include.
If this list is absent then all rooms are included.
not_senders: &'a [UserId]A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.
senders: Option<&'a [UserId]>A list of senders IDs to include.
If this list is absent then all senders are included.
types: Option<&'a [String]>A list of event types to include.
If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.
url_filter: Option<UrlFilter>Controls whether to include events with a URL key in their content.
None: No filteringSome(EventsWithUrl): Only events with a URLSome(EventsWithoutUrl): Only events without a URL
lazy_load_options: LazyLoadOptionsOptions to control lazy-loading of membership events.
Defaults to LazyLoadOptions::Disabled.
Implementations