Struct ruma_client_api::r0::keys::get_key_changes::Request [−][src]
Data for a request to the get_key_changes API endpoint.
Gets a list of users who have updated their device identity keys since a previous sync token.
Fields
from: &'a strThe desired start point of the list.
Should be the next_batch field from a response to an earlier call to /sync.
to: &'a strThe desired end point of the list.
Should be the next_batch field from a recent call to /sync - typically the most recent such call.
Implementations