Struct ruma_client_api::r0::keys::get_key_changes::Response [−][src]
Data in the response from the get_key_changes API endpoint.
Fields
changed: Vec<UserId>The Matrix User IDs of all users who updated their device identity keys.
left: Vec<UserId>The Matrix User IDs of all users who may have left all the end-to-end encrypted rooms they previously shared with the user.
Implementations