Struct ruma_client_api::r0::keys::get_keys::Response [−][src]
pub struct Response {
pub failures: BTreeMap<String, JsonValue>,
pub device_keys: BTreeMap<UserId, BTreeMap<DeviceIdBox, DeviceKeys>>,
pub master_keys: BTreeMap<UserId, CrossSigningKey>,
pub self_signing_keys: BTreeMap<UserId, CrossSigningKey>,
pub user_signing_keys: BTreeMap<UserId, CrossSigningKey>,
}Expand description
Data in the response from the get_keys API endpoint.
Fields
failures: BTreeMap<String, JsonValue>If any remote homeservers could not be reached, they are recorded here. The names of the properties are the names of the unreachable servers.
device_keys: BTreeMap<UserId, BTreeMap<DeviceIdBox, DeviceKeys>>Information on the queried devices.
master_keys: BTreeMap<UserId, CrossSigningKey>unstable-pre-spec only.Information on the master cross-signing keys of the queried users.
self_signing_keys: BTreeMap<UserId, CrossSigningKey>unstable-pre-spec only.Information on the self-signing keys of the queried users.
user_signing_keys: BTreeMap<UserId, CrossSigningKey>unstable-pre-spec only.Information on the user-signing keys of the queried users.
Implementations