pub struct Response {
    pub file: Vec<u8>,
    pub content_type: String,
    pub content_disposition: String,
}
Data in the response from this API endpoint.

Fields

file: Vec<u8>

The content that was previously uploaded.

content_type: String

The content type of the file that was previously uploaded.

content_disposition: String

The name of the file that was previously uploaded, if set.