Enum ruma_client_api::r0::media::get_content_thumbnail::Method [−][src]
#[non_exhaustive]
pub enum Method {
Crop,
Scale,
// some variants omitted
}Expand description
The desired resizing method.
This type can hold an arbitrary string. To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Crop the original to produce the requested image dimensions.
Maintain the original aspect ratio of the source image.
Implementations