Struct ruma_client_api::r0::media::get_content_thumbnail::IncomingRequest [−][src]
pub struct IncomingRequest {
pub media_id: String,
pub server_name: Box<ServerName>,
pub method: Option<Method>,
pub width: UInt,
pub height: UInt,
pub allow_remote: bool,
}Expand description
‘Incoming’ variant of Request.
Fields
media_id: StringThe media ID from the mxc:// URI (the path component).
server_name: Box<ServerName>The server name from the mxc:// URI (the authoritory component).
method: Option<Method>The desired resizing method.
width: UIntThe desired width of the thumbnail. The actual thumbnail may not match the size specified.
height: UIntThe desired height of the thumbnail. The actual thumbnail may not match the size specified.
allow_remote: boolWhether to fetch media deemed remote.
Used to prevent routing loops. Defaults to true.