Struct ruma_client_api::r0::media::get_content_thumbnail::Request [−][src]
pub struct Request<'a> {
pub media_id: &'a str,
pub server_name: &'a ServerName,
pub method: Option<Method>,
pub width: UInt,
pub height: UInt,
pub allow_remote: bool,
}Expand description
Data for a request to the get_content_thumbnail API endpoint.
Get a thumbnail of content from the media store.
Fields
media_id: &'a strThe media ID from the mxc:// URI (the path component).
server_name: &'a ServerNameThe server name from the mxc:// URI (the authoritory component).
method: Option<Method>The desired resizing method.
width: UIntThe desired width of the thumbnail. The actual thumbnail may not match the size specified.
height: UIntThe desired height of the thumbnail. The actual thumbnail may not match the size specified.
allow_remote: boolWhether to fetch media deemed remote.
Used to prevent routing loops. Defaults to true.
Implementations
Creates a new Request with the given media ID, server name, desired thumbnail width and
desired thumbnail height.