Struct ruma_client_api::r0::membership::ThirdPartySigned [−][src]
pub struct ThirdPartySigned<'a> {
pub sender: &'a UserId,
pub mxid: &'a UserId,
pub token: &'a str,
pub signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>,
}Expand description
A signature of an m.third_party_invite token to prove that this user owns a third party
identity which has been invited to the room.
Fields
sender: &'a UserIdThe Matrix ID of the user who issued the invite.
mxid: &'a UserIdThe Matrix ID of the invitee.
token: &'a strThe state key of the m.third_party_invite event.
signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>A signatures object containing a signature of the entire signed object.
Implementations
pub fn new(
sender: &'a UserId,
mxid: &'a UserId,
token: &'a str,
signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>
) -> Self
pub fn new(
sender: &'a UserId,
mxid: &'a UserId,
token: &'a str,
signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>
) -> Self
Creates a new ThirdPartySigned from the given sender and invitee user IDs, state key token
and signatures.