Struct ruma_client_api::r0::message::get_message_events::Request [−][src]
pub struct Request<'a> {
pub room_id: &'a RoomId,
pub from: &'a str,
pub to: Option<&'a str>,
pub dir: Direction,
pub limit: UInt,
pub filter: Option<RoomEventFilter<'a>>,
}Expand description
Data for a request to the get_message_events API endpoint.
Get message events for a room.
Fields
room_id: &'a RoomIdThe room to get events from.
from: &'a strThe token to start returning events from.
This token can be obtained from a prev_batch token returned for each room by the sync API, or from a start or end token returned by a previous request to this endpoint.
to: Option<&'a str>The token to stop returning events at.
This token can be obtained from a prev_batch token returned for each room by the sync endpoint, or from a start or end token returned by a previous request to this endpoint.
dir: DirectionThe direction to return events from.
limit: UIntThe maximum number of events to return.
Default: 10.
filter: Option<RoomEventFilter<'a>>A RoomEventFilter to filter returned events with.
Implementations
Creates a new Request with the given parameters.
All other parameters will be defaulted.
Creates a new Request with the given room ID and from token, and dir set to Backward.