Struct ruma_client_api::r0::message::send_message_event::Request [−][src]
pub struct Request<'a> {
pub room_id: &'a RoomId,
pub event_type: &'a str,
pub txn_id: &'a str,
pub body: Raw<AnyMessageEventContent>,
}Expand description
Data for a request to the create_message_event API endpoint.
Send a message event to a room.
Fields
room_id: &'a RoomIdThe room to send the event to.
event_type: &'a strThe type of event to send.
txn_id: &'a strThe transaction ID for this event.
Clients should generate an ID unique across requests with the same access token; it will be used by the server to ensure idempotency of requests.
body: Raw<AnyMessageEventContent>The event content to send.
Implementations
Creates a new Request with the given room id, transaction id and event content.