Struct ruma_client_api::r0::profile::set_avatar_url::Request[][src]

pub struct Request<'a> {
    pub user_id: &'a UserId,
    pub avatar_url: Option<&'a MxcUri>,
}
Data for a request to the set_avatar_url API endpoint.

Set the avatar URL of the user.

Fields

user_id: &'a UserId

The user whose avatar URL will be set.

avatar_url: Option<&'a MxcUri>

The new avatar URL for the user.

None is used to unset the avatar.

If you activate the compat feature, this field being an empty string in JSON will give you None here.

Implementations

impl<'a> Request<'a>[src]

pub fn new(user_id: &'a UserId, avatar_url: Option<&'a MxcUri>) -> Self[src]

Creates a new Request with the given user ID and avatar URL.