[−][src]Module ruma_client_api::r0::push
Endpoints for push notifications.
Modules
Structs
| PushRule | A push rule |
| Pusher | Defines a pusher |
| PusherData | Information for the pusher implementation itself. |
Enums
| Action | This represents the different actions that should be taken when a rule is matched, and controls how notifications are delivered to the client. |
| PushCondition | A condition for a push rule |
| PushFormat | A special format that the homeserver should use when sending notifications to a Push Gateway. Currently, only "event_id_only" is supported as of Push Gateway API r0.1.1 |
| PusherKind | Which kind a pusher is |
| RuleKind | The kinds of push rules that are available |
| TweakKind | The different kinds of tweaks available |