Struct ruma_client_api::r0::push::delete_pushrule::Request[][src]

#[non_exhaustive]
pub struct Request<'a> { pub scope: &'a str, pub kind: RuleKind, pub rule_id: &'a str, }

Data for a request to the delete_pushrule API endpoint.

This endpoint removes the push rule defined in the path.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
scope: &'a str

The scope to delete from. ‘global’ to specify global rules.

kind: RuleKind

The kind of rule

rule_id: &'a str

The identifier for the rule.

Implementations

impl<'a> Request<'a>[src]

pub fn new(scope: &'a str, kind: RuleKind, rule_id: &'a str) -> Self[src]

Creates a new Request with the given scope, kind and rule ID.