Enum ruma_client_api::r0::push::PusherKind [−][src]
#[non_exhaustive]
pub enum PusherKind {
Http,
Email,
// some variants omitted
}Expand description
Which kind a pusher is.
This type can hold an arbitrary string. To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
A pusher that sends HTTP pokes.
A pusher that emails the user with unread notifications.
Implementations