Enum ruma_client_api::r0::push::RuleKind [−][src]
#[non_exhaustive]
pub enum RuleKind {
Override,
Underride,
Sender,
Room,
Content,
// some variants omitted
}Expand description
The kinds of push rules that are available.
This type can hold an arbitrary string. To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
User-configured rules that override all other kinds.
Lowest priority user-defined rules.
Sender-specific rules.
Room-specific rules.
Content-specific rules.
Implementations