Struct ruma_client_api::r0::push::get_notifications::IncomingRequest [−][src]
pub struct IncomingRequest {
pub from: Option<String>,
pub limit: Option<UInt>,
pub only: Option<String>,
}Expand description
‘Incoming’ variant of Request.
Fields
from: Option<String>Pagination token given to retrieve the next set of events.
limit: Option<UInt>Limit on the number of events to return in this request.
only: Option<String>Allows basic filtering of events returned. Supply “highlight” to return only events where the notification had the ‘highlight’ tweak set.