Struct ruma_client_api::r0::push::get_notifications::Response [−][src]
pub struct Response {
pub next_token: Option<String>,
pub notifications: Vec<Notification>,
}Expand description
Data in the response from the get_notifications API endpoint.
Fields
next_token: Option<String>The token to supply in the from param of the next /notifications request in order to request more events. If this is absent, there are no more results.
notifications: Vec<Notification>The list of events that triggered notifications.
Implementations
Creates a new Response with the given notifications.