Struct ruma_client_api::r0::push::set_pushrule::IncomingRequest [−][src]
pub struct IncomingRequest {
pub scope: String,
pub kind: RuleKind,
pub rule_id: String,
pub before: Option<String>,
pub after: Option<String>,
pub actions: Vec<Action>,
pub conditions: Vec<PushCondition>,
pub pattern: Option<String>,
}Expand description
‘Incoming’ variant of Request.
Fields
scope: StringThe scope to set the rule in. ‘global’ to specify global rules.
kind: RuleKindThe kind of rule
rule_id: StringThe identifier for the rule.
before: Option<String>Use ‘before’ with a rule_id as its value to make the new rule the next-most important rule with respect to the given user defined rule.
after: Option<String>This makes the new rule the next-less important rule relative to the given user defined rule.
actions: Vec<Action>The actions to perform when this rule is matched.
conditions: Vec<PushCondition>The conditions that must hold true for an event in order for a rule to be applied to an event. A rule with no conditions always matches. Only applicable to underride and override rules, empty Vec otherwise.
pattern: Option<String>The glob-style pattern to match against. Only applicable to content rules.