Struct ruma_client_api::r0::push::set_pushrule::Request [−][src]
pub struct Request<'a> {
pub scope: &'a str,
pub kind: RuleKind,
pub rule_id: &'a str,
pub before: Option<&'a str>,
pub after: Option<&'a str>,
pub actions: &'a [Action],
pub conditions: &'a [PushCondition],
pub pattern: Option<&'a str>,
}Expand description
Data for a request to the set_pushrule API endpoint.
This endpoint allows the creation, modification and deletion of pushers for this user ID.
Fields
scope: &'a strThe scope to set the rule in. ‘global’ to specify global rules.
kind: RuleKindThe kind of rule
rule_id: &'a strThe identifier for the rule.
before: Option<&'a str>Use ‘before’ with a rule_id as its value to make the new rule the next-most important rule with respect to the given user defined rule.
after: Option<&'a str>This makes the new rule the next-less important rule relative to the given user defined rule.
actions: &'a [Action]The actions to perform when this rule is matched.
conditions: &'a [PushCondition]The conditions that must hold true for an event in order for a rule to be applied to an event. A rule with no conditions always matches. Only applicable to underride and override rules, empty Vec otherwise.
pattern: Option<&'a str>The glob-style pattern to match against. Only applicable to content rules.
Implementations