Struct ruma_client_api::r0::push::set_pushrule_actions::Request [−][src]
pub struct Request<'a> {
pub scope: &'a str,
pub kind: RuleKind,
pub rule_id: &'a str,
pub actions: Vec<Action>,
}Expand description
Data for a request to the set_pushrule_actions API endpoint.
This endpoint allows clients to change the actions of a push rule. This can be used to change the actions of builtin rules.
Fields
scope: &'a strThe scope to fetch a rule from. ‘global’ to specify global rules.
kind: RuleKindThe kind of rule
rule_id: &'a strThe identifier for the rule.
actions: Vec<Action>The actions to perform for this rule
Implementations