Struct ruma_client_api::r0::redact::redact_event::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub room_id: &'a RoomId, pub event_id: &'a EventId, pub txn_id: &'a str, pub reason: Option<&'a str>, }
Data for a request to the redact_event API endpoint.
Redact an event, stripping all information not critical to the event graph integrity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: &'a RoomIdExpand description
The ID of the room of the event to redact.
event_id: &'a EventIdExpand description
The ID of the event to redact.
txn_id: &'a strExpand description
The transaction ID for this event.
Clients should generate a unique ID; it will be used by the server to ensure idempotency of requests.
reason: Option<&'a str>Expand description
The reason for the redaction.
Implementations