Enum ruma_client_api::r0::room::Visibility [−][src]
#[non_exhaustive]
pub enum Visibility {
Public,
Private,
// some variants omitted
}Expand description
Whether or not a newly created room will be listed in the room directory.
This type can hold an arbitrary string. To check for formats that are not available as a
documented variant here, use its string representation, obtained through .as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Indicates that the room will be shown in the published room list.
Indicates that the room will not be shown in the published room list.
Implementations