[−][src]Struct ruma_client_api::r0::send::send_message_event::IncomingRequest
'Incoming' variant of Request.
Fields
room_id: RoomIdThe room to send the event to.
event_type: EventTypeThe type of event to send.
txn_id: StringThe transaction ID for this event.
Clients should generate an ID unique across requests with the same access token; it will be used by the server to ensure idempotency of requests.
data: EventResult<MessageEventContent>The event's content.