Struct ruma_client_api::r0::send::send_message_event::Request
source · pub struct Request {
pub room_id: RoomId,
pub event_type: EventType,
pub txn_id: String,
pub data: MessageEventContent,
}Expand description
Data for a request to this API endpoint.
Fields
room_id: RoomIdThe room to send the event to.
event_type: EventTypeThe type of event to send.
txn_id: StringThe transaction ID for this event.
Clients should generate an ID unique across requests with the same access token; it will be used by the server to ensure idempotency of requests.
data: MessageEventContentThe event’s content.