[][src]Struct ruma_client_api::r0::sync::get_message_events::Request

pub struct Request {
    pub room_id: RoomId,
    pub from: String,
    pub to: Option<String>,
    pub dir: Direction,
    pub limit: Option<u64>,
}

Data for a request to this API endpoint.

Fields

room_id: RoomId

The room to get events from.

from: String

The token to start returning events from.

This token can be obtained from a prev_batch token returned for each room by the sync API, or from a start or end token returned by a previous request to this endpoint.

to: Option<String>

The token to stop returning events at.

This token can be obtained from a prev_batch token returned for each room by the sync endpoint, or from a start or end token returned by a previous request to this endpoint.

dir: Direction

The direction to return events from.

limit: Option<u64>

The maximum number of events to return.

Default: 10.