Struct ruma_client_api::r0::sync::sync_events::DeviceLists [−][src]
Information on E2E device udpates.
Fields
changed: Vec<UserId>Expand description
List of users who have updated their device identity keys or who now share an encrypted room with the client since the previous sync
left: Vec<UserId>Expand description
List of users who no longer share encrypted rooms since the previous sync response.
Implementations
impl DeviceLists[src]
impl DeviceLists[src]Trait Implementations
impl Clone for DeviceLists[src]
impl Clone for DeviceLists[src]fn clone(&self) -> DeviceLists[src]
fn clone(&self) -> DeviceLists[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for DeviceLists[src]
impl Debug for DeviceLists[src]impl Default for DeviceLists[src]
impl Default for DeviceLists[src]impl<'de> Deserialize<'de> for DeviceLists[src]
impl<'de> Deserialize<'de> for DeviceLists[src]fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
impl Serialize for DeviceLists[src]
impl Serialize for DeviceLists[src]Auto Trait Implementations
impl RefUnwindSafe for DeviceLists
impl Send for DeviceLists
impl Sync for DeviceLists
impl Unpin for DeviceLists
impl UnwindSafe for DeviceLists