[−][src]Struct ruma_client_api::r0::sync::sync_events::IncomingJoinedRoom
'Incoming' variant of JoinedRoom.
Fields
summary: RoomSummaryInformation about the room which clients may need to correctly render it to users.
unread_notifications: UnreadNotificationsCountCounts of unread notifications for this room.
timeline: IncomingTimelineThe timeline of messages and state changes in the room.
state: IncomingStateUpdates to the state, between the time indicated by the since parameter, and the start
of the timeline (or all state up to the start of the timeline, if since is not
given, or full_state is true).
account_data: IncomingAccountDataThe private data that this user has attached to this room.
ephemeral: IncomingEphemeralThe ephemeral events in the room that aren't recorded in the timeline or state of the room. e.g. typing.