Struct ruma_client_api::r0::sync::sync_events::InvitedRoom [−][src]
pub struct InvitedRoom {
pub invite_state: InviteState,
}Expand description
Updates to the rooms that the user has been invited to.
Fields
invite_state: InviteStateThe state of a room that the user has been invited to.
Implementations