Struct ruma_client_api::r0::sync::sync_events::RoomSummary [−][src]
#[non_exhaustive]pub struct RoomSummary { pub heroes: Vec<String>, pub joined_member_count: Option<UInt>, pub invited_member_count: Option<UInt>, }
Information about room for rendering to clients.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.heroes: Vec<String>Users which can be used to generate a room name if the room does not have one. Required if room name or canonical aliases are not set or empty.
joined_member_count: Option<UInt>Number of users whose membership status is join.
Required if field has changed since last sync; otherwise, it may be
omitted.
invited_member_count: Option<UInt>Number of users whose membership status is invite.
Required if field has changed since last sync; otherwise, it may be
omitted.
Implementations
impl RoomSummary[src]
pub fn new() -> Self[src]
Creates an empty RoomSummary.
pub fn is_empty(&self) -> bool[src]
Returns true if there are no room summary updates.