Struct ruma_client_api::r0::sync::sync_events::Rooms
source · [−]pub struct Rooms {
pub leave: BTreeMap<RoomId, LeftRoom>,
pub join: BTreeMap<RoomId, JoinedRoom>,
pub invite: BTreeMap<RoomId, InvitedRoom>,
pub knock: BTreeMap<RoomId, KnockedRoom>,
}Expand description
Updates to rooms.
Fields
leave: BTreeMap<RoomId, LeftRoom>The rooms that the user has left or been banned from.
join: BTreeMap<RoomId, JoinedRoom>The rooms that the user has joined.
invite: BTreeMap<RoomId, InvitedRoom>The rooms that the user has been invited to.
knock: BTreeMap<RoomId, KnockedRoom>This is supported on crate feature
unstable-pre-spec only.The rooms that the user has knocked on.
Implementations