Struct ruma_client_api::r0::sync::sync_events::UnreadNotificationsCount [−][src]
pub struct UnreadNotificationsCount {
pub highlight_count: Option<UInt>,
pub notification_count: Option<UInt>,
}Expand description
Unread notifications count.
Fields
highlight_count: Option<UInt>The number of unread notifications for this room with the highlight flag set.
notification_count: Option<UInt>The total number of unread notifications for this room.
Implementations