[−][src]Module ruma_client_api::r0::thirdparty
Endpoints for third party lookups
Modules
| get_location_for_protocol | |
| get_location_for_room_alias | |
| get_protocol | |
| get_protocols | |
| get_user_for_protocol | |
| get_user_for_user_id |
Structs
| FieldType | A type definition for a field used to identify third party users or locations. |
| Location | A third party network location. |
| Protocol | Metadata about a third party protocol. |
| ProtocolInstance | Metadata about an instance of a third party protocol. |
| User | A third party network user. |
Enums
| Medium | The medium of a third party identifier. |