Struct ruma_client_api::r0::thirdparty::get_location_for_protocol::IncomingRequest [−][src]
‘Incoming’ variant of Request.
Fields
protocol: StringThe protocol used to communicate to the third party network.
fields: BTreeMap<String, String>One or more custom fields to help identify the third party location.