Struct ruma_client_api::r0::thirdparty::get_location_for_protocol::Request [−][src]
Data for a request to the get_location_for_protocol API endpoint.
Fetches third party locations for a protocol.
Fields
protocol: &'a strThe protocol used to communicate to the third party network.
fields: BTreeMap<String, String>One or more custom fields to help identify the third party location.
Implementations