Struct ruma_client_api::r0::thirdparty::get_user_for_protocol::IncomingRequest [−][src]
‘Incoming’ variant of Request.
Fields
protocol: StringThe protocol used to communicate to the third party network.
fields: BTreeMap<String, String>One or more custom fields that are passed to the AS to help identify the user.