Enum ruma_client_api::r0::uiaa::AuthData [−][src]
pub enum AuthData<'a> {
DirectRequest {
kind: &'a str,
session: Option<&'a str>,
auth_parameters: BTreeMap<String, JsonValue>,
},
FallbackAcknowledgement {
session: &'a str,
},
}Expand description
Additional authentication information for the user-interactive authentication API.
Variants
Used for sending UIAA authentication requests to the homeserver directly from the client.
Fields of DirectRequest
Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.
Fields of FallbackAcknowledgement
session: &'a strThe value of the session key given by the homeserver.
Implementations
Creates a new AuthData::DirectRequest with the given login type.
Creates a new AuthData::FallbackAcknowledgement with the given session key.