Enum ruma_client_api::r0::uiaa::IncomingAuthData[][src]

#[non_exhaustive]
pub enum IncomingAuthData {
    Password(IncomingPassword),
    ReCaptcha(IncomingReCaptcha),
    Token(IncomingToken),
    OAuth2(IncomingOAuth2),
    EmailIdentity(IncomingEmailIdentity),
    Msisdn(IncomingMsisdn),
    Dummy(IncomingDummy),
    FallbackAcknowledgement(IncomingFallbackAcknowledgement),
    // some variants omitted
}
‘Incoming’ variant of AuthData.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

Password-based authentication (m.login.password).

Tuple Fields of Password

0: IncomingPassword

Google ReCaptcha 2.0 authentication (m.login.recaptcha).

Tuple Fields of ReCaptcha

0: IncomingReCaptcha

Token-based authentication (m.login.token).

Tuple Fields of Token

0: IncomingToken

OAuth2-based authentication (m.login.oauth2).

Tuple Fields of OAuth2

0: IncomingOAuth2
EmailIdentity(IncomingEmailIdentity)

Email-based authentication (m.login.email.identity).

Tuple Fields of EmailIdentity

0: IncomingEmailIdentity

Phone number-based authentication (m.login.msisdn).

Tuple Fields of Msisdn

0: IncomingMsisdn

Dummy authentication (m.login.dummy).

Tuple Fields of Dummy

0: IncomingDummy
FallbackAcknowledgement(IncomingFallbackAcknowledgement)

Fallback acknowledgement.

Tuple Fields of FallbackAcknowledgement

0: IncomingFallbackAcknowledgement

Implementations

Returns the value of the type field, if it exists.

Returns the value of the session field, if it exists.