Struct ruma_client_api::r0::uiaa::Password [−][src]
pub struct Password<'a> {
pub identifier: UserIdentifier<'a>,
pub password: &'a str,
pub session: Option<&'a str>,
}Expand description
Data for password-based UIAA flow.
See the spec for how to use this.
Fields
identifier: UserIdentifier<'a>One of the user’s identifiers.
password: &'a strThe plaintext password.
session: Option<&'a str>The value of the session key given by the homeserver, if any.
Implementations
Creates a new Password with the given identifier and password.