Struct ruma_client_api::r0::user_directory::search_users::Response [−][src]
Data in the response from the search_users API endpoint.
Fields
results: Vec<User>Ordered by rank and then whether or not profile info is available.
limited: boolIndicates if the result list has been truncated by the limit.
Implementations