Struct ruma_client_api::r0::user_directory::search_users::User
source · [−]pub struct User {
pub user_id: UserId,
pub display_name: Option<String>,
pub avatar_url: Option<MxcUri>,
}Expand description
User data as result of a search.
Fields
user_id: UserIdThe user’s matrix user ID.
display_name: Option<String>The display name of the user, if one exists.
avatar_url: Option<MxcUri>The avatar url, as an MXC, if one exists.
If you activate the compat feature, this field being an empty string in JSON will give
you None here.
Implementations