pub struct Request<'a> {
pub room_id: &'a RoomId,
pub fully_read: Option<&'a EventId>,
pub read_receipt: Option<&'a EventId>,
pub private_read_receipt: Option<&'a EventId>,
}Available on crate features
client or server only.Expand description
Data for a request to the set_read_marker API endpoint.
Sets the position of the read marker for a given room, and optionally the read receipt’s location.
Fields
room_id: &'a RoomIdThe room ID to set the read marker in for the user.
fully_read: Option<&'a EventId>Available on crate feature
unstable-msc2285 only.The event ID the fully-read marker should be located at.
The event MUST belong to the room.
This is equivalent to calling the create_receipt endpoint with a
ReceiptType::FullyRead.
Without the unstable-msc2285 feature, this field is required.
read_receipt: Option<&'a EventId>The event ID to set the public read receipt location at.
This is equivalent to calling the create_receipt endpoint with a
ReceiptType::Read.
private_read_receipt: Option<&'a EventId>Available on crate feature
unstable-msc2285 only.The event ID to set the private read receipt location at.
This is equivalent to calling the create_receipt endpoint with a
ReceiptType::ReadPrivate.
Implementations