pub struct Request<'a> {
pub room_id: &'a RoomId,
pub event_id: &'a EventId,
pub from: Option<&'a str>,
pub to: Option<&'a str>,
pub limit: Option<UInt>,
}client or server only.Expand description
Data for a request to the get_relating_events API endpoint.
Get the child events for a given parent event.
Fields
room_id: &'a RoomIdThe ID of the room containing the parent event.
event_id: &'a EventIdThe ID of the parent event whose child events are to be returned.
from: Option<&'a str>The pagination token to start returning results from.
If None, results start at the most recent topological event known to the server.
Can be a next_batch token from a previous call, or a returned start token from
/messages or a next_batch token from /sync.
Note that when paginating the from token should be “after” the to token in
terms of topological ordering, because it is only possible to paginate “backwards”
through events, starting at from.
to: Option<&'a str>The pagination token to stop returning results at.
If None, results continue up to limit or until there are no more events.
Like from, this can be a previous token from a prior call to this endpoint
or from /messages or /sync.
limit: Option<UInt>The maximum number of results to return in a single chunk.
The server can and should apply a maximum value to this parameter to avoid large responses.
Similarly, the server should apply a default value when not supplied.
Implementations