Struct ruma_client_api::relations::get_relating_events::v1::Response
source · pub struct Response {
pub chunk: Vec<Raw<AnyMessageLikeEvent>>,
pub next_batch: Option<String>,
pub prev_batch: Option<String>,
}Available on crate features
client or server only.Expand description
Response type for the get_relating_events endpoint.
Fields
chunk: Vec<Raw<AnyMessageLikeEvent>>The paginated child events which point to the parent.
The events returned are ordered topologically, most-recent first.
If no events are related to the parent or the pagination yields no results, an
empty chunk is returned.
next_batch: Option<String>An opaque string representing a pagination token.
If this is None, there are no more results to fetch and the client should stop
paginating.
prev_batch: Option<String>An opaque string representing a pagination token.
If this is None, this is the start of the result set, i.e. this is the first
batch/page.
Implementations