Struct ruma_client_api::room::create_room::v3::CreationContent
source · pub struct CreationContent {
pub federate: bool,
pub predecessor: Option<PreviousRoom>,
pub room_type: Option<RoomType>,
}Available on crate features
client or server only.Expand description
Extra options to be added to the m.room.create event.
This is the same as the event content struct for m.room.create, but without some fields
that servers are supposed to ignore.
Fields
federate: boolWhether users on other servers can join this room.
Defaults to true if key does not exist.
predecessor: Option<PreviousRoom>A reference to the room this room replaces, if the previous room was upgraded.
room_type: Option<RoomType>The room type.
This is currently only used for spaces.
Implementations
sourceimpl CreationContent
impl CreationContent
sourcepub fn into_event_content(
self,
creator: OwnedUserId,
room_version: RoomVersionId
) -> RoomCreateEventContent
pub fn into_event_content(
self,
creator: OwnedUserId,
room_version: RoomVersionId
) -> RoomCreateEventContent
Given a CreationContent and the other fields that a homeserver has to fill, construct
a RoomCreateEventContent.