Enum ruma_client_api::search::search_events::v3::GroupingKey
source · #[non_exhaustive]
pub enum GroupingKey {
RoomId,
Sender,
// some variants omitted
}Available on crate features
client or server only.Expand description
The key within events to use for this grouping.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations