ruma_client_api::session::login::v3

Enum IncomingLoginInfo

pub enum IncomingLoginInfo {
    Password(IncomingPassword),
    Token(IncomingToken),
    ApplicationService(IncomingApplicationService),
    // some variants omitted
}
Available on crate features client or server only.
‘Incoming’ variant of LoginInfo.

Variants



Password(IncomingPassword)

An identifier and password are supplied to authenticate.



Token(IncomingToken)

Token-based login.



ApplicationService(IncomingApplicationService)

Application Service-specific login.

Implementations

Source

impl IncomingLoginInfo

pub fn new(login_type: &str, data: JsonObject) -> Result<Self>

Creates a new IncomingLoginInfo with the given login_type string, session and data.

Prefer to use the public variants of IncomingLoginInfo where possible; this constructor is meant be used for unsupported authentication mechanisms only and does not allow setting arbitrary data for supported ones.

Errors

Returns an error if the login_type is known and serialization of data to the corresponding IncomingLoginInfo variant fails.

pub fn to_outgoing(&self) -> LoginInfo<'_>

Convert IncomingLoginInfo to LoginInfo.