Available on crate features
client or server only.Expand description
/v3/ (spec)
Structs
Data for a request to the
logout API endpoint.Data in the response from the
logout API endpoint.Constants
Metadata for the
logout API endpoint.Type Definitions
Convenience type alias for Request, for consistency with other IncomingRequest types.
Convenience type alias for Response, for consistency with other IncomingResponse types.