Struct ruma_client_api::session::refresh_token::v3::Response
source · pub struct Response {
pub access_token: String,
pub refresh_token: Option<String>,
pub expires_in_ms: Option<Duration>,
}Available on crate features
client or server only.Expand description
Response type for the refresh endpoint.
Fields
access_token: StringThe new access token to use.
refresh_token: Option<String>The new refresh token to use when the access token needs to be refreshed again.
If this is None, the old refresh token can be re-used.
expires_in_ms: Option<Duration>The lifetime of the access token, in milliseconds.
If this is None, the client can assume that the access token will not expire.
Implementations