Module ruma_client_api::space
source · Available on crate features
client or server only.Expand description
Endpoints for spaces.
See the Matrix specification for more details about spaces.
Modules
GET /_matrix/client/*/rooms/{roomId}/hierarchyStructs
A chunk of a space hierarchy response, describing one room.
Initial set of mandatory fields of
SpaceHierarchyRoomsChunk.Enums
The rule used for users wishing to join a room.