ruma_client_api::space::get_hierarchy::v1

Struct IncomingRequest

pub struct IncomingRequest {
    pub room_id: OwnedRoomId,
    pub from: Option<String>,
    pub limit: Option<UInt>,
    pub max_depth: Option<UInt>,
    pub suggested_only: bool,
}
Available on crate features client or server only.
‘Incoming’ variant of Request.

Fields

room_id: OwnedRoomId

The room ID of the space to get a hierarchy for.

from: Option<String>

A pagination token from a previous result.

If specified, max_depth and suggested_only cannot be changed from the first request.

limit: Option<UInt>

The maximum number of rooms to include per response.

max_depth: Option<UInt>

How far to go into the space.

When reached, no further child rooms will be returned.

suggested_only: bool

Whether or not the server should only consider suggested rooms.

Suggested rooms are annotated in their m.space.child event contents.

Defaults to false.