Struct ruma_client_api::space::SpaceHierarchyRoomsChunk
source · pub struct SpaceHierarchyRoomsChunk {
pub canonical_alias: Option<OwnedRoomAliasId>,
pub name: Option<String>,
pub num_joined_members: UInt,
pub room_id: OwnedRoomId,
pub topic: Option<String>,
pub world_readable: bool,
pub guest_can_join: bool,
pub avatar_url: Option<OwnedMxcUri>,
pub join_rule: SpaceRoomJoinRule,
pub room_type: Option<RoomType>,
pub children_state: Vec<Raw<HierarchySpaceChildEvent>>,
}client or server only.Expand description
A chunk of a space hierarchy response, describing one room.
To create an instance of this type, first create a SpaceHierarchyRoomsChunkInit and convert it
via SpaceHierarchyRoomsChunk::from / .into().
Fields
canonical_alias: Option<OwnedRoomAliasId>The canonical alias of the room, if any.
name: Option<String>The name of the room, if any.
num_joined_members: UIntThe number of members joined to the room.
room_id: OwnedRoomIdThe ID of the room.
topic: Option<String>The topic of the room, if any.
world_readable: boolWhether the room may be viewed by guest users without joining.
guest_can_join: boolWhether guest users may join the room and participate in it.
If they can, they will be subject to ordinary power level rules like any other user.
avatar_url: Option<OwnedMxcUri>The URL for the room’s avatar, if one is set.
If you activate the compat feature, this field being an empty string in JSON will result
in None here during deserialization.
join_rule: SpaceRoomJoinRuleThe join rule of the room.
room_type: Option<RoomType>The type of room from m.room.create, if any.
children_state: Vec<Raw<HierarchySpaceChildEvent>>The stripped m.space.child events of the space-room.
If the room is not a space-room, this should be empty.