ruma_client_api::state::send_state_event::v3

Struct IncomingRequest

pub struct IncomingRequest {
    pub room_id: OwnedRoomId,
    pub event_type: StateEventType,
    pub state_key: String,
    pub body: Raw<AnyStateEventContent>,
    pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
}
Available on crate features client or server only.
‘Incoming’ variant of Request.

Fields

room_id: OwnedRoomId

The room to set the state in.

event_type: StateEventType

The type of event to send.

state_key: String

The state_key for the state to send.

body: Raw<AnyStateEventContent>

The event content to send.

timestamp: Option<MilliSecondsSinceUnixEpoch>

Timestamp to use for the origin_server_ts of the event.

This is called timestamp massaging and can only be used by Appservices.

Note that this does not change the position of the event in the timeline.