ruma_client_api::state::send_state_event::v3

Struct Request

pub struct Request<'a> {
    pub room_id: &'a RoomId,
    pub event_type: StateEventType,
    pub state_key: &'a str,
    pub body: Raw<AnyStateEventContent>,
    pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
}
Available on crate features client or server only.
Data for a request to the send_state_event API endpoint.

Send a state event to a room associated with a given state key.

Fields

room_id: &'a RoomId

The room to set the state in.

event_type: StateEventType

The type of event to send.

state_key: &'a str

The state_key for the state to send.

body: Raw<AnyStateEventContent>

The event content to send.

timestamp: Option<MilliSecondsSinceUnixEpoch>

Timestamp to use for the origin_server_ts of the event.

This is called timestamp massaging and can only be used by Appservices.

Note that this does not change the position of the event in the timeline.

Implementations

Source

impl<'a> Request<'a>

pub fn new<T, K>( room_id: &'a RoomId, state_key: &'a K, content: &'a T, ) -> Result<Self>
where T: StateEventContent, T::StateKey: Borrow<K>, K: AsRef<str> + ?Sized,

Creates a new Request with the given room id, state key and event content.

Errors

Since Request stores the request body in serialized form, this function can fail if Ts Serialize implementation can fail.

pub fn new_raw( room_id: &'a RoomId, event_type: StateEventType, state_key: &'a str, body: Raw<AnyStateEventContent>, ) -> Self

Creates a new Request with the given room id, event type, state key and raw event content.