pub struct JoinedRoom {
pub summary: RoomSummary,
pub unread_notifications: UnreadNotificationsCount,
pub timeline: Timeline,
pub state: State,
pub account_data: RoomAccountData,
pub ephemeral: Ephemeral,
pub unread_count: Option<UInt>,
}Available on crate features
client or server only.Expand description
Updates to joined rooms.
Fields
summary: RoomSummaryInformation about the room which clients may need to correctly render it to users.
unread_notifications: UnreadNotificationsCountCounts of unread notifications for this room.
timeline: TimelineThe timeline of messages and state changes in the room.
state: StateUpdates to the state, between the time indicated by the since parameter, and the
start of the timeline (or all state up to the start of the timeline, if
since is not given, or full_state is true).
account_data: RoomAccountDataThe private data that this user has attached to this room.
ephemeral: EphemeralThe ephemeral events in the room that aren’t recorded in the timeline or state of the room.
unread_count: Option<UInt>Available on crate feature
unstable-msc2654 only.The number of unread events since the latest read receipt.
This uses the unstable prefix in MSC2654.
Implementations