Struct ruma_client_api::sync::sync_events::v3::Response
source · pub struct Response {
pub next_batch: String,
pub rooms: Rooms,
pub presence: Presence,
pub account_data: GlobalAccountData,
pub to_device: ToDevice,
pub device_lists: DeviceLists,
pub device_one_time_keys_count: BTreeMap<DeviceKeyAlgorithm, UInt>,
pub device_unused_fallback_key_types: Option<Vec<DeviceKeyAlgorithm>>,
}Available on crate features
client or server only.Expand description
Response type for the sync endpoint.
Fields
next_batch: StringThe batch token to supply in the since param of the next /sync request.
rooms: RoomsUpdates to rooms.
presence: PresenceUpdates to the presence status of other users.
account_data: GlobalAccountDataThe global private data created by this user.
to_device: ToDeviceMessages sent directly between devices.
device_lists: DeviceListsInformation on E2E device updates.
Only present on an incremental sync.
device_one_time_keys_count: BTreeMap<DeviceKeyAlgorithm, UInt>For each key algorithm, the number of unclaimed one-time keys currently held on the server for a device.
device_unused_fallback_key_types: Option<Vec<DeviceKeyAlgorithm>>For each key algorithm, the number of unclaimed one-time keys currently held on the server for a device.
The presence of this field indicates that the server supports fallback keys.
Implementations