Struct ruma_client_api::sync::sync_events::v3::RoomSummary
source · pub struct RoomSummary {
pub heroes: Vec<String>,
pub joined_member_count: Option<UInt>,
pub invited_member_count: Option<UInt>,
}Available on crate features
client or server only.Expand description
Information about room for rendering to clients.
Fields
heroes: Vec<String>Users which can be used to generate a room name if the room does not have one.
Required if room name or canonical aliases are not set or empty.
joined_member_count: Option<UInt>Number of users whose membership status is join.
Required if field has changed since last sync; otherwise, it may be
omitted.
invited_member_count: Option<UInt>Number of users whose membership status is invite.
Required if field has changed since last sync; otherwise, it may be
omitted.
Implementations