Struct ruma_client_api::sync::sync_events::v3::Timeline
source · pub struct Timeline {
pub limited: bool,
pub prev_batch: Option<String>,
pub events: Vec<Raw<AnySyncTimelineEvent>>,
}Available on crate features
client or server only.Expand description
Events in the room.
Fields
limited: boolTrue if the number of events returned was limited by the limit on the filter.
Default to false.
prev_batch: Option<String>A token that can be supplied to to the from parameter of the
/rooms/{roomId}/messages endpoint.
events: Vec<Raw<AnySyncTimelineEvent>>A list of events.
Implementations