Module ruma_client_api::sync::sync_events::v4
source · [−]Available on (crate features
client or server) and crate feature unstable-msc3575 only.Expand description
Structs
Account-data extension response data.
Account-data extension configuration.
E2EE extension response data.
E2EE extension configuration.
Extensions specific response data.
Sliding-Sync extension configuration.
‘Incoming’ variant of Request.
Data for a request to the
sync API endpoint.Data in the response from the
sync API endpoint.The RoomSubscriptions of the SlidingSync Request
Updates to joined rooms.
Updates to joined rooms.
Updates to joined rooms.
Sliding Sync Request for each list.
Filter for a sliding sync list, set at request.
To-device messages extension response.
To-device messages extension configuration.
Enums
Operation applied to the specific SlidingSyncList
Constants
Metadata for the
sync API endpoint.Type Definitions
Convenience type alias for Response, for consistency with other IncomingResponse types.