Enum ruma_client_api::sync::sync_events::v4::SlidingOp
source · pub enum SlidingOp {
Sync,
Insert,
Delete,
Invalidate,
}Available on (crate features
client or server) and crate feature unstable-msc3575 only.Expand description
Operation applied to the specific SlidingSyncList
Variants
Sync
Full reset of the given window.
Insert
Insert an item at the given point, moves all following entry by one to the next Empty or Invalid field.
Delete
Drop this entry, moves all following entry up by one.
Invalidate
Mark these as invaldiated.