Struct ruma_client_api::sync::sync_events::v4::Request
source · pub struct Request {
pub pos: Option<String>,
pub delta_token: Option<String>,
pub txn_id: Option<String>,
pub timeout: Option<Duration>,
pub lists: BTreeMap<String, SyncRequestList>,
pub room_subscriptions: BTreeMap<OwnedRoomId, RoomSubscription>,
pub unsubscribe_rooms: Vec<OwnedRoomId>,
pub extensions: ExtensionsConfig,
}client or server) and crate feature unstable-msc3575 only.Expand description
Request type for the sync endpoint.
Fields
pos: Option<String>A point in time to continue a sync from.
Should be a token from the pos field of a previous /sync
response.
delta_token: Option<String>The delta token to store for session recovery.
The delta token is a future bandwidth optimisation to resume from an earlier session. If you received a delta token in your last response you can persist and it when establishing a new sessions to “resume” from the last state and not resend information you had stored. If you send a delta token, the server expects you to have stored the last state, if there is no delta token present the server will resend all information necessary to calculate the state.
Please consult “Bandwidth optimisations for persistent clients” of the MSC for further details, expectations of the implementation and limitations to consider before implementing this.
txn_id: Option<String>Allows clients to know what request params reached the server, functionally similar to txn IDs on /send for events.
timeout: Option<Duration>The maximum time to poll before responding to this request.
lists: BTreeMap<String, SyncRequestList>The list configurations of rooms we are interested in mapped by name.
room_subscriptions: BTreeMap<OwnedRoomId, RoomSubscription>Specific rooms and event types that we want to receive events from.
unsubscribe_rooms: Vec<OwnedRoomId>Specific rooms we no longer want to receive events from.
extensions: ExtensionsConfigExtensions API.
Implementations