Struct ruma_client_api::sync::sync_events::v4::RoomSubscription
source · pub struct RoomSubscription {
pub required_state: Vec<(TimelineEventType, String)>,
pub timeline_limit: Option<UInt>,
}Available on (crate features
client or server) and crate feature unstable-msc3575 only.Expand description
Configuration for room subscription
Fields
required_state: Vec<(TimelineEventType, String)>Required state for each room returned. An array of event type and state key tuples.
Note that elements of this array are NOT sticky so they must be specified in full when they are changed. Sticky.
timeline_limit: Option<UInt>The maximum number of timeline events to return per room. Sticky.