#[non_exhaustive]
pub enum AuthData {
    Password(Password),
    ReCaptcha(ReCaptcha),
    EmailIdentity(EmailIdentity),
    Msisdn(Msisdn),
    Dummy(Dummy),
    RegistrationToken(RegistrationToken),
    FallbackAcknowledgement(FallbackAcknowledgement),
    // some variants omitted
}
Available on crate features client or server only.
Information for one authentication stage.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Password(Password)

Password-based authentication (m.login.password).



ReCaptcha(ReCaptcha)

Google ReCaptcha 2.0 authentication (m.login.recaptcha).



EmailIdentity(EmailIdentity)

Email-based authentication (m.login.email.identity).



Msisdn(Msisdn)

Phone number-based authentication (m.login.msisdn).



Dummy(Dummy)

Dummy authentication (m.login.dummy).



RegistrationToken(RegistrationToken)

Registration token-based authentication (m.login.registration_token).



FallbackAcknowledgement(FallbackAcknowledgement)

Fallback acknowledgement.

Implementations

source

impl AuthData

source

pub fn new(
    auth_type: &str,
    session: Option<String>,
    data: JsonObject
) -> Result<Self>

Creates a new AuthData with the given auth_type string, session and data.

Prefer to use the public variants of AuthData where possible; this constructor is meant to be used for unsupported authentication types only and does not allow setting arbitrary data for supported ones.

Errors

Returns an error if the auth_type is known and serialization of data to the corresponding AuthData variant fails.

source

pub fn fallback_acknowledgement(session: String) -> Self

Creates a new AuthData::FallbackAcknowledgement with the given session key.

source

pub fn auth_type(&self) -> Option<AuthType>

Returns the value of the type field, if it exists.

source

pub fn session(&self) -> Option<&str>

Returns the value of the session field, if it exists.

source

pub fn data(&self) -> Cow<'_, JsonObject>

Returns the associated data.

The returned JSON object won’t contain the type and session fields, use .auth_type() / .session() to access those.

Prefer to use the public variants of AuthData where possible; this method is meant to be used for custom auth types only.