ruma_client_api::uiaa

Enum IncomingAuthData

#[non_exhaustive]
pub enum IncomingAuthData { Password(IncomingPassword), ReCaptcha(IncomingReCaptcha), EmailIdentity(IncomingEmailIdentity), Msisdn(IncomingMsisdn), Dummy(IncomingDummy), RegistrationToken(IncomingRegistrationToken), FallbackAcknowledgement(IncomingFallbackAcknowledgement), }
Available on crate features client or server only.
‘Incoming’ variant of AuthData.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Password(IncomingPassword)

Password-based authentication (m.login.password).



ReCaptcha(IncomingReCaptcha)

Google ReCaptcha 2.0 authentication (m.login.recaptcha).



EmailIdentity(IncomingEmailIdentity)

Email-based authentication (m.login.email.identity).



Msisdn(IncomingMsisdn)

Phone number-based authentication (m.login.msisdn).



Dummy(IncomingDummy)

Dummy authentication (m.login.dummy).



RegistrationToken(IncomingRegistrationToken)

Registration token-based authentication (m.login.registration_token).



FallbackAcknowledgement(IncomingFallbackAcknowledgement)

Fallback acknowledgement.

Implementations

Source

impl IncomingAuthData

pub fn new( auth_type: &str, session: Option<String>, data: JsonObject, ) -> Result<Self>

Creates a new IncomingAuthData with the given auth_type string, session and data.

Prefer to use the public variants of IncomingAuthData where possible; this constructor is meant be used for unsupported authentication types only and does not allow setting arbitrary data for supported ones.

Errors

Returns an error if the auth_type is known and serialization of data to the corresponding IncomingAuthData variant fails.

pub fn auth_type(&self) -> Option<AuthType>

Returns the value of the type field, if it exists.

pub fn session(&self) -> Option<&str>

Returns the value of the session field, if it exists.

pub fn data(&self) -> Cow<'_, JsonObject>

Returns the associated data.

The returned JSON object won’t contain the type and session fields, use .auth_type() / .session() to access those.

Prefer to use the public variants of AuthData where possible; this method is meant to be used for custom auth types only.

pub fn to_outgoing(&self) -> AuthData<'_>

Convert IncomingAuthData to AuthData.