pub enum IncomingUserIdentifier {
UserIdOrLocalpart(String),
Email {
address: String,
},
Msisdn {
number: String,
},
PhoneNumber {
country: String,
phone: String,
},
// some variants omitted
}Available on crate features
client or server only.Expand description
‘Incoming’ variant of UserIdentifier.
Variants
UserIdOrLocalpart(String)
Either a fully qualified Matrix user ID, or just the localpart (as part of the ‘identifier’ field).
An email address.
Msisdn
A phone number in the MSISDN format.
PhoneNumber
A phone number as a separate country code and phone number.
The homeserver will be responsible for canonicalizing this to the MSISDN format.
Fields

country: StringThe country that the phone number is from.
This is a two-letter uppercase ISO-3166-1 alpha-2 country code.