pub enum UserIdentifier {
    UserIdOrLocalpart(String),
    Email {
        address: String,
    },
    Msisdn {
        number: String,
    },
    PhoneNumber {
        country: String,
        phone: String,
    },
    // some variants omitted
}
Available on crate features client or server only.
Identification information for the user.

Variants



UserIdOrLocalpart(String)

Either a fully qualified Matrix user ID, or just the localpart (as part of the ‘identifier’ field).



Email

Fields

address: String

The email address.

An email address.



Msisdn

Fields

number: String

The phone number according to the E.164 numbering plan.

A phone number in the MSISDN format.



PhoneNumber

Fields

country: String

The country that the phone number is from.

This is a two-letter uppercase ISO-3166-1 alpha-2 country code.

phone: String

The phone number.

A phone number as a separate country code and phone number.

The homeserver will be responsible for canonicalizing this to the MSISDN format.

Implementations

source

impl UserIdentifier

source

pub fn third_party_id(medium: Medium, address: String) -> Self

Creates a new UserIdentifier from the given third party identifier.

source

pub fn as_third_party_id(&self) -> Option<(&Medium, &str)>

Get this UserIdentifier as a third party identifier if it is one.