Struct ruma_client_api::uiaa::UiaaInfo
source · pub struct UiaaInfo {
pub flows: Vec<AuthFlow>,
pub completed: Vec<AuthType>,
pub params: Box<RawJsonValue>,
pub session: Option<String>,
pub auth_error: Option<StandardErrorBody>,
}Available on crate features
client or server only.Expand description
Information about available authentication flows and status for User-Interactive Authenticiation API.
Fields
flows: Vec<AuthFlow>List of authentication flows available for this endpoint.
completed: Vec<AuthType>List of stages in the current flow completed by the client.
params: Box<RawJsonValue>Authentication parameters required for the client to complete authentication.
To create a Box<RawJsonValue>, use serde_json::value::to_raw_value.
session: Option<String>Session key for client to use to complete authentication.
auth_error: Option<StandardErrorBody>Authentication-related errors for previous request returned by homeserver.
Implementations