ruma_client_api::user_directory::search_users::v3

Struct Request

pub struct Request<'a> {
    pub search_term: &'a str,
    pub limit: UInt,
    pub language: Option<String>,
}
Available on crate features client or server only.
Data for a request to the search_users API endpoint.

Performs a search for users.

Fields

search_term: &'a str

The term to search for.

limit: UInt

The maximum number of results to return.

Defaults to 10.

language: Option<String>

Language tag to determine the collation to use for the (case-insensitive) search.

See MDN for the syntax.

Implementations

Source

impl<'a> Request<'a>

pub fn new(search_term: &'a str) -> Self

Creates a new Request with the given search term.