Struct ruma_client_api::user_directory::search_users::v3::User
source · pub struct User {
pub user_id: OwnedUserId,
pub display_name: Option<String>,
pub avatar_url: Option<OwnedMxcUri>,
}Available on crate features
client or server only.Expand description
User data as result of a search.
Fields
user_id: OwnedUserIdThe user’s matrix user ID.
display_name: Option<String>The display name of the user, if one exists.
avatar_url: Option<OwnedMxcUri>The avatar url, as an MXC, if one exists.
If you activate the compat feature, this field being an empty string in JSON will
result in None here during deserialization.
Implementations