Available on crate features
client or server only.Expand description
/v3/ (spec)
This deletes a backup version and its room keys.
Structs
- ‘Incoming’ variant of Request.
- Data for a request to the
delete_backup_versionAPI endpoint. - Data in the response from the
delete_backup_versionAPI endpoint.
Constants
- Metadata for the
delete_backup_versionAPI endpoint.
Type Aliases
- Convenience type alias for Response, for consistency with other IncomingResponse types.