pub struct Response {
pub homeserver: HomeserverInfo,
pub identity_server: Option<IdentityServerInfo>,
pub tile_server: Option<TileServerInfo>,
pub authentication: Option<AuthenticationServerInfo>,
}Available on crate features
client or server only.Expand description
Data in the response from the client_well_known API endpoint.
Fields
homeserver: HomeserverInfoInformation about the homeserver to connect to.
identity_server: Option<IdentityServerInfo>Information about the identity server to connect to.
tile_server: Option<TileServerInfo>Available on crate feature
unstable-msc3488 only.Information about the tile server to use to display location data.
authentication: Option<AuthenticationServerInfo>Available on crate feature
unstable-msc2965 only.Information about the authentication server to connect to when using OpenID Connect.
Implementations