Available on crate features client or server only.
GET /_matrix/client/*/capabilities

Get information about the server’s supported feature set and other relevant capabilities (spec).

Modules

Iterator implementation for Capabilities
/v3/ (spec)

Structs

Contains information about all the capabilities that the server supports.
Information about the m.change_password capability
Information about the m.room_versions capability
Information about the m.set_avatar_url capability
Information about the m.set_displayname capability
Information about the m.3pid_changes capability

Enums

The stability of a room version.