Module ruma_client_api::discovery::get_capabilities
source · Available on crate features
client or server only.Expand description
GET /_matrix/client/*/capabilities
Get information about the server’s supported feature set and other relevant capabilities (spec).
Modules
Structs
Contains information about all the capabilities that the server supports.
Information about the m.change_password capability
Information about the m.room_versions capability
Information about the
m.set_avatar_url capabilityInformation about the
m.set_displayname capabilityInformation about the
m.3pid_changes capabilityEnums
The stability of a room version.