Struct ruma_client_api::error::Error [−][src]
pub struct Error {
pub kind: ErrorKind,
pub message: String,
pub status_code: StatusCode,
}Expand description
A Matrix Error
Fields
kind: ErrorKindExpand description
A value which can be used to handle an error message
message: StringExpand description
A human-readable error message, usually a sentence explaining what went wrong.
status_code: StatusCodeExpand description
The http status code