Struct ruma_client_api::error::ErrorBody [−][src]
A Matrix Error without a status code
Fields
kind: ErrorKindA value which can be used to handle an error message
message: StringA human-readable error message, usually a sentence explaining what went wrong.
Implementations
Convert the ErrorBody into an Error by adding the http status code.