ruma_client_api::keys::get_keys::v3

Struct Request

pub struct Request<'a> {
    pub timeout: Option<Duration>,
    pub device_keys: BTreeMap<OwnedUserId, Vec<OwnedDeviceId>>,
    pub token: Option<&'a str>,
}
Available on crate features client or server only.
Data for a request to the get_keys API endpoint.

Returns the current devices and identity keys for the given users.

Fields

timeout: Option<Duration>

The time (in milliseconds) to wait when downloading keys from remote servers.

10 seconds is the recommended default.

device_keys: BTreeMap<OwnedUserId, Vec<OwnedDeviceId>>

The keys to be downloaded.

An empty list indicates all devices for the corresponding user.

token: Option<&'a str>

If the client is fetching keys as a result of a device update received in a sync request, this should be the ‘since’ token of that sync request, or any later sync token.

This allows the server to ensure its response contains the keys advertised by the notification in that sync.

Implementations

Source

impl Request<'_>

pub fn new() -> Self

Creates an empty Request.