pub struct Response {
pub failures: BTreeMap<String, JsonValue>,
pub device_keys: BTreeMap<OwnedUserId, BTreeMap<OwnedDeviceId, Raw<DeviceKeys>>>,
pub master_keys: BTreeMap<OwnedUserId, Raw<CrossSigningKey>>,
pub self_signing_keys: BTreeMap<OwnedUserId, Raw<CrossSigningKey>>,
pub user_signing_keys: BTreeMap<OwnedUserId, Raw<CrossSigningKey>>,
}Available on crate features
client or server only.Expand description
Response type for the get_keys endpoint.
Fields
failures: BTreeMap<String, JsonValue>If any remote homeservers could not be reached, they are recorded here.
The names of the properties are the names of the unreachable servers.
device_keys: BTreeMap<OwnedUserId, BTreeMap<OwnedDeviceId, Raw<DeviceKeys>>>Information on the queried devices.
master_keys: BTreeMap<OwnedUserId, Raw<CrossSigningKey>>Information on the master cross-signing keys of the queried users.
self_signing_keys: BTreeMap<OwnedUserId, Raw<CrossSigningKey>>Information on the self-signing keys of the queried users.
user_signing_keys: BTreeMap<OwnedUserId, Raw<CrossSigningKey>>Information on the user-signing keys of the queried users.
Implementations