Struct ruma_client_api::media::get_content_thumbnail::v3::Request
source · pub struct Request {
pub server_name: OwnedServerName,
pub media_id: String,
pub method: Option<Method>,
pub width: UInt,
pub height: UInt,
pub allow_remote: bool,
pub timeout_ms: Duration,
pub allow_redirect: bool,
}client or server only.Expand description
Request type for the get_content_thumbnail endpoint.
Fields
server_name: OwnedServerNameThe server name from the mxc:// URI (the authoritory component).
media_id: StringThe media ID from the mxc:// URI (the path component).
method: Option<Method>The desired resizing method.
width: UIntThe desired width of the thumbnail.
The actual thumbnail may not match the size specified.
height: UIntThe desired height of the thumbnail.
The actual thumbnail may not match the size specified.
allow_remote: boolWhether to fetch media deemed remote.
Used to prevent routing loops. Defaults to true.
timeout_ms: DurationThe maximum duration that the client is willing to wait to start receiving data, in the case that the content has not yet been uploaded.
The default value is 20 seconds.
allow_redirect: boolWhether the server may return a 307 or 308 redirect response that points at the relevant media content.
Unless explicitly set to true, the server must return the media content itself.
Implementations