ruma_client_api::membership

Struct ThirdPartySigned

pub struct ThirdPartySigned<'a> {
    pub sender: &'a UserId,
    pub mxid: &'a UserId,
    pub token: &'a str,
    pub signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>,
}
Available on crate features client or server only.
A signature of an m.third_party_invite token to prove that this user owns a third party identity which has been invited to the room.

Fields

sender: &'a UserId

The Matrix ID of the user who issued the invite.

mxid: &'a UserId

The Matrix ID of the invitee.

token: &'a str

The state key of the m.third_party_invite event.

signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>

A signatures object containing a signature of the entire signed object.

Implementations

Source

impl<'a> ThirdPartySigned<'a>

pub fn new( sender: &'a UserId, mxid: &'a UserId, token: &'a str, signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>, ) -> Self

Creates a new ThirdPartySigned from the given sender and invitee user IDs, state key token and signatures.