ruma_client_api::message::get_message_events::v3

Struct Request

pub struct Request<'a> {
    pub room_id: &'a RoomId,
    pub from: Option<&'a str>,
    pub to: Option<&'a str>,
    pub dir: Direction,
    pub limit: UInt,
    pub filter: RoomEventFilter<'a>,
}
Available on crate features client or server only.
Data for a request to the get_message_events API endpoint.

Get message events for a room.

Fields

room_id: &'a RoomId

The room to get events from.

from: Option<&'a str>

The token to start returning events from.

This token can be obtained from a prev_batch token returned for each room by the sync endpoint, or from a start or end token returned by a previous request to this endpoint.

If this is None, the server will return messages from the start or end of the history visible to the user, depending on the value of dir.

to: Option<&'a str>

The token to stop returning events at.

This token can be obtained from a prev_batch token returned for each room by the sync endpoint, or from a start or end token returned by a previous request to this endpoint.

dir: Direction

The direction to return events from.

limit: UInt

The maximum number of events to return.

Default: 10.

filter: RoomEventFilter<'a>

A RoomEventFilter to filter returned events with.

Implementations

Source

impl<'a> Request<'a>

pub fn new(room_id: &'a RoomId, dir: Direction) -> Self

Creates a new Request with the given room ID and direction.

All other parameters will be defaulted.

pub fn backward(room_id: &'a RoomId) -> Self

Creates a new Request with the given room ID and dir set to Backward.

If the returned request is sent without from being set, pagination will start at the end of (the accessible part of) the room timeline.

Example
let request = get_message_events::v3::Request::backward(room_id).from(token);
pub fn forward(room_id: &'a RoomId) -> Self

Creates a new Request with the given room ID and dir set to Forward.

If the returned request is sent without from being set, pagination will start at the beginning of (the accessible part of) the room timeline.

Example
let request = get_message_events::v3::Request::forward(room_id).from(token);
pub fn from(self, from: impl Into<Option<&'a str>>) -> Self

Creates a new Request from self with the from field set to the given value.

Since the field is public, you can also assign to it directly. This method merely acts as a shorthand for that, because it is very common to set this field.