Module ruma_client_api::push
source · Available on crate features
client or server only.Expand description
Endpoints for push notifications.
Modules
DELETE /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}GET /_matrix/client/*/notificationsGET /_matrix/client/*/pushersGET /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}GET /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}/actionsGET /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}/enabledGET /_matrix/client/*/pushrules/GET /_matrix/client/*/pushrules/global/POST /_matrix/client/*/pushers/setPUT /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}PUT /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}/actionsPUT /_matrix/client/*/pushrules/{scope}/{kind}/{ruleId}/enabledStructs
Information for an email pusher.
An error that happens when
PushRule cannot
be converted into ConditionalPushRuleAn error that happens when
PushRule cannot
be converted into PatternedPushRuleLike
SimplePushRule, but may represent any kind of push rule thanks to pattern and
conditions being optional.Defines a pusher.
Strings to uniquely identify a
Pusher.Initial set of fields of
Pusher.Enums
Which kind a pusher is, and the information for that kind.
The kinds of push rules that are available.
The scope of a push rule.