Struct ruma_client_api::push::PusherInit
source · pub struct PusherInit {
pub ids: PusherIds,
pub kind: PusherKind,
pub app_display_name: String,
pub device_display_name: String,
pub profile_tag: Option<String>,
pub lang: String,
}Available on crate features
client or server only.Expand description
Initial set of fields of Pusher.
This struct will not be updated even if additional fields are added to Pusher in a new
(non-breaking) release of the Matrix specification.
Fields
ids: PusherIdsIdentifiers for this pusher.
kind: PusherKindThe kind of the pusher.
app_display_name: StringA string that will allow the user to identify what application owns this pusher.
device_display_name: StringA string that will allow the user to identify what device owns this pusher.
profile_tag: Option<String>Determines which set of device-specific rules this pusher executes.
lang: StringThe preferred language for receiving notifications (e.g. ‘en’ or ‘en-US’).