Struct ruma_client_api::r0::account::bind_3pid::IncomingRequest[][src]

pub struct IncomingRequest {
    pub client_secret: String,
    pub identity_server_info: IncomingIdentityServerInfo,
    pub sid: String,
}
‘Incoming’ variant of Request.

Fields

client_secret: String

Client-generated secret string used to protect this session.

identity_server_info: IncomingIdentityServerInfo

The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.

sid: String

The session identifier given by the identity server.