Struct ruma_client_api::r0::account::bind_3pid::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub client_secret: &'a str, pub identity_server_info: IdentityServerInfo<'a>, pub sid: &'a str, }
Data for a request to the bind_3pid API endpoint.
Bind a 3PID to a user’s account on an identity server
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_secret: &'a strExpand description
Client-generated secret string used to protect this session.
identity_server_info: IdentityServerInfo<'a>Expand description
The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
sid: &'a strExpand description
The session identifier given by the identity server.
Implementations
impl<'a> Request<'a>[src]
impl<'a> Request<'a>[src]pub fn new(
client_secret: &'a str,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a str
) -> Self[src]
pub fn new(
client_secret: &'a str,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a str
) -> Self[src]Creates a new Request with the given client secret, identity server information and
session identifier.