[−][src]Struct ruma_client_api::r0::account::bind_3pid::Request
Data for a request to the bind_3pid API endpoint.
Bind a 3PID to a user's account on an identity server
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_secret: &'a strClient-generated secret string used to protect this session.
identity_server_info: IdentityServerInfo<'a>The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
sid: &'a strThe session identifier given by the identity server.
Implementations
impl<'a> Request<'a>[src]
pub fn new(
client_secret: &'a str,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a str
) -> Self[src]
client_secret: &'a str,
identity_server_info: IdentityServerInfo<'a>,
sid: &'a str
) -> Self
Creates a new Request with the given client secret, identity server information and
session identifier.