[−][src]Struct ruma_client_api::r0::account::register::Request
Data for a request to the register API endpoint.
Register an account on this homeserver.
Fields
password: Option<String>The desired password for the account.
May be empty for accounts that should not be able to log in again with a password, e.g., for guest or application service accounts.
username: Option<String>local part of the desired Matrix ID.
If omitted, the homeserver MUST generate a Matrix ID local part.
device_id: Option<DeviceId>ID of the client device.
If this does not correspond to a known client device, a new device will be created. The server will auto-generate a device_id if this is not specified.
initial_device_display_name: Option<String>A display name to assign to the newly-created device.
Ignored if device_id corresponds to a known device.
auth: Option<AuthData>Additional authentication information for the user-interactive authentication API.
Note that this information is not used to define how the registered user should be authenticated, but is instead used to authenticate the register call itself. It should be left empty, or omitted, unless an earlier call returned an response with status code 401.
kind: Option<RegistrationKind>Kind of account to register
Defaults to User if omitted.
inhibit_login: boolIf true, an access_token and device_id should not be returned
from this call, therefore preventing an automatic login.