pub struct Request {
pub bind_email: Option<bool>,
pub password: Option<String>,
pub username: Option<String>,
pub device_id: Option<String>,
pub initial_device_display_name: Option<String>,
pub auth: Option<AuthenticationData>,
pub kind: Option<RegistrationKind>,
}Expand description
Data for a request to this API endpoint.
Fields
bind_email: Option<bool>If true, the server binds the email used for authentication to the Matrix ID with the ID Server.
password: Option<String>The desired password for the account.
Should only be empty for guest accounts.
username: Option<String>local part of the desired Matrix ID.
If omitted, the homeserver MUST generate a Matrix ID local part.
device_id: Option<String>ID of the client device.
If this does not correspond to a known client device, a new device will be created. The server will auto-generate a device_id if this is not specified.
initial_device_display_name: Option<String>A display name to assign to the newly-created device.
Ignored if device_id corresponds to a known device.
auth: Option<AuthenticationData>Additional authentication information for the user-interactive authentication API.
Note that this information is not used to define how the registered user should be authenticated, but is instead used to authenticate the register call itself. It should be left empty, or omitted, unless an earlier call returned an response with status code 401.
kind: Option<RegistrationKind>Kind of account to register
Defaults to User if ommited.