[][src]Struct ruma_client_api::r0::account::register::Response

pub struct Response {
    pub access_token: Option<String>,
    pub user_id: UserId,
    pub device_id: Option<DeviceId>,
}

Data in the response from the register API endpoint.

Fields

access_token: Option<String>

An access token for the account.

This access token can then be used to authorize other requests.

user_id: UserId

The fully-qualified Matrix ID that has been registered.

device_id: Option<DeviceId>

ID of the registered device.

Will be the same as the corresponding parameter in the request, if one was specified.