[−][src]Struct ruma_client_api::r0::account::register::Response
Data in the response from this API endpoint.
Fields
access_token: StringAn access token for the account.
This access token can then be used to authorize other requests.
home_server: StringThe hostname of the homeserver on which the account has been registered.
user_id: UserIdThe fully-qualified Matrix ID that has been registered.
device_id: StringID of the registered device.
Will be the same as the corresponding parameter in the request, if one was specified.