pub struct Response {
    pub access_token: String,
    pub home_server: String,
    pub user_id: UserId,
    pub device_id: String,
}
Data in the response from this API endpoint.

Fields

access_token: String

An access token for the account.

This access token can then be used to authorize other requests.

home_server: String

The hostname of the homeserver on which the account has been registered.

user_id: UserId

The fully-qualified Matrix ID that has been registered.

device_id: String

ID of the registered device.

Will be the same as the corresponding parameter in the request, if one was specified.