Struct ruma_client_api::r0::account::request_register_token::Request
source · pub struct Request {
pub client_secret: String,
pub email: String,
pub id_server: Option<String>,
pub send_attempt: u64,
}Expand description
Data for a request to this API endpoint.
Fields
client_secret: StringClient-generated secret string used to protect this session.
email: StringThe email address.
id_server: Option<String>The ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
send_attempt: u64Used to distinguish protocol level retries from requests to re-send the email.