[−][src]Struct ruma_client_api::r0::account::IdentityServerInfo
Additional authentication information for requestToken endpoints.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id_server: &'a strThe ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
id_access_token: &'a strAccess token previously registered with identity server.
Implementations
impl<'a> IdentityServerInfo<'a>[src]
pub fn new(id_server: &'a str, id_access_token: &'a str) -> Self[src]
Creates a new IdentityServerInfo with the given server name and access token.