Struct ruma_client_api::r0::account::IncomingIdentityServerInfo [−][src]
#[non_exhaustive]pub struct IncomingIdentityServerInfo { pub id_server: String, pub id_access_token: String, }
‘Incoming’ variant of IdentityServerInfo.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id_server: StringThe ID server to send the onward request to as a hostname with an appended colon and port number if the port is not the default.
id_access_token: StringAccess token previously registered with identity server.