[−][src]Struct ruma_client_api::r0::account::UserInteractiveAuthenticationInfo
Information about available authentication flows and status for User-Interactive Authenticiation API.
Fields
flows: Vec<AuthenticationFlow>List of authentication flows available for this endpoint.
completed: Vec<String>List of stages in the current flow completed by the client.
params: ValueAuthentication parameters required for the client to complete authentication.
session: Option<String>Session key for client to use to complete authentication.