Struct ruma_client_api::r0::backup::KeyBackupData [−][src]
pub struct KeyBackupData {
pub first_message_index: UInt,
pub forwarded_count: UInt,
pub is_verified: bool,
pub session_data: SessionData,
}unstable-pre-spec only.Expand description
Information about the backup key.
Fields
first_message_index: UIntThe index of the first message in the session that the key can decrypt.
forwarded_count: UIntThe number of times this key has been forwarded via key-sharing between devices.
is_verified: boolWhether the device backing up the key verified the device that the key is from.
session_data: SessionDataData about the session.