Struct ruma_client_api::r0::capabilities::Capabilities [−][src]
#[non_exhaustive]pub struct Capabilities { pub change_password: ChangePasswordCapability, pub room_versions: RoomVersionsCapability, // some fields omitted }
Contains information about all the capabilities that the server supports.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.change_password: ChangePasswordCapabilityExpand description
Capability to indicate if the user can change their password.
room_versions: RoomVersionsCapabilityExpand description
The room versions the server supports.
Implementations
impl Capabilities[src]
impl Capabilities[src]pub fn get(&self, capability: &str) -> Option<Cow<'_, JsonValue>>[src]
pub fn get(&self, capability: &str) -> Option<Cow<'_, JsonValue>>[src]Returns the value of the given capability.
Prefer to use the public fields of Capabilities where possible; this method is meant to be
used for unsupported capabilities only.
pub fn set(&mut self, capability: &str, value: JsonValue) -> Result<()>[src]
pub fn set(&mut self, capability: &str, value: JsonValue) -> Result<()>[src]Sets a capability to the given value.
Prefer to use the public fields of Capabilities where possible; this method is meant to be
used for unsupported capabilities only and does not allow setting arbitrary data for
supported ones.
pub fn iter(&self) -> CapabilitiesIter<'_>ⓘNotable traits for CapabilitiesIter<'a>
impl<'a> Iterator for CapabilitiesIter<'a> type Item = CapabilityRef<'a>;[src]
pub fn iter(&self) -> CapabilitiesIter<'_>ⓘNotable traits for CapabilitiesIter<'a>
impl<'a> Iterator for CapabilitiesIter<'a> type Item = CapabilityRef<'a>;[src]Returns an iterator over the capabilities.