Struct ruma_client_api::r0::capabilities::RoomVersionsCapability[][src]

#[non_exhaustive]
pub struct RoomVersionsCapability { pub default: RoomVersionId, pub available: BTreeMap<RoomVersionId, RoomVersionStability>, }

Information about the m.room_versions capability

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
default: RoomVersionId

The default room version the server is using for new rooms.

available: BTreeMap<RoomVersionId, RoomVersionStability>

A detailed description of the room versions the server supports.

Implementations

impl RoomVersionsCapability[src]

pub fn new(
    default: RoomVersionId,
    available: BTreeMap<RoomVersionId, RoomVersionStability>
) -> Self
[src]

Creates a new RoomVersionsCapability with the given default room version ID and room version descriptions.

pub fn is_default(&self) -> bool[src]

Returns whether all fields have their default value.