Struct ruma_client_api::r0::contact::create_contact::ThreePidCredentials
source · pub struct ThreePidCredentials {
pub client_secret: String,
pub id_server: String,
pub sid: String,
}Expand description
The third party credentials to associate with the account.
Fields
client_secret: StringThe client secret used in the session with the identity server.
id_server: StringThe identity server to use.
sid: StringThe session identifier given by the identity server.