Struct ruma_client_api::r0::context::get_context::Response[][src]

#[non_exhaustive]
pub struct Response { pub start: Option<String>, pub end: Option<String>, pub events_before: Vec<Raw<AnyRoomEvent>>, pub event: Option<Raw<AnyRoomEvent>>, pub events_after: Vec<Raw<AnyRoomEvent>>, pub state: Vec<Raw<AnyStateEvent>>, }

Data in the response from the get_context API endpoint.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
start: Option<String>

A token that can be used to paginate backwards with.

end: Option<String>

A token that can be used to paginate forwards with.

events_before: Vec<Raw<AnyRoomEvent>>

A list of room events that happened just before the requested event, in reverse-chronological order.

event: Option<Raw<AnyRoomEvent>>

Details of the requested event.

events_after: Vec<Raw<AnyRoomEvent>>

A list of room events that happened just after the requested event, in chronological order.

state: Vec<Raw<AnyStateEvent>>

The state of the room at the last event returned.

Implementations

impl Response[src]

pub fn new() -> Self[src]

Creates an empty Response.