[−][src]Struct ruma_client_api::r0::context::get_context::Response
Data in the response from the get_context API endpoint.
Fields
end: StringA token that can be used to paginate forwards with.
event: RoomEventDetails of the requested event.
events_after: Vec<RoomEvent>A list of room events that happened just after the requested event, in chronological order.
events_before: Vec<RoomEvent>A list of room events that happened just before the requested event, in reverse-chronological order.
start: StringA token that can be used to paginate backwards with.
state: Vec<StateEvent>The state of the room at the last event returned.