pub struct Response {
    pub end: String,
    pub event: RoomEvent,
    pub events_after: Vec<RoomEvent>,
    pub events_before: Vec<RoomEvent>,
    pub start: String,
    pub state: Vec<StateEvent>,
}
Data in the response from this API endpoint.

Fields

end: String

A token that can be used to paginate forwards with.

event: RoomEvent

Details of the requested event.

events_after: Vec<RoomEvent>

A list of room events that happened just after the requested event, in chronological order.

events_before: Vec<RoomEvent>

A list of room events that happened just before the requested event, in reverse-chronological order.

start: String

A token that can be used to paginate backwards with.

state: Vec<StateEvent>

The state of the room at the last event returned.