Struct ruma_client_api::r0::filter::Filter [−][src]
#[non_exhaustive]pub struct Filter<'a> { pub not_types: &'a [String], pub limit: Option<UInt>, pub senders: Option<&'a [UserId]>, pub types: Option<&'a [String]>, pub not_senders: &'a [UserId], }
Filter for non-room data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.not_types: &'a [String]A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.
limit: Option<UInt>The maximum number of events to return.
senders: Option<&'a [UserId]>A list of senders IDs to include.
If this list is absent then all senders are included.
types: Option<&'a [String]>A list of event types to include.
If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.
not_senders: &'a [UserId]A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.
Implementations