Struct ruma_client_api::r0::filter::FilterDefinition [−][src]
#[non_exhaustive]pub struct FilterDefinition<'a> { pub event_fields: Option<&'a [String]>, pub event_format: EventFormat, pub presence: Filter<'a>, pub account_data: Filter<'a>, pub room: RoomFilter<'a>, }
A filter definition
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_fields: Option<&'a [String]>Expand description
List of event fields to include.
If this list is absent then all fields are included. The entries may include ‘.’ characters to indicate sub-fields. So [‘content.body’] will include the ‘body’ field of the ‘content’ object. A literal ‘.’ character in a field name may be escaped using a ’'. A server may include more fields than were requested.
event_format: EventFormatExpand description
The format to use for events.
‘client’ will return the events in a format suitable for clients. ‘federation’ will return the raw event as received over federation. The default is ‘client’.
presence: Filter<'a>Expand description
The presence updates to include.
account_data: Filter<'a>Expand description
The user account data that isn’t associated with rooms to include.
room: RoomFilter<'a>Expand description
Filters to be applied to room data.
Implementations
impl<'a> FilterDefinition<'a>[src]
impl<'a> FilterDefinition<'a>[src]Trait Implementations
impl<'a> CanBeEmpty for FilterDefinition<'a>[src]
impl<'a> CanBeEmpty for FilterDefinition<'a>[src]impl<'a> Clone for FilterDefinition<'a>[src]
impl<'a> Clone for FilterDefinition<'a>[src]fn clone(&self) -> FilterDefinition<'a>[src]
fn clone(&self) -> FilterDefinition<'a>[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl<'a> Debug for FilterDefinition<'a>[src]
impl<'a> Debug for FilterDefinition<'a>[src]impl<'a> Default for FilterDefinition<'a>[src]
impl<'a> Default for FilterDefinition<'a>[src]fn default() -> FilterDefinition<'a>[src]
fn default() -> FilterDefinition<'a>[src]Returns the “default value” for a type. Read more
impl<'a> From<FilterDefinition<'a>> for Filter<'a>[src]
impl<'a> From<FilterDefinition<'a>> for Filter<'a>[src]fn from(def: FilterDefinition<'a>) -> Self[src]
fn from(def: FilterDefinition<'a>) -> Self[src]Performs the conversion.
impl<'a> Outgoing for FilterDefinition<'a>[src]
impl<'a> Outgoing for FilterDefinition<'a>[src]type Incoming = IncomingFilterDefinition
type Incoming = IncomingFilterDefinitionThe ‘Incoming’ variant of Self.
impl<'a> Serialize for FilterDefinition<'a>[src]
impl<'a> Serialize for FilterDefinition<'a>[src]Auto Trait Implementations
impl<'a> RefUnwindSafe for FilterDefinition<'a>
impl<'a> Send for FilterDefinition<'a>
impl<'a> Sync for FilterDefinition<'a>
impl<'a> Unpin for FilterDefinition<'a>
impl<'a> UnwindSafe for FilterDefinition<'a>