pub struct FilterDefinition {
    pub event_fields: Vec<String>,
    pub event_format: Option<EventFormat>,
    pub account_data: Option<Filter>,
    pub room: Option<RoomFilter>,
    pub presence: Option<Filter>,
}
A filter definition

Fields

event_fields: Vec<String>

List of event fields to include.

If this list is absent then all fields are included. The entries may include ‘.’ charaters to indicate sub-fields. So [‘content.body’] will include the ‘body’ field of the ‘content’ object. A literal ‘.’ character in a field name may be escaped using a ’'. A server may include more fields than were requested.

event_format: Option<EventFormat>

The format to use for events.

‘client’ will return the events in a format suitable for clients. ‘federation’ will return the raw event as receieved over federation. The default is ‘client’.

account_data: Option<Filter>

The user account data that isn’t associated with rooms to include.

room: Option<RoomFilter>

Filters to be applied to room data.

presence: Option<Filter>

The presence updates to include.