Struct ruma_client_api::r0::filter::IncomingFilter [−][src]
#[non_exhaustive]pub struct IncomingFilter { pub not_types: Vec<String>, pub limit: Option<UInt>, pub senders: Option<Vec<UserId>>, pub types: Option<Vec<String>>, pub not_senders: Vec<UserId>, }
‘Incoming’ variant of Filter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.not_types: Vec<String>A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.
limit: Option<UInt>The maximum number of events to return.
senders: Option<Vec<UserId>>A list of senders IDs to include.
If this list is absent then all senders are included.
types: Option<Vec<String>>A list of event types to include.
If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.
not_senders: Vec<UserId>A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.
Implementations
impl IncomingFilter[src]
impl IncomingFilter[src]Trait Implementations
impl CanBeEmpty for IncomingFilter[src]
impl CanBeEmpty for IncomingFilter[src]impl Clone for IncomingFilter[src]
impl Clone for IncomingFilter[src]fn clone(&self) -> IncomingFilter[src]
fn clone(&self) -> IncomingFilter[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for IncomingFilter[src]
impl Debug for IncomingFilter[src]impl Default for IncomingFilter[src]
impl Default for IncomingFilter[src]fn default() -> IncomingFilter[src]
fn default() -> IncomingFilter[src]Returns the “default value” for a type. Read more
impl<'de> Deserialize<'de> for IncomingFilter[src]
impl<'de> Deserialize<'de> for IncomingFilter[src]fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
impl Serialize for IncomingFilter[src]
impl Serialize for IncomingFilter[src]Auto Trait Implementations
impl RefUnwindSafe for IncomingFilter
impl Send for IncomingFilter
impl Sync for IncomingFilter
impl Unpin for IncomingFilter
impl UnwindSafe for IncomingFilter