Struct ruma_client_api::r0::filter::IncomingRoomFilter[][src]

#[non_exhaustive]
pub struct IncomingRoomFilter { pub include_leave: bool, pub account_data: IncomingRoomEventFilter, pub timeline: IncomingRoomEventFilter, pub ephemeral: IncomingRoomEventFilter, pub state: IncomingRoomEventFilter, pub not_rooms: Vec<RoomId>, pub rooms: Option<Vec<RoomId>>, }

‘Incoming’ variant of RoomFilter.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
include_leave: bool

Include rooms that the user has left in the sync.

Defaults to false.

account_data: IncomingRoomEventFilter

The per user account data to include for rooms.

timeline: IncomingRoomEventFilter

The message and state update events to include for rooms.

ephemeral: IncomingRoomEventFilter

The events that aren’t recorded in the room history, e.g. typing and receipts, to include for rooms.

state: IncomingRoomEventFilter

The state events to include for rooms.

not_rooms: Vec<RoomId>

A list of room IDs to exclude.

If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter. This filter is applied before the filters in ephemeral, state, timeline or account_data.

rooms: Option<Vec<RoomId>>

A list of room IDs to include.

If this list is absent then all rooms are included. This filter is applied before the filters in ephemeral, state, timeline or account_data.

Implementations

impl IncomingRoomFilter[src]

pub fn is_empty(&self) -> bool[src]

Returns true if all fields are empty.