Struct ruma_client_api::r0::filter::RoomEventFilter [−][src]
#[non_exhaustive]pub struct RoomEventFilter<'a> { pub not_types: &'a [String], pub not_rooms: &'a [String], pub limit: Option<UInt>, pub rooms: Option<&'a [RoomId]>, pub not_senders: &'a [UserId], pub senders: Option<&'a [UserId]>, pub types: Option<&'a [String]>, pub url_filter: Option<UrlFilter>, pub lazy_load_options: LazyLoadOptions, }
Filters to be applied to room events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.not_types: &'a [String]Expand description
A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.
not_rooms: &'a [String]Expand description
A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter.
limit: Option<UInt>Expand description
The maximum number of events to return.
rooms: Option<&'a [RoomId]>Expand description
A list of room IDs to include.
If this list is absent then all rooms are included.
not_senders: &'a [UserId]Expand description
A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.
senders: Option<&'a [UserId]>Expand description
A list of senders IDs to include.
If this list is absent then all senders are included.
types: Option<&'a [String]>Expand description
A list of event types to include.
If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.
url_filter: Option<UrlFilter>Expand description
Controls whether to include events with a URL key in their content.
None: No filteringSome(EventsWithUrl): Only events with a URLSome(EventsWithoutUrl): Only events without a URL
lazy_load_options: LazyLoadOptionsExpand description
Options to control lazy-loading of membership events.
Defaults to LazyLoadOptions::Disabled.
Implementations
impl<'a> RoomEventFilter<'a>[src]
impl<'a> RoomEventFilter<'a>[src]Trait Implementations
impl<'a> CanBeEmpty for RoomEventFilter<'a>[src]
impl<'a> CanBeEmpty for RoomEventFilter<'a>[src]impl<'a> Clone for RoomEventFilter<'a>[src]
impl<'a> Clone for RoomEventFilter<'a>[src]fn clone(&self) -> RoomEventFilter<'a>[src]
fn clone(&self) -> RoomEventFilter<'a>[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl<'a> Debug for RoomEventFilter<'a>[src]
impl<'a> Debug for RoomEventFilter<'a>[src]impl<'a> Default for RoomEventFilter<'a>[src]
impl<'a> Default for RoomEventFilter<'a>[src]fn default() -> RoomEventFilter<'a>[src]
fn default() -> RoomEventFilter<'a>[src]Returns the “default value” for a type. Read more
impl<'a> Outgoing for RoomEventFilter<'a>[src]
impl<'a> Outgoing for RoomEventFilter<'a>[src]type Incoming = IncomingRoomEventFilter
type Incoming = IncomingRoomEventFilterThe ‘Incoming’ variant of Self.
impl<'a> Serialize for RoomEventFilter<'a>[src]
impl<'a> Serialize for RoomEventFilter<'a>[src]Auto Trait Implementations
impl<'a> RefUnwindSafe for RoomEventFilter<'a>
impl<'a> Send for RoomEventFilter<'a>
impl<'a> Sync for RoomEventFilter<'a>
impl<'a> Unpin for RoomEventFilter<'a>
impl<'a> UnwindSafe for RoomEventFilter<'a>