Struct ruma_client_api::r0::filter::RoomEventFilter[][src]

#[non_exhaustive]
pub struct RoomEventFilter<'a> { pub not_types: &'a [String], pub not_rooms: &'a [String], pub limit: Option<UInt>, pub rooms: Option<&'a [RoomId]>, pub not_senders: &'a [UserId], pub senders: Option<&'a [UserId]>, pub types: Option<&'a [String]>, pub url_filter: Option<UrlFilter>, pub lazy_load_options: LazyLoadOptions, }

Filters to be applied to room events.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
not_types: &'a [String]

A list of event types to exclude.

If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the ‘types’ filter. A ‘*’ can be used as a wildcard to match any sequence of characters.

not_rooms: &'a [String]

A list of room IDs to exclude.

If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter.

limit: Option<UInt>

The maximum number of events to return.

rooms: Option<&'a [RoomId]>

A list of room IDs to include.

If this list is absent then all rooms are included.

not_senders: &'a [UserId]

A list of sender IDs to exclude.

If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the ‘senders’ filter.

senders: Option<&'a [UserId]>

A list of senders IDs to include.

If this list is absent then all senders are included.

types: Option<&'a [String]>

A list of event types to include.

If this list is absent then all event types are included. A ‘*’ can be used as a wildcard to match any sequence of characters.

url_filter: Option<UrlFilter>

Controls whether to include events with a URL key in their content.

  • None: No filtering
  • Some(EventsWithUrl): Only events with a URL
  • Some(EventsWithoutUrl): Only events without a URL
lazy_load_options: LazyLoadOptions

Options to control lazy-loading of membership events.

Defaults to LazyLoadOptions::Disabled.

Implementations

impl<'a> RoomEventFilter<'a>[src]

pub fn empty() -> Self[src]

Creates an empty RoomEventFilter.

You can also use the Default implementation.

pub fn ignore_all() -> Self[src]

Creates a RoomEventFilter that can be used to ignore all room events.

pub fn is_empty(&self) -> bool[src]

Returns true if all fields are empty.