[−][src]Struct ruma_client_api::r0::filter::RoomEventFilter
Filters to be applied to room events
Fields
not_types: Vec<String>A list of event types to exclude.
If this list is absent then no event types are excluded. A matching type will be excluded even if it is listed in the 'types' filter. A '*' can be used as a wildcard to match any sequence of characters.
not_rooms: Vec<String>A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the 'rooms' filter.
limit: Option<u64>The maximum number of events to return.
rooms: Vec<RoomId>A list of room IDs to include.
If this list is absent then all rooms are included.
not_senders: Vec<UserId>A list of sender IDs to exclude.
If this list is absent then no senders are excluded. A matching sender will be excluded even if it is listed in the 'senders' filter.
senders: Vec<UserId>A list of senders IDs to include.
If this list is absent then all senders are included.
types: Vec<String>A list of event types to include.
If this list is absent then all event types are included. A '*' can be used as a wildcard to match any sequence of characters.