Struct ruma_client_api::r0::filter::RoomFilter [−][src]
#[non_exhaustive]pub struct RoomFilter<'a> { pub include_leave: bool, pub account_data: RoomEventFilter<'a>, pub timeline: RoomEventFilter<'a>, pub ephemeral: RoomEventFilter<'a>, pub state: RoomEventFilter<'a>, pub not_rooms: &'a [RoomId], pub rooms: Option<&'a [RoomId]>, }
Filters to be applied to room data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_leave: boolExpand description
Include rooms that the user has left in the sync.
Defaults to false.
account_data: RoomEventFilter<'a>Expand description
The per user account data to include for rooms.
timeline: RoomEventFilter<'a>Expand description
The message and state update events to include for rooms.
ephemeral: RoomEventFilter<'a>Expand description
The events that aren’t recorded in the room history, e.g. typing and receipts, to include for rooms.
state: RoomEventFilter<'a>Expand description
The state events to include for rooms.
not_rooms: &'a [RoomId]Expand description
A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if
it is listed in the ‘rooms’ filter. This filter is applied before the filters in
ephemeral, state, timeline or account_data.
rooms: Option<&'a [RoomId]>Expand description
A list of room IDs to include.
If this list is absent then all rooms are included. This filter is applied before the
filters in ephemeral, state, timeline or account_data.
Implementations
impl<'a> RoomFilter<'a>[src]
impl<'a> RoomFilter<'a>[src]Trait Implementations
impl<'a> CanBeEmpty for RoomFilter<'a>[src]
impl<'a> CanBeEmpty for RoomFilter<'a>[src]impl<'a> Clone for RoomFilter<'a>[src]
impl<'a> Clone for RoomFilter<'a>[src]fn clone(&self) -> RoomFilter<'a>[src]
fn clone(&self) -> RoomFilter<'a>[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl<'a> Debug for RoomFilter<'a>[src]
impl<'a> Debug for RoomFilter<'a>[src]impl<'a> Default for RoomFilter<'a>[src]
impl<'a> Default for RoomFilter<'a>[src]fn default() -> RoomFilter<'a>[src]
fn default() -> RoomFilter<'a>[src]Returns the “default value” for a type. Read more
impl<'a> Outgoing for RoomFilter<'a>[src]
impl<'a> Outgoing for RoomFilter<'a>[src]type Incoming = IncomingRoomFilter
type Incoming = IncomingRoomFilterThe ‘Incoming’ variant of Self.
impl<'a> Serialize for RoomFilter<'a>[src]
impl<'a> Serialize for RoomFilter<'a>[src]Auto Trait Implementations
impl<'a> RefUnwindSafe for RoomFilter<'a>
impl<'a> Send for RoomFilter<'a>
impl<'a> Sync for RoomFilter<'a>
impl<'a> Unpin for RoomFilter<'a>
impl<'a> UnwindSafe for RoomFilter<'a>