Struct ruma_client_api::r0::filter::RoomFilter [−][src]
#[non_exhaustive]pub struct RoomFilter<'a> { pub include_leave: bool, pub account_data: RoomEventFilter<'a>, pub timeline: RoomEventFilter<'a>, pub ephemeral: RoomEventFilter<'a>, pub state: RoomEventFilter<'a>, pub not_rooms: &'a [RoomId], pub rooms: Option<&'a [RoomId]>, }
Filters to be applied to room data.
Fields (Non-exhaustive)
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_leave: boolInclude rooms that the user has left in the sync.
Defaults to false.
account_data: RoomEventFilter<'a>The per user account data to include for rooms.
timeline: RoomEventFilter<'a>The message and state update events to include for rooms.
ephemeral: RoomEventFilter<'a>The events that aren’t recorded in the room history, e.g. typing and receipts, to include for rooms.
state: RoomEventFilter<'a>The state events to include for rooms.
not_rooms: &'a [RoomId]A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if
it is listed in the ‘rooms’ filter. This filter is applied before the filters in
ephemeral, state, timeline or account_data.
rooms: Option<&'a [RoomId]>A list of room IDs to include.
If this list is absent then all rooms are included. This filter is applied before the
filters in ephemeral, state, timeline or account_data.
Implementations
impl<'a> RoomFilter<'a>[src]
pub fn empty() -> Self[src]
Creates an empty RoomFilter.
You can also use the Default implementation.
pub fn ignore_all() -> Self[src]
Creates a RoomFilter that can be used to ignore all room events (of any type).
pub fn is_empty(&self) -> bool[src]
Returns true if all fields are empty.