pub struct RoomFilter {
    pub include_leave: Option<bool>,
    pub account_data: Option<RoomEventFilter>,
    pub timeline: Option<RoomEventFilter>,
    pub ephemeral: Option<RoomEventFilter>,
    pub state: Option<RoomEventFilter>,
    pub not_rooms: Vec<RoomId>,
    pub rooms: Vec<RoomId>,
}
Filters to be applied to room data

Fields

include_leave: Option<bool>

Include rooms that the user has left in the sync.

Defaults to false if not included.

account_data: Option<RoomEventFilter>

The per user account data to include for rooms.

timeline: Option<RoomEventFilter>

The message and state update events to include for rooms.

ephemeral: Option<RoomEventFilter>

The events that aren’t recorded in the room history, e.g. typing and receipts, to include for rooms.

state: Option<RoomEventFilter>

The state events to include for rooms.

not_rooms: Vec<RoomId>

A list of room IDs to exclude.

If this list is absent then no rooms are excluded. A matching room will be excluded even if it is listed in the ‘rooms’ filter. This filter is applied before the filters in ephemeral, state, timeline or account_data.

rooms: Vec<RoomId>

A list of room IDs to include.

If this list is absent then all rooms are included. This filter is applied before the filters in ephemeral, state, timeline or account_data.