Struct ruma_client_api::r0::keys::get_key_changes::Response [−][src]
Data in the response from the get_key_changes API endpoint.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.changed: Vec<UserId>The Matrix User IDs of all users who updated their device identity keys.
left: Vec<UserId>The Matrix User IDs of all users who may have left all the end-to-end encrypted rooms they previously shared with the user.
Implementations
impl Response[src]
pub fn new(changed: Vec<UserId>, left: Vec<UserId>) -> Self[src]
Creates a new Response with the given changed and left user ID lists.