Struct ruma_client_api::r0::keys::get_keys::IncomingRequest [−][src]
#[non_exhaustive]pub struct IncomingRequest { pub timeout: Option<Duration>, pub device_keys: BTreeMap<UserId, Vec<DeviceIdBox>>, pub token: Option<String>, }
‘Incoming’ variant of Request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timeout: Option<Duration>Expand description
The time (in milliseconds) to wait when downloading keys from remote servers. 10 seconds is the recommended default.
device_keys: BTreeMap<UserId, Vec<DeviceIdBox>>Expand description
The keys to be downloaded. An empty list indicates all devices for the corresponding user.
token: Option<String>Expand description
If the client is fetching keys as a result of a device update received in a sync request, this should be the ‘since’ token of that sync request, or any later sync token. This allows the server to ensure its response contains the keys advertised by the notification in that sync.