Struct ruma_client_api::r0::keys::get_keys::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub timeout: Option<Duration>, pub device_keys: BTreeMap<UserId, Vec<DeviceIdBox>>, pub token: Option<&'a str>, }
Data for a request to the get_keys API endpoint.
Returns the current devices and identity keys for the given users.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timeout: Option<Duration>The time (in milliseconds) to wait when downloading keys from remote servers. 10 seconds is the recommended default.
device_keys: BTreeMap<UserId, Vec<DeviceIdBox>>The keys to be downloaded. An empty list indicates all devices for the corresponding user.
token: Option<&'a str>If the client is fetching keys as a result of a device update received in a sync request, this should be the ‘since’ token of that sync request, or any later sync token. This allows the server to ensure its response contains the keys advertised by the notification in that sync.
Implementations