Enum ruma_client_api::r0::media::get_content_thumbnail::Method [−][src]
pub enum Method {
Crop,
Scale,
// some variants omitted
}Expand description
The desired resizing method.
Variants
Crop the original to produce the requested image dimensions.
Maintain the original aspect ratio of the source image.