[][src]Enum ruma_client_api::r0::media::get_content_thumbnail::Method

pub enum Method {
    Crop,
    Scale,
}

The desired resizing method.

Variants

Crop

Crop the original to produce the requested image dimensions.

Scale

Maintain the original aspect ratio of the source image.