Struct ruma_client_api::r0::media::get_content_thumbnail::Request
source · pub struct Request {
pub media_id: String,
pub server_name: String,
pub height: Option<u64>,
pub method: Option<Method>,
pub width: Option<u64>,
}Expand description
Data for a request to this API endpoint.
Fields
media_id: StringThe media ID from the mxc:// URI (the path component).
server_name: StringThe server name from the mxc:// URI (the authoritory component).
height: Option<u64>The desired height of the thumbnail. The actual thumbnail may not match the size specified.
method: Option<Method>The desired resizing method.
width: Option<u64>The desired width of the thumbnail. The actual thumbnail may not match the size specified.