Struct ruma_client_api::r0::membership::Invite3pid [−][src]
#[non_exhaustive]pub struct Invite3pid<'a> { pub id_server: &'a str, pub id_access_token: &'a str, pub medium: Medium, pub address: &'a str, }
Represents third party IDs to invite to the room.
To create an instance of this type, first create a Invite3pidInit and convert it via
Invite3pid::from / .into().
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id_server: &'a strExpand description
Hostname and port of identity server to be used for account lookups.
id_access_token: &'a strExpand description
An access token registered with the identity server.
medium: MediumExpand description
Type of third party ID.
address: &'a strExpand description
Third party identifier.