Struct ruma_client_api::r0::membership::Invite3pidInit[][src]

pub struct Invite3pidInit<'a> {
    pub id_server: &'a str,
    pub id_access_token: &'a str,
    pub medium: Medium,
    pub address: &'a str,
}
Initial set of fields of Invite3pid.

This struct will not be updated even if additional fields are added to Invite3pid in a new (non-breaking) release of the Matrix specification.

Fields

id_server: &'a str
Hostname and port of identity server to be used for account lookups.

id_access_token: &'a str
An access token registered with the identity server.

medium: Medium
Type of third party ID.

address: &'a str
Third party identifier.