Struct ruma_client_api::r0::membership::Invite3pidInit [−][src]
pub struct Invite3pidInit<'a> {
pub id_server: &'a str,
pub id_access_token: &'a str,
pub medium: Medium,
pub address: &'a str,
}Expand description
Initial set of fields of Invite3pid.
This struct will not be updated even if additional fields are added to Invite3pid in a new
(non-breaking) release of the Matrix specification.
Fields
id_server: &'a strExpand description
Hostname and port of identity server to be used for account lookups.
id_access_token: &'a strExpand description
An access token registered with the identity server.
medium: MediumExpand description
Type of third party ID.
address: &'a strExpand description
Third party identifier.