[−][src]Struct ruma_client_api::r0::membership::ThirdPartySigned
A signature of an m.third_party_invite token to prove that this user owns a third party
identity which has been invited to the room.
Fields
sender: StringThe Matrix ID of the user who issued the invite.
mxid: StringThe Matrix ID of the invitee.
token: StringThe state key of the m.third_party_invite event.
signatures: BTreeMap<String, BTreeMap<String, String>>A signatures object containing a signature of the entire signed object.