Struct ruma_client_api::r0::membership::ThirdPartySigned
source · pub struct ThirdPartySigned {
pub mxid: String,
pub sender: String,
pub signatures: Signatures,
pub token: String,
}Expand description
A signature of an m.third_party_invite token to prove that this user owns a third party
identity which has been invited to the room.
Fields
mxid: StringThe Matrix ID of the invitee.
sender: StringThe Matrix ID of the user who issued the invite.
signatures: SignaturesA signatures object containing a signature of the entire signed object.
token: StringThe state key of the m.third_party_invite event.