[−][src]Enum ruma_client_api::r0::message::get_message_events::Direction
The direction to return events from.
Variants
Return events backwards in time from the requested from token.
Return events forwards in time from the requested from token.