Struct ruma_client_api::r0::message::get_message_events::IncomingRequest [−][src]
#[non_exhaustive]pub struct IncomingRequest { pub room_id: RoomId, pub from: String, pub to: Option<String>, pub dir: Direction, pub limit: UInt, pub filter: Option<IncomingRoomEventFilter>, }
‘Incoming’ variant of Request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: RoomIdThe room to get events from.
from: StringThe token to start returning events from.
This token can be obtained from a prev_batch token returned for each room by the sync API, or from a start or end token returned by a previous request to this endpoint.
to: Option<String>The token to stop returning events at.
This token can be obtained from a prev_batch token returned for each room by the sync endpoint, or from a start or end token returned by a previous request to this endpoint.
dir: DirectionThe direction to return events from.
limit: UIntThe maximum number of events to return.
Default: 10.
filter: Option<IncomingRoomEventFilter>A RoomEventFilter to filter returned events with.