[−][src]Struct ruma_client_api::r0::message::get_message_events::Request
Data for a request to the get_message_events API endpoint.
Get message events for a room.
Fields (Non-exhaustive)
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: &'a RoomIdThe room to get events from.
from: &'a strThe token to start returning events from.
This token can be obtained from a prev_batch token returned for each room by the sync API, or from a start or end token returned by a previous request to this endpoint.
to: Option<&'a str>The token to stop returning events at.
This token can be obtained from a prev_batch token returned for each room by the sync endpoint, or from a start or end token returned by a previous request to this endpoint.
dir: DirectionThe direction to return events from.
limit: UIntThe maximum number of events to return.
Default: 10.
filter: Option<RoomEventFilter<'a>>A RoomEventFilter to filter returned events with.
Implementations
impl<'a> Request<'a>[src]
pub fn new(room_id: &'a RoomId, from: &'a str, dir: Direction) -> Self[src]
Creates a new Request with the given parameters.
All other parameters will be defaulted.
pub fn backward(room_id: &'a RoomId, from: &'a str) -> Self[src]
Creates a new Request with the given room ID and from token, and dir set to Backward.
pub fn forward(room_id: &'a RoomId, from: &'a str) -> Self[src]
Creates a new Request with the given room ID and from token, and dir set to Forward.