Struct ruma_client_api::r0::message::send_message_event::IncomingRequest [−][src]
pub struct IncomingRequest {
pub room_id: RoomId,
pub event_type: String,
pub txn_id: String,
pub body: Raw<AnyMessageEventContent>,
}Expand description
‘Incoming’ variant of Request.
Fields
room_id: RoomIdThe room to send the event to.
event_type: StringThe type of event to send.
txn_id: StringThe transaction ID for this event.
Clients should generate an ID unique across requests with the same access token; it will be used by the server to ensure idempotency of requests.
body: Raw<AnyMessageEventContent>The event content to send.