Struct ruma_client_api::r0::message::send_message_event::IncomingRequest [−][src]
#[non_exhaustive]pub struct IncomingRequest { pub room_id: RoomId, pub txn_id: String, pub content: AnyMessageEventContent, }
‘Incoming’ variant of Request.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: RoomIdThe room to send the event to.
txn_id: StringThe transaction ID for this event.
Clients should generate an ID unique across requests with the same access token; it will be used by the server to ensure idempotency of requests.
content: AnyMessageEventContentThe event content to send.