Struct ruma_client_api::r0::message::send_message_event::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub room_id: &'a RoomId, pub txn_id: &'a str, pub content: &'a AnyMessageEventContent, }
Data for a request to the send_message_event API endpoint.
Send a message event to a room.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: &'a RoomIdThe room to send the event to.
txn_id: &'a strThe transaction ID for this event.
Clients should generate an ID unique across requests with the same access token; it will be used by the server to ensure idempotency of requests.
content: &'a AnyMessageEventContentThe event content to send.
Implementations
impl<'a> Request<'a>[src]
pub fn new(
room_id: &'a RoomId,
txn_id: &'a str,
content: &'a AnyMessageEventContent
) -> Self[src]
room_id: &'a RoomId,
txn_id: &'a str,
content: &'a AnyMessageEventContent
) -> Self
Creates a new Request with the given room id, transaction id and event content.