[][src]Struct ruma_client_api::r0::push::get_notifications::IncomingRequest

#[non_exhaustive]pub struct IncomingRequest {
    pub from: Option<String>,
    pub limit: Option<UInt>,
    pub only: Option<String>,
}

'Incoming' variant of Request.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
from: Option<String>

Pagination token given to retrieve the next set of events.

limit: Option<UInt>

Limit on the number of events to return in this request.

only: Option<String>

Allows basic filtering of events returned. Supply "highlight" to return only events where the notification had the 'highlight' tweak set.