Struct ruma_client_api::r0::push::get_notifications::Notification [−][src]
#[non_exhaustive]pub struct Notification { pub actions: Vec<Action>, pub event: Raw<AnySyncRoomEvent>, pub profile_tag: Option<String>, pub read: bool, pub room_id: RoomId, pub ts: MilliSecondsSinceUnixEpoch, }
Represents a notification.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action>The actions to perform when the conditions for this rule are met.
event: Raw<AnySyncRoomEvent>The event that triggered the notification.
profile_tag: Option<String>The profile tag of the rule that matched this event.
read: boolIndicates whether the user has sent a read receipt indicating that they have read this message.
room_id: RoomIdThe ID of the room in which the event was posted.
ts: MilliSecondsSinceUnixEpochThe time at which the event notification was sent.
Implementations
impl Notification[src]
impl Notification[src]pub fn new(
actions: Vec<Action>,
event: Raw<AnySyncRoomEvent>,
read: bool,
room_id: RoomId,
ts: MilliSecondsSinceUnixEpoch
) -> Self[src]
pub fn new(
actions: Vec<Action>,
event: Raw<AnySyncRoomEvent>,
read: bool,
room_id: RoomId,
ts: MilliSecondsSinceUnixEpoch
) -> Self[src]Creates a new Notification with the given actions, event, read flag, room ID and
timestamp.