Struct ruma_client_api::r0::push::get_notifications::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub from: Option<&'a str>, pub limit: Option<UInt>, pub only: Option<&'a str>, }
Data for a request to the get_notifications API endpoint.
Paginate through the list of events that the user has been, or would have been notified about.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.from: Option<&'a str>Expand description
Pagination token given to retrieve the next set of events.
limit: Option<UInt>Expand description
Limit on the number of events to return in this request.
only: Option<&'a str>Expand description
Allows basic filtering of events returned. Supply “highlight” to return only events where the notification had the ‘highlight’ tweak set.
Implementations