Struct ruma_client_api::r0::push::get_notifications::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub from: Option<&'a str>, pub limit: Option<UInt>, pub only: Option<&'a str>, }
Data for a request to the get_notifications API endpoint.
Paginate through the list of events that the user has been, or would have been notified about.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.from: Option<&'a str>Pagination token given to retrieve the next set of events.
limit: Option<UInt>Limit on the number of events to return in this request.
only: Option<&'a str>Allows basic filtering of events returned. Supply “highlight” to return only events where the notification had the ‘highlight’ tweak set.
Implementations
impl<'a> Request<'a>[src]