Struct ruma_client_api::r0::push::get_notifications::Response [−][src]
#[non_exhaustive]pub struct Response { pub next_token: Option<String>, pub notifications: Vec<Notification>, }
Data in the response from the get_notifications API endpoint.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The token to supply in the from param of the next /notifications request in order to request more events. If this is absent, there are no more results.
notifications: Vec<Notification>The list of events that triggered notifications.
Implementations
impl Response[src]
pub fn new(notifications: Vec<Notification>) -> Self[src]
Creates a new Response with the given notifications.