Struct ruma_client_api::r0::push::get_pushers::Pusher [−][src]
pub struct Pusher {
pub pushkey: String,
pub kind: PusherKind,
pub app_id: String,
pub app_display_name: String,
pub device_display_name: String,
pub profile_tag: Option<String>,
pub lang: String,
pub data: PusherData,
}Expand description
Defines a pusher.
Fields
pushkey: StringExpand description
This is a unique identifier for this pusher. Max length, 512 bytes.
kind: PusherKindExpand description
The kind of the pusher.
app_id: StringExpand description
This is a reverse-DNS style identifier for the application. Max length, 64 chars.
app_display_name: StringExpand description
A string that will allow the user to identify what application owns this pusher.
device_display_name: StringExpand description
A string that will allow the user to identify what device owns this pusher.
profile_tag: Option<String>Expand description
This string determines which set of device specific rules this pusher executes.
lang: StringExpand description
The preferred language for receiving notifications (e.g. ‘en’ or ‘en-US’)
data: PusherDataExpand description
Information for the pusher implementation itself.