Struct ruma_client_api::r0::push::set_pusher::PusherInit [−][src]
pub struct PusherInit {
pub pushkey: String,
pub kind: Option<PusherKind>,
pub app_id: String,
pub app_display_name: String,
pub device_display_name: String,
pub profile_tag: Option<String>,
pub lang: String,
pub data: PusherData,
}Expand description
Initial set of fields of Pusher.
This struct will not be updated even if additional fields are added to Pusher in a new
(non-breaking) release of the Matrix specification.
Fields
pushkey: StringThis is a unique identifier for this pusher. Max length, 512 bytes.
kind: Option<PusherKind>The kind of the pusher. None deletes the pusher.
app_id: StringThis is a reverse-DNS style identifier for the application. Max length, 64 chars.
app_display_name: StringA string that will allow the user to identify what application owns this pusher.
device_display_name: StringA string that will allow the user to identify what device owns this pusher.
profile_tag: Option<String>This string determines which set of device specific rules this pusher executes.
lang: StringThe preferred language for receiving notifications (e.g. ‘en’ or ‘en-US’)
data: PusherDataInformation for the pusher implementation itself.