Struct ruma_client_api::r0::push::set_pusher::Request [−][src]
Data for a request to the set_pusher API endpoint.
This endpoint allows the creation, modification and deletion of pushers for this user ID.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pusher: PusherExpand description
The pusher to configure.
append: boolExpand description
Controls if another pusher with the same pushkey and app id should be created.
Defaults to false. See the spec for more details.
Implementations