[−][src]Struct ruma_client_api::r0::push::set_pushrule::Request
Data for a request to the set_pushrule API endpoint.
This endpoint allows the creation, modification and deletion of pushers for this user ID.
Fields (Non-exhaustive)
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope: &'a strThe scope to set the rule in. 'global' to specify global rules.
kind: RuleKindThe kind of rule
rule_id: &'a strThe identifier for the rule.
before: Option<&'a str>Use 'before' with a rule_id as its value to make the new rule the next-most important rule with respect to the given user defined rule.
after: Option<&'a str>This makes the new rule the next-less important rule relative to the given user defined rule.
actions: &'a [Action]The actions to perform when this rule is matched.
conditions: &'a [PushCondition]The conditions that must hold true for an event in order for a rule to be applied to an event. A rule with no conditions always matches. Only applicable to underride and override rules, empty Vec otherwise.
pattern: Option<&'a str>The glob-style pattern to match against. Only applicable to content rules.
Implementations
impl<'a> Request<'a>[src]
pub fn new(
scope: &'a str,
kind: RuleKind,
rule_id: &'a str,
actions: &'a [Action]
) -> Self[src]
scope: &'a str,
kind: RuleKind,
rule_id: &'a str,
actions: &'a [Action]
) -> Self
Creates a new Request with the given scope, rule kind, rule ID and actions.