Struct ruma_client_api::r0::push::set_pushrule_actions::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub scope: &'a str, pub kind: RuleKind, pub rule_id: &'a str, pub actions: Vec<Action>, }
Data for a request to the set_pushrule_actions API endpoint.
This endpoint allows clients to change the actions of a push rule. This can be used to change the actions of builtin rules.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope: &'a strThe scope to fetch a rule from. ‘global’ to specify global rules.
kind: RuleKindThe kind of rule
rule_id: &'a strThe identifier for the rule.
actions: Vec<Action>The actions to perform for this rule
Implementations
impl<'a> Request<'a>[src]
pub fn new(
scope: &'a str,
kind: RuleKind,
rule_id: &'a str,
actions: Vec<Action>
) -> Self[src]
scope: &'a str,
kind: RuleKind,
rule_id: &'a str,
actions: Vec<Action>
) -> Self
Creates a new Request with the given scope, rule kind, rule ID and actions.