Struct ruma_client_api::r0::push::PushRule [−][src]
#[non_exhaustive]pub struct PushRule { pub actions: Vec<Action>, pub default: bool, pub enabled: bool, pub rule_id: String, pub conditions: Option<Vec<PushCondition>>, pub pattern: Option<String>, }
Like SimplePushRule, but may represent any kind of push rule
thanks to pattern and conditions being optional.
To create an instance of this type, use one of its From implementations.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action>The actions to perform when this rule is matched.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.
conditions: Option<Vec<PushCondition>>The conditions that must hold true for an event in order for a rule to be applied to an event. A rule with no conditions always matches.
Only applicable to underride and override rules.
pattern: Option<String>The glob-style pattern to match against. Only applicable to content rules.