Struct ruma_client_api::r0::read_marker::set_read_marker::IncomingRequest [−][src]
pub struct IncomingRequest {
pub room_id: RoomId,
pub fully_read: EventId,
pub read_receipt: Option<EventId>,
}Expand description
‘Incoming’ variant of Request.
Fields
room_id: RoomIdThe room ID to set the read marker in for the user.
fully_read: EventIdThe event ID the read marker should be located at. The event MUST belong to the room.
read_receipt: Option<EventId>The event ID to set the read receipt location at. This is equivalent to calling the create_read_receipt endpoint and is provided here to save that extra call.