Struct ruma_client_api::r0::redact::redact_event::IncomingRequest [−][src]
pub struct IncomingRequest {
pub room_id: RoomId,
pub event_id: EventId,
pub txn_id: String,
pub reason: Option<String>,
}Expand description
‘Incoming’ variant of Request.
Fields
room_id: RoomIdThe ID of the room of the event to redact.
event_id: EventIdThe ID of the event to redact.
txn_id: StringThe transaction ID for this event.
Clients should generate a unique ID; it will be used by the server to ensure idempotency of requests.
reason: Option<String>The reason for the redaction.