Struct ruma_client_api::r0::redact::redact_event::IncomingRequest [−][src]
#[non_exhaustive]pub struct IncomingRequest { pub room_id: RoomId, pub event_id: EventId, pub txn_id: String, pub reason: Option<String>, }
‘Incoming’ variant of Request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: RoomIdExpand description
The ID of the room of the event to redact.
event_id: EventIdExpand description
The ID of the event to redact.
txn_id: StringExpand description
The transaction ID for this event.
Clients should generate a unique ID; it will be used by the server to ensure idempotency of requests.
reason: Option<String>Expand description
The reason for the redaction.