Struct ruma_client_api::r0::redact::redact_event::Request
source · pub struct Request {
pub event_id: EventId,
pub reason: Option<String>,
pub room_id: RoomId,
pub txn_id: String,
}Expand description
Data for a request to this API endpoint.
Fields
event_id: EventIdThe ID of the event to redact.
reason: Option<String>The reason for the redaction.
room_id: RoomIdThe ID of the room of the event to redact.
txn_id: StringThe transaction ID for this event.
Clients should generate a unique ID; it will be used by the server to ensure idempotency of requests.