[−][src]Enum ruma_client_api::r0::room::create_room::Visibility
Whether or not a newly created room will be listed in the room directory.
Variants
PublicIndicates that the room will be shown in the published room list.
PrivateIndicates that the room from the published room list.