Enum ruma_client_api::r0::room::create_room::Visibility
source · pub enum Visibility {
Public,
Private,
}Expand description
Whether or not a newly created room will be listed in the room directory.
Variants
Public
Indicates that the room will be shown in the published room list.
Private
Indicates that the room from the published room list.