Struct ruma_client_api::r0::room::create_room::Request [−][src]
pub struct Request<'a> {
pub creation_content: CreationContent,
pub initial_state: &'a [AnyInitialStateEvent],
pub invite: &'a [UserId],
pub invite_3pid: &'a [Invite3pid<'a>],
pub is_direct: bool,
pub name: Option<&'a str>,
pub power_level_content_override: Option<Raw<PowerLevelsEventContent>>,
pub preset: Option<RoomPreset>,
pub room_alias_name: Option<&'a str>,
pub room_version: Option<&'a RoomVersionId>,
pub topic: Option<&'a str>,
pub visibility: Visibility,
}Expand description
Data for a request to the create_room API endpoint.
Create a new room.
Fields
creation_content: CreationContentExtra keys to be added to the content of the m.room.create.
initial_state: &'a [AnyInitialStateEvent]List of state events to send to the new room.
Takes precedence over events set by preset, but gets overridden by name and topic keys.
invite: &'a [UserId]A list of user IDs to invite to the room.
This will tell the server to invite everyone in the list to the newly created room.
invite_3pid: &'a [Invite3pid<'a>]List of third party IDs of users to invite.
is_direct: boolIf set, this sets the is_direct flag on room invites.
name: Option<&'a str>If this is included, an m.room.name event will be sent into the room to indicate
the name of the room.
power_level_content_override: Option<Raw<PowerLevelsEventContent>>Power level content to override in the default power level event.
preset: Option<RoomPreset>Convenience parameter for setting various default state events based on a preset.
room_alias_name: Option<&'a str>The desired room alias local part.
room_version: Option<&'a RoomVersionId>Room version to set for the room. Defaults to homeserver’s default if not specified.
topic: Option<&'a str>If this is included, an m.room.topic event will be sent into the room to indicate
the topic for the room.
visibility: VisibilityA public visibility indicates that the room will be shown in the published room list. A private visibility will hide the room from the published room list.
Defaults to Private.
Implementations