Struct ruma_client_api::r0::room::create_room::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub creation_content: CreationContent, pub initial_state: &'a [AnyInitialStateEvent], pub invite: &'a [UserId], pub invite_3pid: &'a [Invite3pid<'a>], pub is_direct: bool, pub name: Option<&'a str>, pub power_level_content_override: Option<Raw<PowerLevelsEventContent>>, pub preset: Option<RoomPreset>, pub room_alias_name: Option<&'a str>, pub room_version: Option<&'a RoomVersionId>, pub topic: Option<&'a str>, pub visibility: Visibility, }
Data for a request to the create_room API endpoint.
Create a new room.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creation_content: CreationContentExpand description
Extra keys to be added to the content of the m.room.create.
initial_state: &'a [AnyInitialStateEvent]Expand description
List of state events to send to the new room.
Takes precedence over events set by preset, but gets overriden by name and topic keys.
invite: &'a [UserId]Expand description
A list of user IDs to invite to the room.
This will tell the server to invite everyone in the list to the newly created room.
invite_3pid: &'a [Invite3pid<'a>]Expand description
List of third party IDs of users to invite.
is_direct: boolExpand description
If set, this sets the is_direct flag on room invites.
name: Option<&'a str>Expand description
If this is included, an m.room.name event will be sent into the room to indicate
the name of the room.
power_level_content_override: Option<Raw<PowerLevelsEventContent>>Expand description
Power level content to override in the default power level event.
preset: Option<RoomPreset>Expand description
Convenience parameter for setting various default state events based on a preset.
room_alias_name: Option<&'a str>Expand description
The desired room alias local part.
room_version: Option<&'a RoomVersionId>Expand description
Room version to set for the room. Defaults to homeserver’s default if not specified.
topic: Option<&'a str>Expand description
If this is included, an m.room.topic event will be sent into the room to indicate
the topic for the room.
visibility: VisibilityExpand description
A public visibility indicates that the room will be shown in the published room list. A private visibility will hide the room from the published room list.
Defaults to Private.
Implementations