[−][src]Struct ruma_client_api::r0::room::create_room::Request
Data for a request to the create_room API endpoint.
Create a new room.
Fields
creation_content: Option<CreationContent>Extra keys to be added to the content of the m.room.create.
initial_state: Vec<InitialStateEvent>List of state events to send to the new room.
Takes precedence over events set by preset, but gets overriden by name and topic keys.
invite: Vec<UserId>A list of user IDs to invite to the room.
This will tell the server to invite everyone in the list to the newly created room.
invite_3pid: Vec<Invite3pid>List of third party IDs of users to invite.
is_direct: Option<bool>If set, this sets the is_direct flag on room invites.
name: Option<String>If this is included, an m.room.name event will be sent into the room to indicate
the name of the room.
power_level_content_override: Option<EventJson<PowerLevelsEventContent>>Power level content to override in the default power level event.
preset: Option<RoomPreset>Convenience parameter for setting various default state events based on a preset.
room_alias_name: Option<String>The desired room alias local part.
room_version: Option<String>Room version to set for the room. Defaults to homeserver's default if not specified.
topic: Option<String>If this is included, an m.room.topic event will be sent into the room to indicate
the topic for the room.
visibility: Option<Visibility>A public visibility indicates that the room will be shown in the published room list. A private visibility will hide the room from the published room list. Rooms default to private visibility if this key is not included.