pub struct Request {
    pub creation_content: Option<CreationContent>,
    pub invite: Vec<UserId>,
    pub name: Option<String>,
    pub preset: Option<RoomPreset>,
    pub room_alias_name: Option<String>,
    pub topic: Option<String>,
    pub visibility: Option<Visibility>,
}
Data for a request to this API endpoint.

Fields

creation_content: Option<CreationContent>

Extra keys to be added to the content of the m.room.create.

invite: Vec<UserId>

A list of user IDs to invite to the room.

This will tell the server to invite everyone in the list to the newly created room.

name: Option<String>

If this is included, an m.room.name event will be sent into the room to indicate the name of the room.

preset: Option<RoomPreset>

Convenience parameter for setting various default state events based on a preset.

room_alias_name: Option<String>

The desired room alias local part.

topic: Option<String>

If this is included, an m.room.topic event will be sent into the room to indicate the topic for the room.

visibility: Option<Visibility>

A public visibility indicates that the room will be shown in the published room list. A private visibility will hide the room from the published room list. Rooms default to private visibility if this key is not included.