[−][src]Enum ruma_client_api::r0::room::Visibility
Whether or not a newly created room will be listed in the room directory.
Variants
Indicates that the room will be shown in the published room list.
Indicates that the room will not be shown in the published room list.