pub struct Request {
pub password: String,
pub medium: Option<Medium>,
pub login_type: LoginType,
pub user: String,
pub address: Option<String>,
pub device_id: Option<String>,
}Expand description
Data for a request to this API endpoint.
Fields
password: StringThe user’s password.
medium: Option<Medium>When logging in using a third party identifier, the medium of the identifier.
login_type: LoginTypeThe authentication mechanism.
user: StringThe fully qualified user ID or just local part of the user ID.
address: Option<String>Third party identifier for the user.
device_id: Option<String>ID of the client device