[−][src]Struct ruma_client_api::r0::session::login::Response
Data in the response from the login API endpoint.
Fields (Non-exhaustive)
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: UserIdThe fully-qualified Matrix ID that has been registered.
access_token: StringAn access token for the account.
home_server: Option<ServerNameBox>The hostname of the homeserver on which the account has been registered.
Deprecated: Clients should instead use the user_id.server_name()
method if they require it.
device_id: DeviceIdBoxID of the logged-in device.
Will be the same as the corresponding parameter in the request, if one was specified.
well_known: Option<DiscoveryInfo>Client configuration provided by the server.
If present, clients SHOULD use the provided object to reconfigure themselves.
Implementations
impl Response[src]
pub fn new(
user_id: UserId,
access_token: String,
device_id: DeviceIdBox
) -> Self[src]
user_id: UserId,
access_token: String,
device_id: DeviceIdBox
) -> Self
Creates a new Response with the given user ID, access token and device ID.