[−][src]Struct ruma_client_api::r0::session::login::Response
Data in the response from the login API endpoint.
Fields
access_token: StringAn access token for the account.
home_server: StringThe hostname of the homeserver on which the account has been registered.
refresh_token: Option<String>A refresh token may be exchanged for a new access token using the /tokenrefresh API endpoint.
user_id: UserIdThe fully-qualified Matrix ID that has been registered.
device_id: StringID of the logged-in device.
Will be the same as the corresponging parameter in the request, if one was specified.