[][src]Struct ruma_client_api::r0::session::login::Response

pub struct Response {
    pub access_token: String,
    pub home_server: String,
    pub refresh_token: Option<String>,
    pub user_id: UserId,
    pub device_id: String,
}

Data in the response from this API endpoint.

Fields

access_token: String

An access token for the account.

home_server: String

The hostname of the homeserver on which the account has been registered.

refresh_token: Option<String>

A refresh token may be exchanged for a new access token using the /tokenrefresh API endpoint.

user_id: UserId

The fully-qualified Matrix ID that has been registered.

device_id: String

ID of the logged-in device.

Will be the same as the corresponging parameter in the request, if one was specified.