[][src]Enum ruma_client_api::r0::sync::get_message_events::Direction

pub enum Direction {
    Backward,
    Forward,
}

The direction to return events from.

Variants

Backward

Return events backwards in time from the requested from token.

Forward

Return events forwards in time from the requested from token.