[−][src]Enum ruma_client_api::r0::sync::get_message_events::Direction
The direction to return events from.
Variants
BackwardReturn events backwards in time from the requested from token.
ForwardReturn events forwards in time from the requested from token.