[][src]Module ruma_client_api::r0::sync::sync_events

Structs

AccountData

The private data that this user has attached to this room.

Endpoint

The API endpoint.

Ephemeral

Ephemeral events not recorded in the timeline or state of the room.

InviteState

The state of a room that the user has been invited to.

InvitedRoom

Updates to the rooms that the user has been invited to.

JoinedRoom

Updates to joined rooms.

LeftRoom

Historical updates to left rooms.

Presence

Updates to the presence status of other users.

Request

Data for a request to this API endpoint.

Response

Data in the response from this API endpoint.

Rooms

Updates to rooms.

State

State events in the room.

Timeline

Events in the room.

UnreadNotificationsCount

unread notifications count

Enums

Filter

A filter represented either as its full JSON definition or the ID of a saved filter.

SetPresence

Whether to set presence or not during sync.