Structs

The private data that this user has attached to this room.
The API endpoint.
Ephemeral events not recorded in the timeline or state of the room.
The state of a room that the user has been invited to.
Updates to the rooms that the user has been invited to.
Updates to joined rooms.
Historical updates to left rooms.
Updates to the presence status of other users.
Data for a request to this API endpoint.
Data in the response from this API endpoint.
Updates to rooms.
State events in the room.
Events in the room.
unread notifications count

Enums

A filter represented either as its full JSON definition or the ID of a saved filter.
Whether to set presence or not during sync.