[][src]Struct ruma_client_api::r0::sync::sync_events::IncomingRequest

#[non_exhaustive]pub struct IncomingRequest {
    pub filter: Option<IncomingFilter>,
    pub since: Option<String>,
    pub full_state: bool,
    pub set_presence: PresenceState,
    pub timeout: Option<Duration>,
}

'Incoming' variant of Request.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
filter: Option<IncomingFilter>

A filter represented either as its full JSON definition or the ID of a saved filter.

since: Option<String>

A point in time to continue a sync from.

Should be a token from the next_batch field of a previous /sync request.

full_state: bool

Controls whether to include the full state for all rooms the user is a member of.

set_presence: PresenceState

Controls whether the client is automatically marked as online by polling this API.

Defaults to PresenceState::Online.

timeout: Option<Duration>

The maximum time to poll in milliseconds before returning this request.