Struct ruma_client_api::r0::sync::sync_events::InvitedRoom[][src]

#[non_exhaustive]
pub struct InvitedRoom { pub invite_state: InviteState, }

Updates to the rooms that the user has been invited to.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
invite_state: InviteState

The state of a room that the user has been invited to.

Implementations

impl InvitedRoom[src]

pub fn new() -> Self[src]

Creates an empty InvitedRoom.

pub fn is_empty(&self) -> bool[src]

Returns true if there are no updates to this room.