[−][src]Struct ruma_client_api::r0::sync::sync_events::InvitedRoom
Updates to the rooms that the user has been invited to.
Fields
invite_state: InviteStateThe state of a room that the user has been invited to.