Struct ruma_client_api::r0::sync::sync_events::InvitedRoom [] [src]

pub struct InvitedRoom {
    pub invite_state: InviteState,
}

Updates to the rooms that the user has been invited to.

Fields

The state of a room that the user has been invited to.