Struct ruma_client_api::r0::sync::sync_events::JoinedRoom [−][src]
pub struct JoinedRoom {
pub summary: RoomSummary,
pub unread_notifications: UnreadNotificationsCount,
pub timeline: Timeline,
pub state: State,
pub account_data: RoomAccountData,
pub ephemeral: Ephemeral,
// some fields omitted
}Expand description
Updates to joined rooms.
Fields
summary: RoomSummaryExpand description
Information about the room which clients may need to correctly render it to users.
unread_notifications: UnreadNotificationsCountExpand description
Counts of unread notifications for this room.
timeline: TimelineExpand description
The timeline of messages and state changes in the room.
state: StateExpand description
Updates to the state, between the time indicated by the since parameter, and the start
of the timeline (or all state up to the start of the timeline, if since is not
given, or full_state is true).
account_data: RoomAccountDataExpand description
The private data that this user has attached to this room.
ephemeral: EphemeralExpand description
The ephemeral events in the room that aren’t recorded in the timeline or state of the room. e.g. typing.
Implementations
impl JoinedRoom[src]
impl JoinedRoom[src]Trait Implementations
impl Clone for JoinedRoom[src]
impl Clone for JoinedRoom[src]fn clone(&self) -> JoinedRoom[src]
fn clone(&self) -> JoinedRoom[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for JoinedRoom[src]
impl Debug for JoinedRoom[src]impl Default for JoinedRoom[src]
impl Default for JoinedRoom[src]impl<'de> Deserialize<'de> for JoinedRoom[src]
impl<'de> Deserialize<'de> for JoinedRoom[src]fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
impl Serialize for JoinedRoom[src]
impl Serialize for JoinedRoom[src]Auto Trait Implementations
impl RefUnwindSafe for JoinedRoom
impl Send for JoinedRoom
impl Sync for JoinedRoom
impl Unpin for JoinedRoom
impl UnwindSafe for JoinedRoom