[][src]Struct ruma_client_api::r0::sync::sync_events::JoinedRoom

pub struct JoinedRoom {
    pub unread_notifications: UnreadNotificationsCount,
    pub timeline: Timeline,
    pub state: State,
    pub account_data: AccountData,
    pub ephemeral: Ephemeral,
}

Updates to joined rooms.

Fields

unread_notifications: UnreadNotificationsCount

Counts of unread notifications for this room.

timeline: Timeline

The timeline of messages and state changes in the room.

state: State

Updates to the state, between the time indicated by the since parameter, and the start of the timeline (or all state up to the start of the timeline, if since is not given, or full_state is true).

account_data: AccountData

The private data that this user has attached to this room.

ephemeral: Ephemeral

The ephemeral events in the room that aren't recorded in the timeline or state of the room. e.g. typing.