Struct ruma_client_api::r0::sync::sync_events::LeftRoom [−][src]
#[non_exhaustive]pub struct LeftRoom { pub timeline: Timeline, pub state: State, pub account_data: AccountData, }
Historical updates to left rooms.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timeline: TimelineThe timeline of messages and state changes in the room up to the point when the user left.
state: StateThe state updates for the room up to the start of the timeline.
account_data: AccountDataThe private data that this user has attached to this room.
Implementations
impl LeftRoom[src]
pub fn new() -> Self[src]
Creates an empty LeftRoom.
pub fn is_empty(&self) -> bool[src]
Returns true if there are updates in the room.