Struct ruma_client_api::r0::sync::sync_events::LeftRoom
source · Expand description
Historical updates to left rooms.
Fields
timeline: TimelineThe timeline of messages and state changes in the room up to the point when the user left.
state: StateThe state updates for the room up to the start of the timeline.