Struct ruma_client_api::r0::sync::sync_events::LeftRoom [] [src]

pub struct LeftRoom {
    pub timeline: Timeline,
    pub state: State,
}

Historical updates to left rooms.

Fields

The timeline of messages and state changes in the room up to the point when the user left.

The state updates for the room up to the start of the timeline.