Struct ruma_client_api::r0::sync::sync_events::Request [−][src]
#[non_exhaustive]pub struct Request<'a> { pub filter: Option<&'a Filter<'a>>, pub since: Option<&'a str>, pub full_state: bool, pub set_presence: &'a PresenceState, pub timeout: Option<Duration>, }
Data for a request to the sync API endpoint.
Get all new events from all rooms since the last sync or a given point of time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter: Option<&'a Filter<'a>>A filter represented either as its full JSON definition or the ID of a saved filter.
since: Option<&'a str>A point in time to continue a sync from.
Should be a token from the next_batch field of a previous /sync
request.
full_state: boolControls whether to include the full state for all rooms the user is a member of.
set_presence: &'a PresenceStateControls whether the client is automatically marked as online by polling this API.
Defaults to PresenceState::Online.
timeout: Option<Duration>The maximum time to poll in milliseconds before returning this request.
Implementations