[−][src]Struct ruma_client_api::r0::sync::sync_events::Request
Data for a request to the sync API endpoint.
Get all new events from all rooms since the last sync or a given point of time.
Fields
filter: Option<Filter>A filter represented either as its full JSON definition or the ID of a saved filter.
since: Option<String>A point in time to continue a sync from.
Should be a token from the next_batch field of a previous /sync
request.
full_state: boolControls whether to include the full state for all rooms the user is a member of.
set_presence: SetPresenceControls whether the client is automatically marked as online by polling this API.
timeout: Option<Duration>The maximum time to poll in milliseconds before returning this request.