[−][src]Struct ruma_client_api::r0::sync::sync_events::Request
Data for a request to this API endpoint.
Fields
filter: Option<Filter>A filter represented either as its full JSON definition or the ID of a saved filter.
since: Option<String>A point in time to continue a sync from.
full_state: Option<bool>Controls whether to include the full state for all rooms the user is a member of.
set_presence: Option<SetPresence>Controls whether the client is automatically marked as online by polling this API.
timeout: Option<u64>The maximum time to poll in milliseconds before returning this request.