Struct ruma_client_api::r0::sync::sync_events::Response [−][src]
#[non_exhaustive]pub struct Response { pub next_batch: String, pub rooms: Rooms, pub presence: Presence, pub account_data: AccountData, pub to_device: ToDevice, pub device_lists: DeviceLists, pub device_one_time_keys_count: BTreeMap<DeviceKeyAlgorithm, UInt>, }
Data in the response from the sync API endpoint.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_batch: StringThe batch token to supply in the since param of the next /sync request.
rooms: RoomsUpdates to rooms.
presence: PresenceUpdates to the presence status of other users.
account_data: AccountDataThe global private data created by this user.
to_device: ToDeviceMessages sent dirrectly between devices.
device_lists: DeviceListsInformation on E2E device updates.
Only present on an incremental sync.
device_one_time_keys_count: BTreeMap<DeviceKeyAlgorithm, UInt>For each key algorithm, the number of unclaimed one-time keys currently held on the server for a device.
Implementations
impl Response[src]