[−][src]Struct ruma_client_api::r0::sync::sync_events::Response
Data in the response from the sync API endpoint.
Fields
next_batch: StringThe batch token to supply in the since param of the next /sync request.
rooms: RoomsUpdates to rooms.
presence: PresenceUpdates to the presence status of other users.
account_data: AccountDataThe global private data created by this user.
to_device: ToDeviceMessages sent dirrectly between devices.
device_lists: DeviceListsInformation on E2E device updates.
Only present on an incremental sync.
device_one_time_keys_count: BTreeMap<KeyAlgorithm, UInt>For each key algorithm, the number of unclaimed one-time keys currently held on the server for a device.