Struct ruma_client_api::r0::sync::sync_events::Rooms [−][src]
pub struct Rooms {
pub leave: BTreeMap<RoomId, LeftRoom>,
pub join: BTreeMap<RoomId, JoinedRoom>,
pub invite: BTreeMap<RoomId, InvitedRoom>,
}Expand description
Updates to rooms.
Fields
leave: BTreeMap<RoomId, LeftRoom>The rooms that the user has left or been banned from.
join: BTreeMap<RoomId, JoinedRoom>The rooms that the user has joined.
invite: BTreeMap<RoomId, InvitedRoom>The rooms that the user has been invited to.
Implementations