[][src]Struct ruma_client_api::r0::sync::sync_events::Rooms

pub struct Rooms {
    pub leave: HashMap<RoomId, LeftRoom>,
    pub join: HashMap<RoomId, JoinedRoom>,
    pub invite: HashMap<RoomId, InvitedRoom>,
}

Updates to rooms.

Fields

leave: HashMap<RoomId, LeftRoom>

The rooms that the user has left or been banned from.

join: HashMap<RoomId, JoinedRoom>

The rooms that the user has joined.

invite: HashMap<RoomId, InvitedRoom>

The rooms that the user has been invited to.