Struct ruma_client_api::r0::sync::sync_events::Rooms [] [src]

pub struct Rooms {
    pub leave: HashMap<RoomId, LeftRoom>,
    pub join: HashMap<RoomId, JoinedRoom>,
    pub invite: HashMap<RoomId, InvitedRoom>,
}

Updates to rooms.

Fields

The rooms that the user has left or been banned from.

The rooms that the user has joined.

The rooms that the user has been invited to.