Struct ruma_client_api::r0::sync::sync_events::Timeline [−][src]
pub struct Timeline {
pub limited: bool,
pub prev_batch: Option<String>,
pub events: Vec<Raw<AnySyncRoomEvent>>,
// some fields omitted
}Expand description
Events in the room.
Fields
limited: boolExpand description
True if the number of events returned was limited by the limit on the filter.
Default to false.
prev_batch: Option<String>Expand description
A token that can be supplied to to the from parameter of the /rooms/{roomId}/messages
endpoint.
events: Vec<Raw<AnySyncRoomEvent>>Expand description
A list of events.
Implementations