Struct ruma_client_api::r0::sync::sync_events::Timeline [−][src]
#[non_exhaustive]pub struct Timeline { pub limited: bool, pub prev_batch: Option<String>, pub events: Vec<Raw<AnySyncRoomEvent>>, }
Events in the room.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.limited: boolTrue if the number of events returned was limited by the limit on the filter.
prev_batch: Option<String>A token that can be supplied to to the from parameter of the
/rooms/{roomId}/messages endpoint.
events: Vec<Raw<AnySyncRoomEvent>>A list of events.
Implementations
impl Timeline[src]
pub fn new() -> Self[src]
Creates an empty Timeline.
pub fn is_empty(&self) -> bool[src]
Returns true if there are no timeline updates.