[−][src]Struct ruma_client_api::r0::sync::sync_events::Timeline
Events in the room.
Fields
limited: boolTrue if the number of events returned was limited by the limit on the filter.
prev_batch: StringA token that can be supplied to to the from parameter of the
/rooms/{roomId}/messages endpoint.
events: Vec<RoomEvent>A list of events.