Struct ruma_client_api::r0::sync::sync_events::Timeline [] [src]

pub struct Timeline {
    pub limited: bool,
    pub prev_batch: String,
    pub events: Vec<StateEvent>,
}

Events in the room.

Fields

True if the number of events returned was limited by the limit on the filter.

A token that can be supplied to to the from parameter of the /rooms/{roomId}/messages endpoint.

A list of events.