Struct ruma_client_api::r0::sync::sync_events::Timeline
[−]
[src]
pub struct Timeline {
pub limited: bool,
pub prev_batch: String,
pub events: Vec<StateEvent>,
}Events in the room.
Fields
limited: bool
True if the number of events returned was limited by the limit on the filter.
prev_batch: String
A token that can be supplied to to the from parameter of the
/rooms/{roomId}/messages endpoint.
events: Vec<StateEvent>
A list of events.