Struct ruma_client_api::r0::sync::sync_events::UnreadNotificationsCount[][src]

#[non_exhaustive]
pub struct UnreadNotificationsCount { pub highlight_count: Option<UInt>, pub notification_count: Option<UInt>, }

unread notifications count

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
highlight_count: Option<UInt>

The number of unread notifications for this room with the highlight flag set.

notification_count: Option<UInt>

The total number of unread notifications for this room.

Implementations

impl UnreadNotificationsCount[src]

pub fn new() -> Self[src]

Creates an empty UnreadNotificationsCount.

pub fn is_empty(&self) -> bool[src]

Returns true if there are no notification count updates.