Struct ruma_client_api::r0::sync::sync_events::UnreadNotificationsCount
source · pub struct UnreadNotificationsCount {
pub highlight_count: Option<u64>,
pub notification_count: Option<u64>,
}Expand description
unread notifications count
Fields
highlight_count: Option<u64>The number of unread notifications for this room with the highlight flag set.
notification_count: Option<u64>The total number of unread notifications for this room.