Struct ruma_client_api::r0::sync::sync_events::UnreadNotificationsCount [] [src]

pub struct UnreadNotificationsCount {
    pub highlight_count: u64,
    pub notification_count: u64,
}

unread notifications count

Fields

The number of unread notifications for this room with the highlight flag set.

The total number of unread notifications for this room.