Enum ruma_client_api::r0::uiaa::AuthData[][src]

#[non_exhaustive]
pub enum AuthData<'a> {
    DirectRequest {
        kind: &'a str,
        session: Option<&'a str>,
        auth_parameters: BTreeMap<String, JsonValue>,
    },
    FallbackAcknowledgement {
        session: &'a str,
    },
}
Additional authentication information for the user-interactive authentication API.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DirectRequest
Used for sending UIAA authentication requests to the homeserver directly from the client.

Show fields

Fields of DirectRequest

kind: &'a str
The login type that the client is attempting to complete.

session: Option<&'a str>
The value of the session key given by the homeserver.

auth_parameters: BTreeMap<String, JsonValue>
Parameters submitted for a particular authentication stage.

FallbackAcknowledgement
Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.

Show fields

Fields of FallbackAcknowledgement

session: &'a str
The value of the session key given by the homeserver.

Implementations

impl<'a> AuthData<'a>[src]

pub fn direct_request(kind: &'a str) -> Self[src]

Creates a new AuthData::DirectRequest with the given login type.

pub fn fallback_acknowledgement(session: &'a str) -> Self[src]

Creates a new AuthData::FallbackAcknowledgement with the given session key.