Enum ruma_client_api::r0::uiaa::AuthData [−][src]
#[non_exhaustive]
pub enum AuthData<'a> {
DirectRequest {
kind: &'a str,
session: Option<&'a str>,
auth_parameters: BTreeMap<String, JsonValue>,
},
FallbackAcknowledgement {
session: &'a str,
},
}Expand description
Additional authentication information for the user-interactive authentication API.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Used for sending UIAA authentication requests to the homeserver directly from the client.
Show fields
Fields of DirectRequest
kind: &'a strExpand description
The login type that the client is attempting to complete.
session: Option<&'a str>Expand description
The value of the session key given by the homeserver.
auth_parameters: BTreeMap<String, JsonValue>Expand description
Parameters submitted for a particular authentication stage.
Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.
Show fields
Fields of FallbackAcknowledgement
session: &'a strExpand description
The value of the session key given by the homeserver.
Implementations
impl<'a> AuthData<'a>[src]
impl<'a> AuthData<'a>[src]pub fn direct_request(kind: &'a str) -> Self[src]
pub fn direct_request(kind: &'a str) -> Self[src]Creates a new AuthData::DirectRequest with the given login type.
pub fn fallback_acknowledgement(session: &'a str) -> Self[src]
pub fn fallback_acknowledgement(session: &'a str) -> Self[src]Creates a new AuthData::FallbackAcknowledgement with the given session key.