[][src]Enum ruma_client_api::r0::uiaa::AuthData

pub enum AuthData<'a> {
    DirectRequest {
        kind: &'a str,
        session: Option<&'a str>,
        auth_parameters: BTreeMap<String, JsonValue>,
    },
    FallbackAcknowledgement {
        session: &'a str,
    },
}

Additional authentication information for the user-interactive authentication API.

Variants

DirectRequest

Used for sending UIAA authentication requests to the homeserver directly from the client.

Fields of DirectRequest

kind: &'a str

The login type that the client is attempting to complete.

session: Option<&'a str>

The value of the session key given by the homeserver.

auth_parameters: BTreeMap<String, JsonValue>

Parameters submitted for a particular authentication stage.

FallbackAcknowledgement

Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.

Fields of FallbackAcknowledgement

session: &'a str

The value of the session key given by the homeserver.