[−][src]Enum ruma_client_api::r0::uiaa::AuthData
Additional authentication information for the user-interactive authentication API.
Variants
Used for sending UIAA authentication requests to the homeserver directly from the client.
Fields of DirectRequest
Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.
Fields of FallbackAcknowledgement
session: &'a strThe value of the session key given by the homeserver.