Enum ruma_client_api::r0::uiaa::IncomingAuthData [−][src]
#[non_exhaustive]
pub enum IncomingAuthData {
DirectRequest {
kind: String,
session: Option<String>,
auth_parameters: BTreeMap<String, JsonValue>,
},
FallbackAcknowledgement {
session: String,
},
}Expand description
‘Incoming’ variant of AuthData.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Used for sending UIAA authentication requests to the homeserver directly from the client.
Show fields
Fields of DirectRequest
kind: StringExpand description
The login type that the client is attempting to complete.
session: Option<String>Expand description
The value of the session key given by the homeserver.
auth_parameters: BTreeMap<String, JsonValue>Expand description
Parameters submitted for a particular authentication stage.
Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.
Show fields
Fields of FallbackAcknowledgement
session: StringExpand description
The value of the session key given by the homeserver.