Enum ruma_client_api::r0::uiaa::IncomingAuthData [−][src]
#[non_exhaustive]
pub enum IncomingAuthData {
DirectRequest {
kind: String,
session: Option<String>,
auth_parameters: BTreeMap<String, JsonValue>,
},
FallbackAcknowledgement {
session: String,
},
}‘Incoming’ variant of AuthData.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Used for sending UIAA authentication requests to the homeserver directly from the client.
Fields of DirectRequest
Used by the client to acknowledge that the user has completed a UIAA stage through the fallback method.
Fields of FallbackAcknowledgement
session: StringThe value of the session key given by the homeserver.