pub struct IncomingRequest {
pub room_id: OwnedRoomId,
pub fully_read: Option<OwnedEventId>,
pub read_receipt: Option<OwnedEventId>,
pub private_read_receipt: Option<OwnedEventId>,
}Available on crate features
client or server only.Expand description
‘Incoming’ variant of Request.
Fields
room_id: OwnedRoomIdThe room ID to set the read marker in for the user.
fully_read: Option<OwnedEventId>Available on crate feature
unstable-msc2285 only.The event ID the fully-read marker should be located at.
The event MUST belong to the room.
This is equivalent to calling the create_receipt endpoint with a
ReceiptType::FullyRead.
Without the unstable-msc2285 feature, this field is required.
read_receipt: Option<OwnedEventId>The event ID to set the public read receipt location at.
This is equivalent to calling the create_receipt endpoint with a
ReceiptType::Read.
private_read_receipt: Option<OwnedEventId>Available on crate feature
unstable-msc2285 only.The event ID to set the private read receipt location at.
This is equivalent to calling the create_receipt endpoint with a
ReceiptType::ReadPrivate.