logo
pub struct IncomingRequest {
    pub room_id: OwnedRoomId,
    pub fully_read: OwnedEventId,
    pub read_receipt: Option<OwnedEventId>,
}
‘Incoming’ variant of Request.

Fields

room_id: OwnedRoomId

The room ID to set the read marker in for the user.

fully_read: OwnedEventId

The event ID the read marker should be located at.

The event MUST belong to the room.

read_receipt: Option<OwnedEventId>

The event ID to set the read receipt location at.

This is equivalent to calling the create_read_receipt endpoint and is provided here to save that extra call.