ruma_client_api::room::create_room::v3

Struct IncomingRequest

pub struct IncomingRequest {
    pub creation_content: Option<Raw<CreationContent>>,
    pub initial_state: Vec<Raw<AnyInitialStateEvent>>,
    pub invite: Vec<OwnedUserId>,
    pub invite_3pid: Vec<IncomingInvite3pid>,
    pub is_direct: bool,
    pub name: Option<String>,
    pub power_level_content_override: Option<Raw<RoomPowerLevelsEventContent>>,
    pub preset: Option<RoomPreset>,
    pub room_alias_name: Option<String>,
    pub room_version: Option<RoomVersionId>,
    pub topic: Option<String>,
    pub visibility: Visibility,
}
Available on crate features client or server only.
‘Incoming’ variant of Request.

Fields

creation_content: Option<Raw<CreationContent>>

Extra keys to be added to the content of the m.room.create.

initial_state: Vec<Raw<AnyInitialStateEvent>>

List of state events to send to the new room.

Takes precedence over events set by preset, but gets overridden by name and topic keys.

invite: Vec<OwnedUserId>

A list of user IDs to invite to the room.

This will tell the server to invite everyone in the list to the newly created room.

invite_3pid: Vec<IncomingInvite3pid>

List of third party IDs of users to invite.

is_direct: bool

If set, this sets the is_direct flag on room invites.

name: Option<String>

If this is included, an m.room.name event will be sent into the room to indicate the name of the room.

power_level_content_override: Option<Raw<RoomPowerLevelsEventContent>>

Power level content to override in the default power level event.

preset: Option<RoomPreset>

Convenience parameter for setting various default state events based on a preset.

room_alias_name: Option<String>

The desired room alias local part.

room_version: Option<RoomVersionId>

Room version to set for the room.

Defaults to homeserver’s default if not specified.

topic: Option<String>

If this is included, an m.room.topic event will be sent into the room to indicate the topic for the room.

visibility: Visibility

A public visibility indicates that the room will be shown in the published room list.

A private visibility will hide the room from the published room list. Defaults to Private.