pub enum IncomingLoginInfo {
Password(IncomingPassword),
Token(IncomingToken),
ApplicationService(IncomingApplicationService),
// some variants omitted
}Available on crate features
client or server only.Expand description
‘Incoming’ variant of LoginInfo.
Variants
Password(IncomingPassword)
An identifier and password are supplied to authenticate.
Token(IncomingToken)
Token-based login.
ApplicationService(IncomingApplicationService)
Application Service-specific login.
Implementations
Sourceimpl IncomingLoginInfo
impl IncomingLoginInfo
Sourcepub fn new(login_type: &str, data: JsonObject) -> Result<Self>
pub fn new(login_type: &str, data: JsonObject) -> Result<Self>
Creates a new IncomingLoginInfo with the given login_type string, session and data.
Prefer to use the public variants of IncomingLoginInfo where possible; this
constructor is meant be used for unsupported authentication mechanisms only and
does not allow setting arbitrary data for supported ones.
Errors
Returns an error if the login_type is known and serialization of data to the
corresponding IncomingLoginInfo variant fails.
Sourcepub fn to_outgoing(&self) -> LoginInfo<'_>
pub fn to_outgoing(&self) -> LoginInfo<'_>
Convert IncomingLoginInfo to LoginInfo.