Available on crate features
client or server only.Expand description
/v3/ (spec)
Structs
- Data for a request to the
logoutAPI endpoint. - Data in the response from the
logoutAPI endpoint.
Constants
- Metadata for the
logoutAPI endpoint.
Type Aliases
- Convenience type alias for Request, for consistency with other IncomingRequest types.
- Convenience type alias for Response, for consistency with other IncomingResponse types.