pub struct Request<'a> {
pub room_id: &'a RoomId,
pub event_type: StateEventType,
pub state_key: &'a str,
pub body: Raw<AnyStateEventContent>,
pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
}Available on crate features
client or server only.Expand description
Data for a request to the send_state_event API endpoint.
Send a state event to a room associated with a given state key.
Fields
room_id: &'a RoomIdThe room to set the state in.
event_type: StateEventTypeThe type of event to send.
state_key: &'a strThe state_key for the state to send.
body: Raw<AnyStateEventContent>The event content to send.
timestamp: Option<MilliSecondsSinceUnixEpoch>Timestamp to use for the origin_server_ts of the event.
This is called timestamp massaging and can only be used by Appservices.
Note that this does not change the position of the event in the timeline.
Implementations
Sourceimpl<'a> Request<'a>
impl<'a> Request<'a>
Sourcepub fn new_raw(
room_id: &'a RoomId,
event_type: StateEventType,
state_key: &'a str,
body: Raw<AnyStateEventContent>,
) -> Self
pub fn new_raw( room_id: &'a RoomId, event_type: StateEventType, state_key: &'a str, body: Raw<AnyStateEventContent>, ) -> Self
Creates a new Request with the given room id, event type, state key and raw event
content.