Available on crate features client or server only.
/v3/ (spec)

Structs

Ephemeral events not recorded in the timeline or state of the room.
The global private data created by this user.
The state of a room that the user has been invited to.
Updates to the rooms that the user has been invited to.
Updates to joined rooms.
A mapping from a key events to a list of StrippedStateEvent.
Updates to knocked rooms.
Historical updates to left rooms.
Updates to the presence status of other users.
Request type for the sync endpoint.
Response type for the sync endpoint.
The private data that this user has attached to this room.
Information about room for rendering to clients.
Updates to rooms.
State events in the room.
Events in the room.
Messages sent directly between devices.

Enums

A filter represented either as its full JSON definition or the ID of a saved filter.