Available on crate features
client or server only.Expand description
/v3/ (spec)
Structs
- Information on E2E device updates.
- Ephemeral events not recorded in the timeline or state of the room.
- The global private data created by this user.
- ‘Incoming’ variant of Request.
- The state of a room that the user has been invited to.
- Updates to the rooms that the user has been invited to.
- Updates to joined rooms.
- A mapping from a key
eventsto a list ofStrippedStateEvent. - Updates to knocked rooms.
- Historical updates to left rooms.
- Updates to the presence status of other users.
- Data for a request to the
syncAPI endpoint. - Data in the response from the
syncAPI endpoint. - The private data that this user has attached to this room.
- Information about room for rendering to clients.
- Updates to rooms.
- State events in the room.
- Events in the room.
- Messages sent directly between devices.
Enums
- A filter represented either as its full JSON definition or the ID of a saved filter.
- ‘Incoming’ variant of Filter.
Constants
- Metadata for the
syncAPI endpoint.
Type Aliases
- Convenience type alias for Response, for consistency with other IncomingResponse types.