Struct ruma_client_api::sync::sync_events::v3::LeftRoom
source · [−]pub struct LeftRoom {
pub timeline: Timeline,
pub state: State,
pub account_data: RoomAccountData,
}Available on crate features
client or server only.Expand description
Historical updates to left rooms.
Fields
timeline: TimelineThe timeline of messages and state changes in the room up to the point when the user left.
state: StateThe state updates for the room up to the start of the timeline.
account_data: RoomAccountDataThe private data that this user has attached to this room.
Implementations