Available on (crate features
client or server) and crate feature unstable-msc3575 only.Expand description
Structs
- ‘Incoming’ variant of Request.
- Data for a request to the
syncAPI endpoint. - Data in the response from the
syncAPI endpoint. - The RoomSubscriptions of the SlidingSync Request
- Updates to joined rooms.
- Updates to joined rooms.
- Updates to joined rooms.
- Sliding Sync Request for each list.
- Filter for a sliding sync list, set at request.
Enums
- Operation applied to the specific SlidingSyncList
Constants
- Metadata for the
syncAPI endpoint.
Type Aliases
- Convenience type alias for Response, for consistency with other IncomingResponse types.