pub struct SlidingSyncRoom {
Show 14 fields pub name: Option<String>, pub avatar: JsOption<OwnedMxcUri>, pub initial: Option<bool>, pub is_dm: Option<bool>, pub invite_state: Option<Vec<Raw<AnyStrippedStateEvent>>>, pub unread_notifications: UnreadNotificationsCount, pub timeline: Vec<Raw<AnySyncTimelineEvent>>, pub required_state: Vec<Raw<AnySyncStateEvent>>, pub prev_batch: Option<String>, pub limited: bool, pub joined_count: Option<UInt>, pub invited_count: Option<UInt>, pub num_live: Option<UInt>, pub timestamp: Option<MilliSecondsSinceUnixEpoch>,
}
Available on (crate features client or server) and crate feature unstable-msc3575 only.
Updates to joined rooms.

Fields

name: Option<String>

The name of the room as calculated by the server.

avatar: JsOption<OwnedMxcUri>

The avatar of the room.

initial: Option<bool>

Was this an initial response.

is_dm: Option<bool>

This is a direct message.

invite_state: Option<Vec<Raw<AnyStrippedStateEvent>>>

If this is Some(_), this is a not-yet-accepted invite containing the given stripped state events.

unread_notifications: UnreadNotificationsCount

Counts of unread notifications for this room.

timeline: Vec<Raw<AnySyncTimelineEvent>>

The timeline of messages and state changes in the room.

required_state: Vec<Raw<AnySyncStateEvent>>

Updates to the state at the beginning of the timeline. A list of state events.

prev_batch: Option<String>

The prev_batch allowing you to paginate through the messages before the given ones.

limited: bool

True if the number of events returned was limited by the limit on the filter.

joined_count: Option<UInt>

The number of users with membership of join, including the client’s own user ID.

invited_count: Option<UInt>

The number of users with membership of invite.

num_live: Option<UInt>

The number of timeline events which have just occurred and are not historical.

timestamp: Option<MilliSecondsSinceUnixEpoch>

The timestamp of the room.

It’s not to be confused with origin_server_ts of the latest event in the timeline. bump_event_types might “ignore” some events when computing the timestamp of the room. Thus, using this timestamp value is more accurate than relying on the latest event.

Implementations

source

impl SlidingSyncRoom

source

pub fn new() -> Self

Creates an empty Room.