pub struct SlidingSyncRoom {
pub name: Option<String>,
pub initial: Option<bool>,
pub is_dm: Option<bool>,
pub invite_state: Vec<Raw<AnyStrippedStateEvent>>,
pub unread_notifications: UnreadNotificationsCount,
pub timeline: Vec<Raw<AnySyncTimelineEvent>>,
pub required_state: Vec<Raw<AnySyncStateEvent>>,
pub prev_batch: Option<String>,
}Available on (crate features
client or server) and crate feature unstable-msc3575 only.Expand description
Updates to joined rooms.
Fields
name: Option<String>The name of the room as calculated by the server.
initial: Option<bool>Was this an initial response.
is_dm: Option<bool>This is a direct message.
invite_state: Vec<Raw<AnyStrippedStateEvent>>This is not-yet-accepted invite, with the following sync state events the room must be considered in invite state as long as the Option is not None even if there are no state events.
unread_notifications: UnreadNotificationsCountCounts of unread notifications for this room.
timeline: Vec<Raw<AnySyncTimelineEvent>>The timeline of messages and state changes in the room.
required_state: Vec<Raw<AnySyncStateEvent>>Updates to the state at the beginning of the timeline.
A list of state events.
prev_batch: Option<String>The prev_batch allowing you to paginate through the messages before the given ones.
Implementations