Struct ruma_client_api::sync::sync_events::v4::SyncRequestList
source · pub struct SyncRequestList {
pub slow_get_all_rooms: bool,
pub ranges: Vec<(UInt, UInt)>,
pub sort: Vec<String>,
pub room_details: RoomDetailsConfig,
pub include_old_rooms: Option<IncludeOldRooms>,
pub filters: Option<SyncRequestListFilters>,
}client or server) and crate feature unstable-msc3575 only.Expand description
Sliding Sync Request for each list.
Fields
slow_get_all_rooms: boolPut this list into the all-rooms-mode.
Settings this to true will inform the server that, no matter how slow
that might be, the clients wants all rooms the filters apply to. When operating
in this mode, ranges and sort will be ignored there will be no movement operations
(DELETE followed by INSERT) as the client has the entire list and can work out whatever
sort order they wish. There will still be DELETE and INSERT operations when rooms are
left or joined respectively. In addition, there will be an initial SYNC operation to let
the client know which rooms in the rooms object were from this list.
ranges: Vec<(UInt, UInt)>The ranges of rooms we’re interested in.
sort: Vec<String>The sort ordering applied to this list of rooms. Sticky.
room_details: RoomDetailsConfigThe details to be included per room
include_old_rooms: Option<IncludeOldRooms>If tombstoned rooms should be returned and if so, with what information attached
filters: Option<SyncRequestListFilters>Filters to apply to the list before sorting. Sticky.