pub struct SyncRequestList {
pub slow_get_all_rooms: bool,
pub ranges: Vec<(UInt, UInt)>,
pub sort: Vec<String>,
pub required_state: Vec<(RoomEventType, String)>,
pub timeline_limit: Option<UInt>,
pub filters: Option<SyncRequestListFilters>,
}client or server) and crate feature unstable-msc3575 only.Expand description
Sliding Sync Request for each list.
Fields
slow_get_all_rooms: boolPut this list into the all-rooms-mode.
Settings this to true will inform the server that, no matter how slow
that might be, the clients wants all rooms the filters apply to. When operating
in this mode, ranges and sort will be ignored there will be no movement operations
(DELETE followed by INSERT) as the client has the entire list and can work out whatever
sort order they wish. There will still be DELETE and INSERT operations when rooms are
left or joined respectively. In addition, there will be an initial SYNC operation to let
the client know which rooms in the rooms object were from this list.
ranges: Vec<(UInt, UInt)>The ranges of rooms we’re interested in.
sort: Vec<String>The sort ordering applied to this list of rooms. Sticky.
required_state: Vec<(RoomEventType, String)>Required state for each room returned. An array of event type and state key tuples. Note that elements of this array are NOT sticky so they must be specified in full when they are changed. Sticky.
timeline_limit: Option<UInt>The maximum number of timeline events to return per room. Sticky.
filters: Option<SyncRequestListFilters>Filters to apply to the list before sorting. Sticky.