ruma_client_api::uiaa

Enum AuthData

#[non_exhaustive]
pub enum AuthData<'a> { Password(Password<'a>), ReCaptcha(ReCaptcha<'a>), EmailIdentity(EmailIdentity<'a>), Msisdn(Msisdn<'a>), Dummy(Dummy<'a>), RegistrationToken(RegistrationToken<'a>), FallbackAcknowledgement(FallbackAcknowledgement<'a>), }
Available on crate features client or server only.
Information for one authentication stage.

To construct the custom AuthData variant you first have to construct IncomingAuthData::new and then call IncomingAuthData::to_outgoing on it.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Password(Password<'a>)

Password-based authentication (m.login.password).



ReCaptcha(ReCaptcha<'a>)

Google ReCaptcha 2.0 authentication (m.login.recaptcha).



EmailIdentity(EmailIdentity<'a>)

Email-based authentication (m.login.email.identity).



Msisdn(Msisdn<'a>)

Phone number-based authentication (m.login.msisdn).



Dummy(Dummy<'a>)

Dummy authentication (m.login.dummy).



RegistrationToken(RegistrationToken<'a>)

Registration token-based authentication (m.login.registration_token).



FallbackAcknowledgement(FallbackAcknowledgement<'a>)

Fallback acknowledgement.

Implementations

Source

impl<'a> AuthData<'a>

pub fn fallback_acknowledgement(session: &'a str) -> Self

Creates a new AuthData::FallbackAcknowledgement with the given session key.

pub fn auth_type(&self) -> Option<AuthType>

Returns the value of the type field, if it exists.

pub fn session(&self) -> Option<&'a str>

Returns the value of the session field, if it exists.

pub fn data(&self) -> Cow<'_, JsonObject>

Returns the associated data.

The returned JSON object won’t contain the type and session fields, use .auth_type() / .session() to access those.

Prefer to use the public variants of AuthData where possible; this method is meant to be used for custom auth types only.