#[non_exhaustive]pub enum IncomingAuthData {
Password(IncomingPassword),
ReCaptcha(IncomingReCaptcha),
EmailIdentity(IncomingEmailIdentity),
Msisdn(IncomingMsisdn),
Dummy(IncomingDummy),
RegistrationToken(IncomingRegistrationToken),
FallbackAcknowledgement(IncomingFallbackAcknowledgement),
}client or server only.Expand description
‘Incoming’ variant of AuthData.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Password(IncomingPassword)
Password-based authentication (m.login.password).
ReCaptcha(IncomingReCaptcha)
Google ReCaptcha 2.0 authentication (m.login.recaptcha).
EmailIdentity(IncomingEmailIdentity)
Email-based authentication (m.login.email.identity).
Msisdn(IncomingMsisdn)
Phone number-based authentication (m.login.msisdn).
Dummy(IncomingDummy)
Dummy authentication (m.login.dummy).
RegistrationToken(IncomingRegistrationToken)
Registration token-based authentication (m.login.registration_token).
FallbackAcknowledgement(IncomingFallbackAcknowledgement)
Fallback acknowledgement.
Implementations
Sourceimpl IncomingAuthData
impl IncomingAuthData
Sourcepub fn new(
auth_type: &str,
session: Option<String>,
data: JsonObject,
) -> Result<Self>
pub fn new( auth_type: &str, session: Option<String>, data: JsonObject, ) -> Result<Self>
Creates a new IncomingAuthData with the given auth_type string, session and data.
Prefer to use the public variants of IncomingAuthData where possible; this constructor is
meant be used for unsupported authentication types only and does not allow setting arbitrary
data for supported ones.
Errors
Returns an error if the auth_type is known and serialization of data to the
corresponding IncomingAuthData variant fails.
Sourcepub fn data(&self) -> Cow<'_, JsonObject>
pub fn data(&self) -> Cow<'_, JsonObject>
Returns the associated data.
The returned JSON object won’t contain the type and session fields, use
.auth_type() / .session() to access those.
Prefer to use the public variants of AuthData where possible; this method is meant to be
used for custom auth types only.
Sourcepub fn to_outgoing(&self) -> AuthData<'_>
pub fn to_outgoing(&self) -> AuthData<'_>
Convert IncomingAuthData to AuthData.