pub enum UserIdentifier<'a> {
UserIdOrLocalpart(&'a str),
Email {
address: &'a str,
},
Msisdn {
number: &'a str,
},
PhoneNumber {
country: &'a str,
phone: &'a str,
},
// some variants omitted
}Available on crate features
client or server only.Expand description
Identification information for the user.
Variants
UserIdOrLocalpart(&'a str)
Either a fully qualified Matrix user ID, or just the localpart (as part of the ‘identifier’ field).
An email address.
Msisdn
A phone number in the MSISDN format.
PhoneNumber
A phone number as a separate country code and phone number.
The homeserver will be responsible for canonicalizing this to the MSISDN format.
Fields

country: &'a strThe country that the phone number is from.
This is a two-letter uppercase ISO-3166-1 alpha-2 country code.
Implementations
Sourceimpl<'a> UserIdentifier<'a>
impl<'a> UserIdentifier<'a>
Sourcepub fn third_party_id(medium: &'a Medium, address: &'a str) -> Self
pub fn third_party_id(medium: &'a Medium, address: &'a str) -> Self
Creates a new UserIdentifier from the given third party identifier.
Sourcepub fn as_third_party_id(&self) -> Option<(&'a Medium, &'a str)>
pub fn as_third_party_id(&self) -> Option<(&'a Medium, &'a str)>
Get this UserIdentifier as a third party identifier if it is one.