[−][src]Module ruma_client_api::unversioned
Endpoints that cannot change with new versions of the Matrix specification.
Modules
| discover_homeserver | |
| get_supported_versions |
Endpoints that cannot change with new versions of the Matrix specification.
| discover_homeserver | |
| get_supported_versions |